@@ -4,7 +4,9 @@
 
 <HTML>
 <head>
+  
   <title>libMesh - C++ Finite Element Library</title>
+  <meta name="verify-v1" content="X3cfnoMNiuo9l+ZWNoTZv590OCrbnVJsxCDsWZdzFmw=">
   <META name="description" content="A parallel adaptive C++ finite element library for simulating partial differential equations.">
   <META name="keywords" content="finite element, finite element method, finite element modeling, finite element modelling, finite element software, finite element methods, science math numerical analysis, science math numerical analysis software, numerical analysis research group, partial differential equations, applied partial differential equations, elliptic parabolic hyperbolic partial differential equations, finite element analysis modeling software, system of linear equation solver, simultaneous linear equation solver, computational fluid dynamics software">
   <META name="robots" content="index, follow">
@@ -74,22 +76,16 @@ goal of the library is to provide support for adaptive mesh refinement
 (AMR) computations in parallel while allowing a research scientist to
 focus on the physics they are modeling.
 
-<!-- Development began in March 2002 with the intent of providing a -->
-<!-- friendly interface to a number of high-quality software packages that -->
-<!-- are publicly available. -->
-
 <br>
 <br>
 <code>libMesh</code> currently supports 1D, 2D, and 3D steady and transient finite element simulations.
-The library makes use of high-quality, existing software whenever possible.
+The library makes use of high-quality, <a href="externalsoftware.php">existing software</a> whenever possible.
 <a href="http://www-unix.mcs.anl.gov/petsc/petsc-2">PETSc</a> is
-used for the solution of linear systems on both serial and
-parallel platforms, and
+used for the solution of linear systems on both serial and parallel platforms, and
 <a href="http://www.mgnet.org/mgnet/Codes/laspack/html/laspack.html">LASPack</a>
 is included with the library to provide linear solver support on serial machines.
 An optional interface to <a href="http://www.grycap.upv.es/slepc">SLEPc</a> is also
 provided for solving both standard and generalized eigenvalue problems.
-A complete list of external applications used in the library may be found <a href="externalsoftware.php">here</a>.
 
 
 <br>
@@ -109,9 +105,9 @@ Many thanks to <a href="http://sourceforge.net">SourceForge</a> for
 <a href="http://sourceforge.net/projects/libmesh">hosting the
 project</a>.  You can find out what is currently happening in the
 development branch by checking out the
-<a href="http://libmesh.cvs.sourceforge.net/libmesh/libmesh">CVS
+<a href="http://libmesh.svn.sourceforge.net/viewvc/libmesh/trunk/libmesh">SVN
 Logs</a> online, and you can see many people are downloading the library
-on the <a href="http://sourceforge.net/project/stats/?group_id=71130&ugn=libmesh">statistics</a> page.
+on the <a href="http://sourceforge.net/project/stats/?group_id=71130&ugn=libmesh&type=&mode=year">statistics</a> page.
 
 </div>
 <br>
