@@ -19,27 +19,30 @@
 The <code>libMesh</code> source can be 
 <a href="http://sourceforge.net/project/showfiles.php?group_id=71130">downloaded from the project's SourceForge homepage</a>.
 Stable releases are located there as compressed tar archives. You may also
-access the CVS source tree for the latest code. You can get read-only access
-to the CVS repository via:
+access the SVN source tree for the latest code. You can get read-only access
+to the SVN repository via:
 <br>
 
 <div class="fragment">
-  <pre>cvs -d:pserver:anonymous@libmesh.cvs.sourceforge.net:/cvsroot/libmesh co libmesh </pre>
+  <pre>svn checkout https://libmesh.svn.sourceforge.net/svnroot/libmesh/trunk/libmesh </pre>
 </div>
 
+<br>
+More information regarding the <code>libMesh</code> SVN repository may be found <a href="subversion.php"> here</a>.
+
+<br>
 <br>
 If you would like to contribute to the project you will need a SourceForge
 developer account, or you can contribute patches. To create a patch from a
-modified CVS tree simply do:
+modified SVN tree simply do:
 <br>
 <div class="fragment">
-  <pre>cvs diff -c &gt; patch </pre>
+  <pre>svn diff &gt; patch </pre>
 </div>
 
 <br>
 in the top-level directory. You can then submit the file <code>patch</code>.
 
-
 <a name="compilers"></a><h2>Compilers</h2>
 
 <code>libMesh</code> makes extensive use of the standard C++ library,
@@ -63,7 +66,7 @@ The library is known to work with the following compilers:
     </ul>
   <li>Intel ICC/ECC</li>
     <ul>
-      <li><code>icc/ifort</code> 9.x, 8.x</li>
+      <li><code>icc/ifort</code> 10.x, 9.x, 8.x</li>
       <li><code>icc/ifc</code> 7.x</li>
       <li><code>icc/ifc</code> 6.0</li>
       <li>Earlier versions (&lt;= 5.0) not supported</li>
@@ -139,7 +142,7 @@ is configured simply type <code>make</code> to build the library. Typing
 The Makefiles distributed with the library look at the shell environment variable
 <code>METHOD</code> to determine what mode the library should be built in. Valid 
 values for <code>METHOD</code> are <code>opt</code> (optimized mode, the default 
-if <code>METHOD</code> is empty), <code>debug</code> (build with debug symbols), 
+if <code>METHOD</code> is empty), <code>dbg</code> (build with debug symbols), 
 and <code>pro</code> (build with profiling support for use with <code>gprof)</code>. 
 Once the library is configured you can build it simply by typing
 
@@ -149,7 +152,7 @@ Once the library is configured you can build it simply by typing
 
 
 <a name="test"></a><h2>Testing the Library</h2>
-
+<h3>Running the Examples</h3>
 <code>libMesh</code> includes a number of examples in the <code>examples</code>
 directory. From the top-level directory you can build and run the example programs 
 by typing
@@ -165,6 +168,15 @@ in the example to write a different format, just replace the <code>write_gmv</co
 function call with whatever you like.
 
 
+<h3>Unit Tests</h3>
+The SVN repository contains a <code>libmesh_tests</code> entry in the main trunk
+that contains a series of unit tests which can be used to validate a <code>libMesh</code>
+installation.  You may download the tests via
+<div class="fragment">
+  <pre> svn checkout https://libmesh.svn.sourceforge.net/svnroot/libmesh/trunk/libmesh_tests</pre>
+</div>
+
+
 <a name="link"></a><h2>Linking With Your Application</h2>
 
 Since <code>libMesh</code> can be configured with many additional packages we recommend
