@@ -16,14 +16,13 @@
 <h2>libMesh Overviews</h2>
 <ul>
   <li> <a href="http://cfdlab.ae.utexas.edu/~benkirk/libmesh_uwa03.pdf">libMesh Presentation</a> (from the June 2003 UWA Shortcourse)</li>
-  <li> <a href="http://cfdlab.ae.utexas.edu/~peterson/ERDC_talk.pdf">LibMesh Experience and Usage</a> (January 2007 ERDC course)</li>
+  <li> <a href="http://cfdlab.ae.utexas.edu/~peterson/ERDC_talk.pdf">libMesh Experience and Usage</a> (January 2007 ERDC course)</li>
   <li> <a href="http://cfdlab.ae.utexas.edu/~roystgnr/vicksburg.pdf">AMR Infrastructure Expansion, Adding Complexity</a> (January 2007 ERDC course)</li>
-  <li> <a href="http://cfdlab.ae.utexas.edu/~roystgnr/libmesh_intro.pdf">LibMesh Introduction</a> (June 2007 lecture, Num. Meth. for Transport in Semiconductors)</li>
-  <li> <a href="http://cfdlab.ae.utexas.edu/~roystgnr/sandia_libmesh.pdf">LibMesh Finite Element Library</a> (August 2007 seminar, Sandia National Laboratories)</li>
+  <li> <a href="http://cfdlab.ae.utexas.edu/~roystgnr/libmesh_intro.pdf">libMesh Introduction</a> (June 2007 lecture, Num. Meth. for Transport in Semiconductors)</li>
+  <li> <a href="http://cfdlab.ae.utexas.edu/~roystgnr/sandia_libmesh.pdf">libMesh Finite Element Library</a> (August 2007 seminar, Sandia National Laboratories)</li>
 </ul>
 
-
-<h2>Applications</h2>
+<h2>Developer Applications</h2>
 <ul>
 <!--   <li> <a href="http://cfdlab.ae.utexas.edu/~benkirk/adv_flows_project.pdf">Advanced Flows Class Project</a> (natural convection, 2002)</li> -->
 <!--   <li> <a href="http://cfdlab.ae.utexas.edu/~benkirk/siam_geo.pdf">SIAM Geosciences 2003</a></li> -->
@@ -31,6 +30,20 @@
   <li> <a href="http://cfdlab.ae.utexas.edu/~benkirk/seminar/talk.pdf">Finite Elements - Introduction and Applications</a> (April 2004 NASA/JSC technical seminar)</li>
   <li> <a href="http://ntrs.nasa.gov/search.jsp?N=4294668673">SUPG Finite Element Simulations of Compressible Flows for Aerothermodynamic Applications</a>, February 2007</li>
   <li> <a href="http://cfdlab.ae.utexas.edu/~benkirk/defense.pdf">Benjamin S. Kirk's PhD Dissertation Defense</a>, March 2007</li>
+  <li> <a href="http://cfdlab.ae.utexas.edu/~peterson/defense/defense.pdf">John W. Peterson's PhD Dissertation Defense</a>, April 2008</li>
+</ul>
+
+<h2>Applications which use libMesh</h2>
+<ul>
+  <li> <a href="http://libmultiscale.gforge.inria.fr">libMultiScale</a> - multiscale modeling</li>
+   <ul>
+      <li><a href="http://libmultiscale.gforge.inria.fr/presentation-hpsec.pdf">High Performance Multiscale Simulation for Crack Propagation</a>, Guillaume Anciaux, Olivier Coulaud, and Jean Roman, 2006</li>
+      <li><a href="http://libmultiscale.gforge.inria.fr/talk.pdf">Simulation multi-chelles des solides par une approche couple dynamique molculaire/lments finis. De la modlisation  la simulation haute performance</a>, Guillaume Anciaux's PhD Dissertation Defense, July 2007</li>
+   </ul>
+  <li><a href="http://octmesh.forja.rediris.es">OctMesh</a> - finite elements in Octave</li>
+    <ul>
+      <li> <a href="http://octmesh.forja.rediris.es/octmesh-cedya.pdf">OctMesh: a finite elements tool kit for Octave</a>, J. Rafael Rodrguez Galvn, 2007</li>
+    </ul>
 </ul>
 
 
@@ -68,7 +81,7 @@
 <h2>Miscellaneous</h2>
 <ul>
   <li> <a href="http://www.cfdlab.ae.utexas.edu/~peterson/scraper.pdf">Scraper Flow</a> Presentation with I. Schoegl.</li>
-  <li> <a href="http://www.challenge.nm.org/FinalReports/08.pdf">Albuquerque Academy</a> Presentation on Stress Analysis in a Torus.</li>
+  <!-- <li> <a href="http://www.challenge.nm.org/FinalReports/08.pdf">Albuquerque Academy</a> Presentation on Stress Analysis in a Torus.</li> -->
   <li> <a href="http://www.saviac.org/74th_Symposium/abstracts/U040.htm">SAVIAC</a> conference abstract.</li>
 
   <li>
@@ -78,6 +91,10 @@
       low Mach number.</i>
     <a href="http://www.ufrmeca.univ-lyon1.fr/~buffat/PUBLI_HTML/LowMach04.pdf">
       Low Mach Conference</a>, June 2004.
+  </li>
+
+  <li>
+    M.A. Sbai, <a href="http://cfdlab.ae.utexas.edu/~benkirk/Sbai_Stuttgart_CO2_presentation.pdf">A Process Oriented Toolbox for Numerical Analysis of CO2 Disposal in Aquifers</a>, Workshop on Numerical Models for Carbon Dioxide Storage in Geological Formations, Stuttgart, Germany, April 2008.
   </li>  
 </ul>
 
