@@ -1,4 +1,4 @@
-/* $Id: naviersystem.h,v 1.3 2007-05-09 19:31:47 jwpeterson Exp $ */
+/* $Id: naviersystem.h 2644 2008-02-06 20:40:40Z roystgnr $ */
 
 /* The Next Great Finite Element Library. */
 /* Copyright (C) 2003  Benjamin S. Kirk */
@@ -43,6 +43,9 @@ public:
   virtual bool element_constraint (bool request_jacobian);
   virtual bool side_constraint (bool request_jacobian);
 
+  // Mass matrix part
+  virtual bool mass_residual (bool request_jacobian);
+
   // Indices for each variable;
   unsigned int p_var, u_var, v_var, w_var;
 
