@@ -1,4 +1,4 @@
-// $Id: dof_map.h,v 1.35 2007-10-21 20:48:40 benkirk Exp $
+// $Id: dof_map.h 2795 2008-04-14 03:05:20Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -35,9 +35,14 @@
 #include "reference_counted_object.h"
 #include "libmesh.h" // libMesh::invalid_uint
 #include "vector_value.h" // RealVectorValue
+#include "threads.h"
+#include "threads_allocators.h"
+#include "elem_range.h"
+
 
 // Forward Declarations
 class DofMap;
+class DofObject;
 class Elem;
 class MeshBase;
 class Mesh;
@@ -53,15 +58,98 @@ template <typename T> class NumericVector;
 
 
 
+// ------------------------------------------------------------
+// Sparsity Pattern
+
 /**
- * This class handles the numbering of degrees of freedom on a mesh.
- * For systems of equations the class supports a fixed number of variables.
- * The degrees of freedom are numbered such that sequential, contiguous blocks
- * correspond to distinct subdomains.  This is so that the resulting data
- * structures will work well with parallel linear algebra packages.
- *
- * @author Benjamin S. Kirk, 2002-2007
+ * This defines the sparsity pattern, or graph, of a sparse matrix.
+ * The format is quite simple -- the global indices of the nonzero entries
+ * in each row are packed into a vector.  The global indices (i,j) of the 
+ * nth nonzero entry of row i are given by j = sparsity_pattern[i][n];
  */
+namespace SparsityPattern // use a namespace so member classes can be forward-declared.
+{
+  typedef std::vector<unsigned int, Threads::scalable_allocator<unsigned int> > Row;
+  class Graph : public std::vector<Row> {};
+  
+  /**
+   * Splices the two sorted ranges [begin,middle) and [middle,end)
+   * into one sorted range [begin,end).  This method is much like
+   * std::inplace_merge except it assumes the intersection
+   * of the two sorted ranges is empty and that any element in
+   * each range occurs only once in that range.  Additionally,
+   * this sort occurs in-place, while std::inplace_merge may
+   * use a temporary buffer.
+   */ 
+  template<typename BidirectionalIterator>
+  static void sort_row (const BidirectionalIterator begin,
+			BidirectionalIterator       middle,
+			const BidirectionalIterator end);
+
+  /**
+   * This helper class can be called on multiple threads to compute 
+   * the sparsity pattern (or graph) of the sparse matrix resulting
+   * from the discretization.  This pattern may be used directly by
+   * a particular sparse matrix format (e.g. \p LaspackMatrix)
+   * or indirectly (e.g. \p PetscMatrix).  In the latter case the
+   * number of nonzeros per row of the matrix is needed for efficient 
+   * preallocation.  In this case it suffices to provide estimate
+   * (but bounding) values, and in this case the threaded method can
+   * take some short-cuts for efficiency.
+   */
+  class Build
+  {
+  private:
+    const MeshBase &mesh;
+    const DofMap &dof_map;
+    const CouplingMatrix *dof_coupling;
+    const bool implicit_neighbor_dofs;
+    const bool need_full_sparsity_pattern;
+
+  public:
+
+    SparsityPattern::Graph sparsity_pattern;
+    std::vector<unsigned int> n_nz;
+    std::vector<unsigned int> n_oz;
+    
+    Build (const MeshBase &mesh_in,
+	   const DofMap &dof_map_in,
+	   const CouplingMatrix *dof_coupling_in,
+	   const bool implicit_neighbor_dofs_in,
+	   const bool need_full_sparsity_pattern_in) :
+      mesh(mesh_in),
+      dof_map(dof_map_in),
+      dof_coupling(dof_coupling_in),
+      implicit_neighbor_dofs(implicit_neighbor_dofs_in),
+      need_full_sparsity_pattern(need_full_sparsity_pattern_in)
+    {}
+
+    Build (Build &other, Threads::split) :
+      mesh(other.mesh),
+      dof_map(other.dof_map),
+      dof_coupling(other.dof_coupling),
+      implicit_neighbor_dofs(other.implicit_neighbor_dofs),
+      need_full_sparsity_pattern(other.need_full_sparsity_pattern)
+    {}
+
+    void operator()(const ConstElemRange &range);
+
+    void join (const Build &other);
+  };
+
+#if defined(__GNUC__) && (__GNUC__ < 4) && !defined(__INTEL_COMPILER)
+  /**
+   * Dummy function that does nothing but can be used to prohibit
+   * compiler optimization in some situations where some compilers
+   * have optimization bugs.
+   */
+  void _dummy_function(void);
+#endif
+  
+}
+
+
+
 
 // ------------------------------------------------------------
 // AMR constraint matrix types
@@ -70,16 +158,20 @@ template <typename T> class NumericVector;
 /**
  * A row of the Dof constraint matrix.
  */
-typedef std::map<unsigned int, Real> DofConstraintRow;
+typedef std::map<unsigned int, Real, 
+                 std::less<unsigned int>, 
+                 Threads::scalable_allocator<std::pair<const unsigned int, Real> > > DofConstraintRow;
 
 /** 
  * The constraint matrix storage format. 
  * We're using a class instead of a typedef to allow forward
- * declarations and future flexibility.  Is there some issue with
- * deriving from standard containers, i.e. don't do it because they
- * don't have virtual destructors?
+ * declarations and future flexibility.  Don't delete this from
+ * a pointer-to-std::map; the destructor isn't virtual!
  */
-class DofConstraints : public std::map<unsigned int, DofConstraintRow>
+class DofConstraints : public std::map<unsigned int, 
+                                       DofConstraintRow, 
+                                       std::less<unsigned int>, 
+                                       Threads::scalable_allocator<std::pair<const unsigned int, DofConstraintRow> > >
 {
 };
 #endif // ENABLE_AMR || ENABLE_PERIODIC
@@ -90,7 +182,7 @@ class DofConstraints : public std::map<unsigned int, DofConstraintRow>
 
 #ifdef ENABLE_PERIODIC
 /**
- * A row of the Dof constraint matrix.
+ * The definition of a periodic boundary.
  */
 class PeriodicBoundary
 {
@@ -132,10 +224,20 @@ private:
 };
 #endif // ENABLE_PERIODIC
 
+
   
 // ------------------------------------------------------------
 // Dof Map class definition
 
+/**
+ * This class handles the numbering of degrees of freedom on a mesh.
+ * For systems of equations the class supports a fixed number of variables.
+ * The degrees of freedom are numbered such that sequential, contiguous blocks
+ * correspond to distinct subdomains.  This is so that the resulting data
+ * structures will work well with parallel linear algebra packages.
+ *
+ * @author Benjamin S. Kirk, 2002-2007
+ */
 class DofMap : public ReferenceCountedObject<DofMap>
 {
 public:
@@ -237,13 +339,13 @@ public:
    * Returns the number of degrees of freedom on subdomain \p proc.
    */
   unsigned int n_dofs_on_processor(const unsigned int proc) const
-  { assert(proc < _first_df.size()); return (_end_df[proc] - _first_df[proc]); }
+  { libmesh_assert(proc < _first_df.size()); return (_end_df[proc] - _first_df[proc]); }
 
   /**
    * Returns the first dof index that is local to subdomain \p proc.
    */
   unsigned int first_dof(const unsigned int proc = libMesh::processor_id()) const
-  { assert(proc < _first_df.size()); return _first_df[proc]; }
+  { libmesh_assert(proc < _first_df.size()); return _first_df[proc]; }
   
   /**
    * Returns the last dof index that is local to subdomain \p proc.
@@ -251,14 +353,14 @@ public:
    * case where \p proc has no local dof indices.  Use end_dof() instead.
    */
   unsigned int last_dof(const unsigned int proc = libMesh::processor_id()) const
-  { assert(proc < _end_df.size()); return (_end_df[proc] - 1); }  
+  { libmesh_assert(proc < _end_df.size()); return (_end_df[proc] - 1); }  
 
   /**
    * Returns the first dof index that is after all indices local to subdomain \p proc.
    * Analogous to the end() member function of STL containers.
    */
   unsigned int end_dof(const unsigned int proc = libMesh::processor_id()) const
-  { assert(proc < _end_df.size()); return _end_df[proc]; }  
+  { libmesh_assert(proc < _end_df.size()); return _end_df[proc]; }  
   
   /**
    * Fills the vector \p di with the global degree of freedom indices
@@ -299,6 +401,11 @@ public:
    */ 
   void create_dof_constraints (const MeshBase& mesh);
 
+  /**
+   * Gathers any relevant constraint equations from other processors
+   */
+  void allgather_recursive_constraints ();
+
   /**
    * Postprocesses any constrained degrees of freedom in elem_dofs
    * to be constrained only in terms of unconstrained dofs.
@@ -490,38 +597,66 @@ private:
    * @returns the number of the system we are responsible for.
    */
   unsigned int sys_number() const;
+
+  /**
+   * @invalidates all active DofObject dofs for this system
+   */
+  void invalidate_dofs(MeshBase& mesh) const;
+
+  /**
+   * An adapter function that returns Node pointers by index
+   */
+  DofObject* node_ptr(MeshBase& mesh, unsigned int i) const;
+
+  /**
+   * An adapter function that returns Elem pointers by index
+   */
+  DofObject* elem_ptr(MeshBase& mesh, unsigned int i) const;
+
+  /**
+   * A member function type like node_ptr or elem_ptr
+   */
+  typedef DofObject* (DofMap::*dofobject_accessor)
+    (MeshBase& mesh, unsigned int i) const;
   
   /**
-   * Distributes the global degrees of freedom in a 
-   * variable-major ordering.  In this format the local
+   * Helper function for distributing dofs in parallel
+   */
+  template<typename iterator_type>
+  void set_nonlocal_dof_objects(iterator_type objects_begin,
+			        iterator_type objects_end,
+			        MeshBase &mesh,
+			        dofobject_accessor objects);
+
+  /**
+   * Distributes the global degrees of freedom, for dofs on
+   * this processor.  In this format the local
    * degrees of freedom are in a contiguous block for each
    * variable in the system.
+   * Starts at index next_free_dof, and increments it to
+   * the post-final index.
+   * If build_send_list is true, builds the send list.  If
+   * false, clears and reserves the send list
    */  
-  void distribute_dofs_var_major (MeshBase&);
+  void distribute_local_dofs_var_major (unsigned int& next_free_dof,
+				        MeshBase& mesh,
+				        const bool build_send_list);
   
   /**
-   * Distributes the global degrees of freedom in a 
-   * node/element-major ordering.  In this format all the 
+   * Distributes the global degrees of freedom, for dofs on
+   * this processor.  In this format all the 
    * degrees of freedom at a node/element are in contiguous 
    * blocks.  Note in particular that the degrees of freedom
    * for a given variable are not in contiguous blocks, as 
-   * in the case of \p distribute_dofs_var_major.
+   * in the case of \p distribute_local_dofs_var_major.
+   * Starts at index next_free_dof, and increments it to
+   * the post-final index.
+   * If build_send_list is true, builds the send list.  If
+   * false, clears and reserves the send list
    */  
-  void distribute_dofs_node_major (MeshBase&);
-
-  /**
-   * Splices the two sorted ranges [begin,middle) and [middle,end)
-   * into one sorted range [begin,end).  This method is much like
-   * std::inplace_merge except it assumes the intersection
-   * of the two sorted ranges is empty and that any element in
-   * each range occurs only once in that range.  Additionally,
-   * this sort occurs in-place, while std::inplace_merge may
-   * use a temporary buffer.
-   */ 
-  template<typename BidirectionalIterator>
-  void sort_sparsity_row (const BidirectionalIterator begin,
-			  BidirectionalIterator       middle,
-			  const BidirectionalIterator end);
+  void distribute_local_dofs_node_major (unsigned int& next_free_dof,
+				         MeshBase& mesh,
+				         const bool build_send_list);
     
   /**
    * Adds entries to the \p _send_list vector corresponding to DoFs
@@ -557,7 +692,7 @@ private:
    * Finds all the DOFS associated with the element DOFs elem_dofs.
    * This will account for off-element couplings via hanging nodes.
    */
-  void find_connected_dofs (std::vector<unsigned int>& elem_dofs) const;
+  void find_connected_dofs (std::vector<unsigned int> &elem_dofs) const;
   
 #endif
 
@@ -640,15 +775,7 @@ private:
   PeriodicBoundaries _periodic_boundaries;
 #endif
 
-
-#if defined(__GNUC__) && (__GNUC__ < 4) && !defined(__INTEL_COMPILER)
-  /**
-   * Dummy function that does nothing but can be used to prohibit
-   * compiler optimization in some situations where some compilers
-   * have optimization bugs.
-   */
-  static void _dummy_function(void);
-#endif
+  friend class SparsityPattern::Build;
 };
 
 
@@ -705,18 +832,20 @@ unsigned int DofMap::sys_number() const
 
 
 
+// ------------------------------------------------------------
+// SparsityPattern inline member functions
 template<typename BidirectionalIterator>
 inline
-void DofMap::sort_sparsity_row (const BidirectionalIterator begin,
+void SparsityPattern::sort_row (const BidirectionalIterator begin,
 				BidirectionalIterator       middle,
 				const BidirectionalIterator end)
 {
   if ((begin == middle) || (middle == end)) return;
 
-  assert (std::distance (begin,  middle) > 0);
-  assert (std::distance (middle, end)    > 0);
-  assert (std::unique (begin,  middle) == middle);
-  assert (std::unique (middle, end)    == end);
+  libmesh_assert (std::distance (begin,  middle) > 0);
+  libmesh_assert (std::distance (middle, end)    > 0);
+  libmesh_assert (std::unique (begin,  middle) == middle);
+  libmesh_assert (std::unique (middle, end)    == end);
   
   while (middle != end)
     {
@@ -732,7 +861,7 @@ void DofMap::sort_sparsity_row (const BidirectionalIterator begin,
 #if defined(__GNUC__) && (__GNUC__ < 4) && !defined(__INTEL_COMPILER)
 	  /* Prohibit optimization at this point since gcc 3.3.5 seems
 	     to have a bug.  */
-	  this->_dummy_function();
+	  SparsityPattern::_dummy_function();
 #endif
 
 	  if (a == begin) break;
@@ -748,7 +877,7 @@ void DofMap::sort_sparsity_row (const BidirectionalIterator begin,
 #ifdef DEBUG
   {
     // SGI STL extension!
-    // assert (std::is_sorted(begin,end));
+    // libmesh_assert (std::is_sorted(begin,end));
     
     BidirectionalIterator
       prev  = begin,
@@ -756,18 +885,17 @@ void DofMap::sort_sparsity_row (const BidirectionalIterator begin,
 
     for (++first; first != end; prev=first, ++first)
       if (*first < *prev)
-	assert(false);
+	libmesh_assert(false);
   }  
 #endif
 
   // Make sure the two ranges did not contain any common elements
-  assert (std::unique (begin, end) == end);
+  libmesh_assert (std::unique (begin, end) == end);
 }
 
 
 // ------------------------------------------------------------
 // PeriodicBoundary inline member functions
-
 #ifdef ENABLE_PERIODIC
 
 inline
