@@ -1,4 +1,4 @@
-// $Id: dof_object.h,v 1.14 2007-10-21 20:48:40 benkirk Exp $
+// $Id: dof_object.h 2973 2008-08-11 21:31:19Z benkirk $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -43,15 +43,11 @@ class DofObject;
  *
  * This class is intended to be extremely lightweight.  To help acheive
  * this goal no \p std::vector<> or anything else that might be heavy
- * is used to store the degree of freedom indices.  If the library is
- * configured with \p --enable-expensive then there can be multiple
- * components in any variable, if the library is configured with
- * \p --disable-expensive then there can be at MOST one component
- * per variable, i.e n_comp(sys,var) <= 1.
- *
+ * is used to store the degree of freedom indices.
+ * 
  * \author Benjamin S. Kirk
  * \date 2003
- * \version $Revision: 1.14 $
+ * \version $Revision: 2973 $
  */
 
 class DofObject : public ReferenceCountedObject<DofObject>
@@ -241,12 +237,18 @@ public:
 		      const unsigned int var,
 		      const unsigned int comp,
 		      const unsigned int dn);
+
+  /**
+   * @returns true if any system has variables which have been assigned,
+   * false otherwise
+   */
+  bool has_dofs(const unsigned int s=libMesh::invalid_uint) const;
   
   /**
    * Implemented in Elem and Node.
    */
   virtual bool operator==(const DofObject& ) const
-  { error(); return false; }
+  { libmesh_error(); return false; }
 
   
   /**
@@ -284,20 +286,16 @@ private:
    * The number of systems.
    */
   unsigned char _n_systems;
-  
-  /**
-   * The number of variables associated with this
-   * \p DofObject.  This is stored as an unsigned char
-   * for storage efficiency.
-   */
-  unsigned char *_n_vars;
 
   /**
-   * The number of components for each variable of each system
+   * The number of variables and components for each variable of each system
    * associated with this \p DofObject.  This is stored as an
    * unsigned char for storage efficiency.
+   *
+   * _n_v_comp[s][0]   = # of variables in system s
+   * _n_v_comp[s][v+1] = # of components for variable v in system s.
    */
-  unsigned char **_n_comp;
+  unsigned char **_n_v_comp;
 
   /**
    * The first global degree of freedom number
@@ -318,8 +316,7 @@ DofObject::DofObject () :
   _id (invalid_id),
   _processor_id (invalid_processor_id),
   _n_systems  (0),
-  _n_vars (NULL),
-  _n_comp (NULL),
+  _n_v_comp (NULL),
   _dof_ids (NULL)
 {
   this->invalidate();
@@ -344,20 +341,19 @@ DofObject::~DofObject ()
 inline
 void DofObject::invalidate_dofs (const unsigned int sys_num)
 {
-  // FIXME - this should no longer need to loop over c - RHS
-
   // If the user does not specify the system number...
   if (sys_num >= this->n_systems()) 
-    for (unsigned int s=0; s<n_systems(); s++)
-      for (unsigned int v=0; v<n_vars(s); v++)
-	for (unsigned int c=0; c<n_comp(s,v); c++)
-	  this->set_dof_number(s,v,c,invalid_id);
-
+    {
+      for (unsigned int s=0; s<this->n_systems(); s++)
+        for (unsigned int v=0; v<this->n_vars(s); v++)
+	  if (this->n_comp(s,v))
+	    this->set_dof_number(s,v,0,invalid_id);
+    }
   // ...otherwise invalidate the dofs for all systems
   else
     for (unsigned int v=0; v<n_vars(sys_num); v++)
-      for (unsigned int c=0; c<n_comp(sys_num,v); c++)
-	this->set_dof_number(sys_num,v,c,invalid_id);
+      if (this->n_comp(sys_num,v))
+        this->set_dof_number(sys_num,v,0,invalid_id);
 }
 
 
@@ -394,23 +390,30 @@ void DofObject::clear_dofs ()
   // Only clear if there is data
   if (this->n_systems() != 0)
     {
-      for (unsigned int s=0; s<this->n_systems(); s++)
-	if (this->n_vars(s) != 0) // This has only been allocated if 
-	  {                       // variables were declared
-	    assert (_dof_ids[s] != NULL); delete [] _dof_ids[s]; _dof_ids[s] = NULL;
-	    assert (_n_comp[s]  != NULL); delete [] _n_comp[s];  _n_comp[s]  = NULL;
-	  }
+      libmesh_assert (_n_v_comp != NULL);
+      libmesh_assert (_dof_ids  != NULL);
       
-      assert (_n_vars  != NULL); delete [] _n_vars;  _n_vars  = NULL; 
-      assert (_n_comp  != NULL); delete [] _n_comp;  _n_comp  = NULL;
-      assert (_dof_ids != NULL); delete [] _dof_ids; _dof_ids = NULL;
+      for (unsigned int s=0; s<this->n_systems(); s++)
+	{
+	  if (_dof_ids[s] != NULL) // This has only been allocated if 
+	    {                      // variables were declared
+	      delete [] _dof_ids[s]; _dof_ids[s] = NULL;
+	    }
+	  
+	  if (_n_v_comp[s] != NULL) // it is possible the number of variables is 0,
+	    {                       // but this was allocated (_n_v_comp[s][0] == 0)
+	      delete [] _n_v_comp[s]; _n_v_comp[s] = NULL;
+	    }
+	}
+      
+      delete [] _n_v_comp; _n_v_comp = NULL;
+      delete [] _dof_ids;  _dof_ids  = NULL;
     }
   
   // Make sure we cleaned up
   // (or there was nothing there)
-  assert (_n_vars  == NULL);
-  assert (_n_comp  == NULL);
-  assert (_dof_ids == NULL);
+  libmesh_assert (_n_v_comp == NULL);
+  libmesh_assert (_dof_ids  == NULL);
   
   // No systems now.
   _n_systems = 0;
@@ -422,7 +425,7 @@ inline
 unsigned int DofObject::n_dofs (const unsigned int s,
 				const unsigned int var) const
 {
-  assert (s < this->n_systems());
+  libmesh_assert (s < this->n_systems());
   
   unsigned int num = 0;
 
@@ -445,7 +448,7 @@ unsigned int DofObject::n_dofs (const unsigned int s,
 inline
 unsigned int DofObject::id () const
 {
-  assert (this->valid_id());
+  libmesh_assert (this->valid_id());
   return _id;
 }
 
@@ -469,7 +472,6 @@ bool DofObject::valid_id () const
 inline
 unsigned short int DofObject::processor_id () const
 {
-  assert (this->valid_processor_id());
   return _processor_id;
 }
 
@@ -493,7 +495,7 @@ void DofObject::processor_id (const unsigned int id)
       std::cerr << "ERROR: id too large for unsigned short int!" << std::endl
 		<< "Recompile with DofObject::_processor_id larger!" << std::endl;
       
-      error();
+      libmesh_error();
     }
 
 #endif
@@ -522,23 +524,25 @@ unsigned int DofObject::n_systems () const
 inline
 unsigned int DofObject::n_vars(const unsigned int s) const
 {
-  assert (s < this->n_systems());
-  assert (_n_vars != NULL);
-  
-  return static_cast<unsigned int>(_n_vars[s]);
+  libmesh_assert (s < this->n_systems());
+  libmesh_assert (_n_v_comp != NULL);
+  if (_n_v_comp[s] == NULL)
+    return 0;
+  return static_cast<unsigned int>(_n_v_comp[s][0]);
 }
 
 
 
+
 inline
 unsigned int DofObject::n_comp(const unsigned int s,
 			       const unsigned int var) const
 {
-  assert (s < this->n_systems());
-  assert (_dof_ids != NULL);
-  assert (_dof_ids[s] != NULL);
-  assert (_n_comp != NULL);
-  assert (_n_comp[s] != NULL);
+  libmesh_assert (s < this->n_systems());
+  libmesh_assert (_dof_ids != NULL);
+  libmesh_assert (_dof_ids[s] != NULL);
+  libmesh_assert (_n_v_comp != NULL);
+  libmesh_assert (_n_v_comp[s] != NULL);
 
 # ifdef DEBUG
   // Does this ever happen?  I doubt it... 3/7/2003 (BSK)
@@ -553,7 +557,7 @@ unsigned int DofObject::n_comp(const unsigned int s,
     }
 # endif
   
-  return static_cast<unsigned int>(_n_comp[s][var]);
+  return static_cast<unsigned int>(_n_v_comp[s][var+1]);
 }
 
 
@@ -563,17 +567,40 @@ unsigned int DofObject::dof_number(const unsigned int s,
 				   const unsigned int var,
 				   const unsigned int comp) const
 {
-  assert (s < this->n_systems());
-  assert (var  < this->n_vars(s));
-  assert (_dof_ids != NULL);
-  assert (_dof_ids[s] != NULL);  
-  assert (comp < this->n_comp(s,var));
+  libmesh_assert (s < this->n_systems());
+  libmesh_assert (var  < this->n_vars(s));
+  libmesh_assert (_dof_ids != NULL);
+  libmesh_assert (_dof_ids[s] != NULL);  
+  libmesh_assert (comp < this->n_comp(s,var));
   
   if (_dof_ids[s][var] == invalid_id)
     return invalid_id;
   else
     return (_dof_ids[s][var] + comp);
 }
+
+
+
+inline
+bool DofObject::has_dofs (const unsigned int sys) const
+{
+  if (sys == libMesh::invalid_uint)
+    {
+      for (unsigned int s=0; s<this->n_systems(); s++)
+	if (this->n_vars(s))
+	  return true;
+    }
+  
+  else
+    {
+      libmesh_assert (sys < this->n_systems());
+
+      if (this->n_vars(sys))
+	return true;
+    }
+  
+  return false;
+}
   
 
 
