@@ -1,4 +1,4 @@
-// $Id: factory.h,v 1.9 2007-10-21 20:48:40 benkirk Exp $
+// $Id: factory.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -112,7 +112,7 @@ Factory<Base>::Factory (const std::string& name)
 {
   // Make sure we haven't already added this name
   // to the map
-  assert (!factory_map().count(name));
+  libmesh_assert (!factory_map().count(name));
 
   factory_map()[name] = this;
 }
@@ -134,7 +134,7 @@ AutoPtr<Base> Factory<Base>::build (const std::string& name)
 	     it = factory_map().begin(); it != factory_map().end(); ++it)
         std::cerr << "  " << it->first << std::endl;
 
-      error();
+      libmesh_error();
       
       // Do this the stoopid way for IBM xlC
       AutoPtr<Base> ret_val (NULL);
