@@ -1,4 +1,4 @@
-// $Id: getpot.h,v 1.10 2005-09-30 19:59:35 benkirk Exp $
+// $Id: getpot.h 2946 2008-07-30 22:09:25Z jwpeterson $
 //
 // (with patches from Michael Anderson for more general variable types)
 
@@ -92,6 +92,7 @@ class GetPot {
   inline bool         operator()(const char* VarName, bool        Default) const;
   inline int          operator()(const char* VarName, int         Default) const;
   inline double       operator()(const char* VarName, double      Default) const;
+  inline long double  operator()(const char* VarName, long double Default) const;
   inline const char*  operator()(const char* VarName, const char* Default) const;
   inline std::string  operator()(const char* VarName, const std::string& Default) const;
   //     -- vectors
@@ -240,6 +241,7 @@ class GetPot {
   //        * type conversion if possible     
   inline int      __convert_to_type(const std::string& String, int Default) const;
   inline double   __convert_to_type(const std::string& String, double Default) const;
+  inline long double   __convert_to_type(const std::string& String, long double Default) const;
   inline bool     __convert_to_type(const std::string& String, bool Default) const;
 
   //        * prefix extraction
@@ -703,6 +705,17 @@ GetPot::__convert_to_type(const std::string& String, double Default) const
 
 
 
+// convert string to LONG DOUBLE, if not possible return Default
+inline long double   
+GetPot::__convert_to_type(const std::string& String, long double Default) const
+{
+  long double tmp;
+  if( std::sscanf(String.c_str(),"%Lf", &tmp) != 1 ) return Default;
+  return tmp;
+}
+
+
+
 // convert string to INT, if not possible return Default
 inline int   
 GetPot::__convert_to_type(const std::string& String, int Default) const
@@ -1224,6 +1237,16 @@ GetPot::operator()(const char* VarName, double Default) const
 
 
 
+inline long double
+GetPot::operator()(const char* VarName, long double Default) const
+{
+  const variable*  sv = __find_variable(VarName);
+  if( sv == 0 ) return Default;
+  return __convert_to_type(sv->original, Default);
+}
+
+
+
 inline const char*
 GetPot::operator()(const char* VarName, const char* Default) const
 {
