@@ -1,4 +1,4 @@
-// $Id: libmesh_base.h,v 1.5 2007-10-21 20:48:40 benkirk Exp $
+// $Id: libmesh_base.h 2672 2008-02-17 00:31:13Z benkirk $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -36,6 +36,10 @@ namespace libMesh {
    */
   unsigned int processor_id();
 
+  /**
+   * @returns the maximum number of threads used in the simulation.
+   */
+  unsigned int n_threads();
 
   /**
    * Namespaces don't provide private data,
@@ -54,6 +58,11 @@ namespace libMesh {
      * The local processor id.
      */
     extern int _processor_id;
+    
+    /**
+     * Total number of threads possible.
+     */
+    extern int _n_threads;
   }
 }
 
@@ -77,4 +86,13 @@ unsigned int libMesh::processor_id()
 
 
 
+
+inline
+unsigned int libMesh::n_threads()
+{
+  return static_cast<unsigned int>(libMeshPrivateData::_n_threads);
+}
+
+
+
 #endif // #define __libmesh_base_h__
