@@ -1,4 +1,4 @@
-// $Id: libmesh_common.h,v 1.22 2007-10-21 20:48:40 benkirk Exp $
+// $Id: libmesh_common.h 2802 2008-04-23 19:59:24Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -26,21 +26,28 @@
 // The library configuration options
 #include "libmesh_config.h"
 
-// C/C++ includes everyone should know about
-#include <iostream> // needed for std::cout, std::cerr
-#include <complex>
-#include <cassert>
-#ifdef HAVE_STDLIB_H
-# include <cstdlib>
-#endif
-
 // Include the MPI definition
 #ifdef HAVE_MPI
 # include <mpi.h>
 #endif
 
+// C/C++ includes everyone should know about
+#include <iostream> // needed for std::cout, std::cerr
+#include <fstream> // needed for argument to print_trace()
+#include <unistd.h>  // needed for getpid()
+#include <complex>
+// #include <cassert>  // Use libmesh_assert() now
+#ifdef HAVE_STDLIB_H
+# include <cstdlib>
+#endif
+
 // _basic_ library functionality
 #include "libmesh_base.h"
+#include "libmesh_exceptions.h"
+
+#ifdef ENABLE_TRACEFILES
+#  include "print_trace.h"
+#endif
 
 
 
@@ -140,6 +147,18 @@ typedef std::complex<double> Complex;
 typedef std::complex<double> COMPLEX;
 
 
+// Helper functions for complex/real numbers
+// to clean up #ifdef USE_COMPLEX_NUMBERS elsewhere
+template<typename T> inline T libmesh_real(T a) { return a; }
+template<typename T> inline T libmesh_norm(T a) { return a*a; }
+
+template<typename T>
+inline T libmesh_real(std::complex<T> a) { return std::real(a); }
+
+template<typename T>
+inline T libmesh_norm(std::complex<T> a) { return std::norm(a); }
+
+
 // Define the value type for unknowns in simulations.
 // This is either Real or Complex, depending on how
 // the library was configures
@@ -173,7 +192,7 @@ namespace libMesh
 // If you want to make sure you are accessing a section of code just
 // stick a here(); in it, for example
 #undef here
-#define here()     { std::cout << "[" << libMesh::processor_id() << "] " << __FILE__ << ", line " << __LINE__ << ", compiled " << __DATE__ << " at " << __TIME__ << std::endl; }
+#define here()     do { std::cerr << "[" << libMesh::processor_id() << "] " << __FILE__ << ", line " << __LINE__ << ", compiled " << __DATE__ << " at " << __TIME__ << std::endl; } while (0)
 
 // the stop() macro will stop the code until a SIGCONT signal is recieved.  This is useful, for example, when
 // determining the memory used by a given operation.  A stop() could be instered before and after a questionable
@@ -181,28 +200,42 @@ namespace libMesh
 #undef stop
 #ifdef HAVE_CSIGNAL
 #  include <csignal>
-#  define stop()     { if (libMesh::n_processors() == 1) { here(); std::cout << "Stopping process " << getpid() << "..." << std::endl; std::raise(SIGSTOP); std::cout << "Continuing process " << getpid() << "..." << std::endl; } }
+#  define stop()     do { if (libMesh::n_processors() == 1) { here(); std::cout << "Stopping process " << getpid() << "..." << std::endl; std::raise(SIGSTOP); std::cout << "Continuing process " << getpid() << "..." << std::endl; } } while(0)
 #else
-#  define stop()     { if (libMesh::n_processors() == 1) { here(); std::cerr << "WARNING:  stop() does not work without the <csignal> header file!" << std::endl; } }
+#  define stop()     do { if (libMesh::n_processors() == 1) { here(); std::cerr << "WARNING:  stop() does not work without the <csignal> header file!" << std::endl; } } while(0)
 #endif
 
+// The libmesh_assert() macro acts like C's assert(), but throws a 
+// libmesh_error() (including stack trace, etc) instead of just exiting
+#ifdef NDEBUG
+#define libmesh_assert(asserted) 
+#else
+#define libmesh_assert(asserted)  do { if (!(asserted)) { std::cerr << "Assertion `" #asserted "' failed." << std::endl; libmesh_error(); } } while(0)
+#endif
 
-// The error() macro prints a message and aborts the code
+// The libmesh_error() macro prints a message and throws a generic exception
+#ifdef ENABLE_TRACEFILES
+#define libmesh_error()    do { std::stringstream outname; outname << "traceout_" << libMesh::processor_id() << '_' << getpid() << ".txt"; std::ofstream traceout(outname.str().c_str()); print_trace(traceout); std::cerr << "[" << libMesh::processor_id() << "] " << __FILE__ << ", line " << __LINE__ << ", compiled " << __DATE__ << " at " << __TIME__ << std::endl; LIBMESH_THROW(libMesh::LogicError()); } while(0)
+#else
+#define libmesh_error()    do { std::cerr << "[" << libMesh::processor_id() << "] " << __FILE__ << ", line " << __LINE__ << ", compiled " << __DATE__ << " at " << __TIME__ << std::endl; LIBMESH_THROW(libMesh::LogicError()); } while(0)
+#endif
+
+// The error() macro prints a message and throws a generic exception
+// Use libmesh_error() instead; error() is deprecated to avoid namespace
+// conflicts
 #undef error
-#ifdef HAVE_MPI
-#  define error()    { std::cerr << "[" << libMesh::processor_id() << "] " << __FILE__ << ", line " << __LINE__ << ", compiled " << __DATE__ << " at " << __TIME__ << std::endl; if (libMesh::n_processors() > 1) MPI_Abort(libMesh::COMM_WORLD,1); std::abort(); }
-#else
-#  define error()    { std::cerr << "[" << libMesh::processor_id() << "] " << __FILE__ << ", line " << __LINE__ << ", compiled " << __DATE__ << " at " << __TIME__ << std::endl; std::abort(); }
-#endif
+#define error()    do { \
+std::cout << "error() is deprecated; use libmesh_error() instead!" \
+          << std::endl; libmesh_error(); } while(0)
 
 // The untested macro warns that you are using untested code
 #undef untested
-#define untested() { std::cout << "*** Warning, This code is untested, experimental, or likely to see future API changes: " << __FILE__ << ", line " << __LINE__ << ", compiled " << __DATE__ << " at " << __TIME__ << " ***" << std::endl; }
+#define untested() do { std::cout << "*** Warning, This code is untested, experimental, or likely to see future API changes: " << __FILE__ << ", line " << __LINE__ << ", compiled " << __DATE__ << " at " << __TIME__ << " ***" << std::endl; } while (0)
 
 
 // The deprecated macro warns that you are using deprecated code
 #undef deprecated
-#define deprecated() { std::cout << "*** Warning, This Code is Deprecated! " << __FILE__ << ", line " << __LINE__ << ", compiled " << __DATE__ << " at " << __TIME__ << " ***" << std::endl; }
+#define deprecated() do { std::cout << "*** Warning, This Code is Deprecated! " << __FILE__ << ", line " << __LINE__ << ", compiled " << __DATE__ << " at " << __TIME__ << " ***" << std::endl; } while(0)
 
 
 
