@@ -1,4 +1,4 @@
-// $Id: libmesh_logging.h,v 1.5 2007-10-21 20:48:40 benkirk Exp $
+// $Id: libmesh_logging.h 2752 2008-03-05 19:29:28Z benkirk $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -34,10 +34,10 @@
 
 // Note the log is in libMesh, so we need to include it.
 #  include "libmesh.h"
-#  define START_LOG(a,b)   { libMesh::perflog.start_event(a,b); }
-#  define STOP_LOG(a,b)    { libMesh::perflog.stop_event(a,b); }
-#  define PAUSE_LOG(a,b)   { libMesh::perflog.pause_event(a,b); }
-#  define RESTART_LOG(a,b) { libMesh::perflog.restart_event(a,b); }
+#  define START_LOG(a,b)   { libMesh::perflog.push(a,b); }
+#  define STOP_LOG(a,b)    { libMesh::perflog.pop(a,b); }
+#  define PAUSE_LOG(a,b)   { deprecated(); }
+#  define RESTART_LOG(a,b) { deprecated{}; }
 
 #else
 
