@@ -1,4 +1,4 @@
-// $Id: multi_predicates.h,v 1.10 2007-10-21 20:48:40 benkirk Exp $
+// $Id: multi_predicates.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -71,7 +71,7 @@ namespace Predicates
 	{
 	  const predicate<T>* pred = _predicates[i];
 
-	  assert (pred != NULL);
+	  libmesh_assert (pred != NULL);
 	  
 	  if ( ! (*pred)(it) )
 	    return false;
@@ -166,6 +166,36 @@ namespace Predicates
 
   
 
+  // Instantiation for the Ancestor abstract_multi_predicate
+  template <typename T>
+  struct Ancestor : abstract_multi_predicate<T>
+  {
+    // Constructor, pushes back two single predicates
+    Ancestor()
+    {
+      this->_predicates.push_back(new not_null<T>);
+      this->_predicates.push_back(new ancestor<T>);
+    }
+  };
+
+
+  
+
+  // Instantiation for the NotAncestor abstract_multi_predicate
+  template <typename T>
+  struct NotAncestor : abstract_multi_predicate<T>
+  {
+    // Constructor, pushes back two single predicates
+    NotAncestor()
+    {
+      this->_predicates.push_back(new not_null<T>);
+      this->_predicates.push_back(new not_ancestor<T>);
+    }
+  };
+
+
+
+  
   // Instantiation for the SubActive abstract_multi_predicate
   template <typename T>
   struct SubActive : abstract_multi_predicate<T>
@@ -351,6 +381,36 @@ namespace Predicates
 
 
 
+
+  // Instantiation for the LocalLevel abstract_multi_predicate
+  template <typename T>
+  struct LocalLevel : abstract_multi_predicate<T>
+  {
+    LocalLevel(const unsigned int l)
+    {
+      this->_predicates.push_back(new not_null<T>);
+      this->_predicates.push_back(new pid<T>(libMesh::processor_id()));
+      this->_predicates.push_back(new level<T>(l));
+    }
+  };
+
+
+
+
+  // Instantiation for the LocalNotLevel abstract_multi_predicate
+  template <typename T>
+  struct LocalNotLevel : abstract_multi_predicate<T>
+  {
+    LocalNotLevel(const unsigned int l)
+    {
+      this->_predicates.push_back(new not_null<T>);
+      this->_predicates.push_back(new pid<T>(libMesh::processor_id()));
+      this->_predicates.push_back(new not_level<T>(l));
+    }
+  };
+
+
+
   // Instantiation for the ActiveOnBoundary abstract_multi_predicate
   template <typename T>
   struct ActiveOnBoundary : abstract_multi_predicate<T>
