@@ -1,4 +1,4 @@
- // $Id: reference_counter.h,v 1.7 2007-10-21 20:48:40 benkirk Exp $
+ // $Id: reference_counter.h 2652 2008-02-07 21:41:59Z benkirk $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -24,7 +24,7 @@
 
 // Local includes
 #include "libmesh_config.h"
-
+#include "threads.h"
 
 // C++ includes
 #include <string>
@@ -115,7 +115,12 @@ protected:
    * The number of objects.  Print the reference count
    * information when the number returns to 0.
    */
-  static unsigned int _n_objects;
+  static Threads::atomic<unsigned int> _n_objects;
+
+  /**
+   * Mutual exclusion object to enable thread-safe reference counting.
+   */
+  static Threads::spin_mutex _mutex;
 };
 
 
@@ -143,6 +148,7 @@ inline ReferenceCounter::~ReferenceCounter()
 inline
 void ReferenceCounter::increment_constructor_count (const std::string& name)
 {
+  Threads::spin_mutex::scoped_lock lock(Threads::spin_mtx);
   std::pair<unsigned int, unsigned int>& p = _counts[name];
 
   p.first++;
@@ -160,6 +166,7 @@ void ReferenceCounter::increment_constructor_count (const std::string&)
 inline
 void ReferenceCounter::increment_destructor_count (const std::string& name)
 {
+  Threads::spin_mutex::scoped_lock lock(Threads::spin_mtx);
   std::pair<unsigned int, unsigned int>& p = _counts[name];
 
   p.second++;
