@@ -1,4 +1,4 @@
-// $Id: single_predicates.h,v 1.6 2007-10-21 20:48:40 benkirk Exp $
+// $Id: single_predicates.h 2783 2008-04-12 21:58:11Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -100,6 +100,28 @@ namespace Predicates
   };
 
 
+  // The ancestor predicate returns true if the pointer is ancestor.
+  template <typename T>
+  struct ancestor : predicate<T>
+  {
+    virtual ~ancestor() {}
+    virtual bool operator()(const T& it) const { return (*it)->ancestor(); }
+    
+  protected:
+    virtual predicate<T>* clone() const { return new ancestor<T>(*this); }
+  };
+
+  // The not_ancestor predicate returns true when the pointer is not ancestor
+  template <typename T>
+  struct not_ancestor : ancestor<T>
+  {
+    virtual bool operator()(const T& it) const { return !ancestor<T>::operator()(it); }
+
+  protected:
+    virtual predicate<T>* clone() const { return new not_ancestor<T>(*this); }
+  };
+
+
   // The subactive predicate returns true if the pointer is subactive.
   template <typename T>
   struct subactive : predicate<T>
