@@ -1,4 +1,4 @@
-// $Id: variant_filter_iterator.h,v 1.12 2007-10-21 20:48:40 benkirk Exp $
+// $Id: variant_filter_iterator.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -25,7 +25,6 @@
 #include <iterator>
 #include <algorithm> // for std::swap
 #include <cstdlib>   // for std::abort()
-#include <assert.h>
 
 #if defined(__GNUC__) && (__GNUC__ < 3)  && !defined(__INTEL_COMPILER)
 #include <typeinfo>
@@ -285,7 +284,7 @@ public:
      */
     virtual bool operator() (const IterBase* in) const
     {
-      assert (in != NULL);
+      libmesh_assert (in != NULL);
       
       // Attempt downcast
 #if defined(__SUNPRO_CC) || (defined(__GNUC__) && (__GNUC__ < 3)  && !defined(__INTEL_COMPILER))
