@@ -1,4 +1,4 @@
-// $Id: enum_elem_type.h,v 1.6 2007-10-21 20:48:40 benkirk Exp $
+// $Id: enum_elem_type.h 2575 2007-12-06 20:36:07Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -71,8 +71,10 @@ namespace libMeshEnums {
 		 INFPRISM12, // 24
 
 		 NODEELEM,   // 25
+
+		 REMOTEELEM,   // 26
 		 
-		 INVALID_ELEM};
+		 INVALID_ELEM};  // 27 - should always be last
 }
 
 using namespace libMeshEnums;
