@@ -1,4 +1,4 @@
-// $Id: enum_fe_family.h,v 1.11 2007-10-21 20:48:40 benkirk Exp $
+// $Id: enum_fe_family.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -58,7 +58,7 @@ namespace libMeshEnums {
 
   /**
    * \enum libMeshEnums::FEContinuity defines an \p enum for finite element
-   * types to assert a certain level (or type? Hcurl?) of continuity.  
+   * types to libmesh_assert a certain level (or type? Hcurl?) of continuity.  
    */
   enum FEContinuity {DISCONTINUOUS,
                      C_ZERO,
@@ -67,7 +67,7 @@ namespace libMeshEnums {
 
 using namespace libMeshEnums;
 
-#endif // #ifndef __fe_type_h__
+#endif // #ifndef __enum_fe_family_h__
 
 
 
