@@ -1,4 +1,4 @@
-// $Id: enum_quadrature_type.h,v 1.6 2007-10-21 20:48:41 benkirk Exp $
+// $Id: enum_quadrature_type.h 2929 2008-07-14 15:24:52Z jwpeterson $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -29,18 +29,20 @@ namespace libMeshEnums {
   /**
    * Defines an \p enum for currently available quadrature rules.
    */
-  enum QuadratureType {QGAUSS      = 0,
+  enum QuadratureType {QGAUSS            = 0,
+				         
+		       QJACOBI_1_0       = 1,
+		       QJACOBI_2_0       = 2,
+				         
+		       QSIMPSON          = 3,
+		       QTRAP             = 4,
+		       QGRID             = 5,
+		       QGRUNDMANN_MOLLER = 6,
+		       QMONOMIAL         = 7,
 
-		       QJACOBI_1_0 = 1,
-		       QJACOBI_2_0 = 2,
+		       QCLOUGH           = 21,
 
-		       QSIMPSON    = 3,
-		       QTRAP       = 4,
-		       QGRID       = 5,
-
-		       QCLOUGH     = 21,
-
-		       INVALID_Q_RULE = 127};
+		       INVALID_Q_RULE    = 127};
 }
 
 using namespace libMeshEnums;
