@@ -1,4 +1,4 @@
-// $Id: fe.h,v 1.30 2007-10-21 20:48:41 benkirk Exp $
+// $Id: fe.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -56,7 +56,7 @@ class InfFE;
  *
  * \author Benjamin S. Kirk
  * \date 2002-2007
- * \version $Revision: 1.30 $
+ * \version $Revision: 2789 $
  */
 
 //-------------------------------------------------------------
@@ -445,7 +445,7 @@ protected:
  *
  * \author Roy Stogner
  * \date 2004
- * \version $Revision: 1.30 $
+ * \version $Revision: 2789 $
  */
 
 //-------------------------------------------------------------
@@ -470,7 +470,7 @@ public:
  *
  * \author Roy Stogner
  * \date 2005
- * \version $Revision: 1.30 $
+ * \version $Revision: 2789 $
  */
 
 //-------------------------------------------------------------
@@ -505,7 +505,7 @@ public:
  *
  * \author Benjamin S. Kirk
  * \date 2002-2007
- * \version $Revision: 1.30 $
+ * \version $Revision: 2789 $
  */
 
 //-------------------------------------------------------------
@@ -530,7 +530,7 @@ public:
  *
  * \author Benjamin S. Kirk
  * \date 2002-2007
- * \version $Revision: 1.30 $
+ * \version $Revision: 2789 $
  */
 
 //-------------------------------------------------------------
@@ -555,7 +555,7 @@ public:
  *
  * \author Benjamin S. Kirk
  * \date 2002-2007
- * \version $Revision: 1.30 $
+ * \version $Revision: 2789 $
  */
 
 //-------------------------------------------------------------
@@ -581,7 +581,7 @@ public:
  *
  * \author Benjamin S. Kirk
  * \date 2002-2007
- * \version $Revision: 1.30 $
+ * \version $Revision: 2789 $
  */
 
 //-------------------------------------------------------------
@@ -732,7 +732,7 @@ FE<Dim,T>::FE (const FEType& fet) :
   // Sanity check.  Make sure the
   // Family specified in the template instantiation
   // matches the one in the FEType object
-  assert (T == fe_type.family);
+  libmesh_assert (T == fe_type.family);
 }
 
 
