@@ -1,4 +1,4 @@
-// $Id: inf_fe.h,v 1.12 2007-10-21 20:48:41 benkirk Exp $
+// $Id: inf_fe.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -66,7 +66,7 @@ class FEComputeData;
  *
  * \author Daniel Dreyer
  * \date 2003
- * \version $Revision: 1.12 $
+ * \version $Revision: 2789 $
  */
 
 //-------------------------------------------------------------
@@ -89,7 +89,7 @@ protected:
    *
    * \author Daniel Dreyer
    * \date 2003
-   * \version $Revision: 1.12 $
+   * \version $Revision: 2789 $
    */
   //-------------------------------------------------------------
   // InfFE::Radial class definition
@@ -181,7 +181,7 @@ protected:
    *
    * \author Daniel Dreyer
    * \date 2003
-   * \version $Revision: 1.12 $
+   * \version $Revision: 2789 $
    */
   //-------------------------------------------------------------
   // InfFE::Base class definition
@@ -448,7 +448,7 @@ public:
    * for matrix assembly of the current element.
    */
   virtual unsigned int n_quadrature_points () const
-  { assert (radial_qrule != NULL); return _n_total_qp; }
+  { libmesh_assert (radial_qrule != NULL); return _n_total_qp; }
 
 
 protected:
@@ -500,7 +500,7 @@ protected:
    */
   virtual void init_base_shape_functions(const std::vector<Point>&,
 					 const Elem*)
-  { error(); }
+  { libmesh_error(); }
 
   /**
    * Some of the member data only depend on the radial part of the
@@ -839,7 +839,7 @@ Real InfFE<Dim,T_radial,T_map>::Radial::decay(const Real v)
       return 0.;
 
     default:
-      error();
+      libmesh_error();
       return 0.;
   }
 }
