@@ -1,4 +1,4 @@
-// $Id: cell_inf_prism.h,v 1.8 2007-10-21 20:48:41 benkirk Exp $
+// $Id: cell_inf_prism.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -89,6 +89,13 @@ public:
    */
   unsigned int n_children() const { return 4; }
   
+  /*
+   * @returns true iff the specified child is on the
+   * specified side
+   */
+  virtual bool is_child_on_side(const unsigned int c,
+			        const unsigned int s) const;
+  
   /**
    * @returns an id associated with the \p s side of this element.
    * The id is not necessariy unique, but should be close.  This is
@@ -118,7 +125,7 @@ InfPrism::InfPrism(const unsigned int nn, Elem* p) :
 // inline
 // unsigned int InfPrism::n_children_per_side(const unsigned int s) const
 // {
-//   assert (s < this->n_sides());
+//   libmesh_assert (s < this->n_sides());
 
 //   switch (s)
 //   {
@@ -129,7 +136,7 @@ InfPrism::InfPrism(const unsigned int nn, Elem* p) :
 //     default:
 //       // on infinite faces (sides), only 2 children exist
 //       //
-//       // note that the face at infinity is already caught by the assertion
+//       // note that the face at infinity is already caught by the libmesh_assertion
 //       return 2;
 //   }
 // }
