@@ -1,4 +1,4 @@
-// $Id: cell_prism.h,v 1.8 2007-10-21 20:48:41 benkirk Exp $
+// $Id: cell_prism.h 2780 2008-04-11 23:31:32Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -77,6 +77,13 @@ public:
    */
   unsigned int n_children() const { return 8; }
   
+  /*
+   * @returns true iff the specified child is on the
+   * specified side
+   */
+  virtual bool is_child_on_side(const unsigned int c,
+			        const unsigned int s) const;
+  
   /**
    * @returns an id associated with the \p s side of this element.
    * The id is not necessariy unique, but should be close.  This is
