@@ -1,4 +1,4 @@
-// $Id: cell_prism15.h,v 1.15 2007-10-21 20:48:41 benkirk Exp $
+// $Id: cell_prism15.h 2788 2008-04-13 02:05:22Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -199,7 +199,7 @@ protected:
   float embedding_matrix (const unsigned int,
 			 const unsigned int,
 			 const unsigned int) const
-  { error(); return 0.; }
+  { libmesh_error(); return 0.; }
   
 #endif
 
