@@ -1,4 +1,4 @@
-// $Id: cell_pyramid.h,v 1.6 2007-10-21 20:48:41 benkirk Exp $
+// $Id: cell_pyramid.h 2788 2008-04-13 02:05:22Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -78,6 +78,13 @@ public:
    */
   unsigned int n_children() const { return 10; }
   
+  /*
+   * @returns true iff the specified child is on the
+   * specified side
+   */
+  virtual bool is_child_on_side(const unsigned int c,
+			        const unsigned int s) const;
+  
   /**
    * @returns an id associated with the \p s side of this element.
    * The id is not necessariy unique, but should be close.  This is
@@ -102,7 +109,7 @@ public:
    */
   unsigned int side_children_matrix (const unsigned int, 
 				     const unsigned int) const
-  { error(); return 0; }
+  { libmesh_error(); return 0; }
 
 #endif
   
