@@ -1,4 +1,4 @@
-// $Id: edge.h,v 1.10 2007-10-21 20:48:41 benkirk Exp $
+// $Id: edge.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -96,6 +96,13 @@ class Edge : public Elem
    */
   unsigned int n_children() const { return 2; }
 
+  /*
+   * @returns true iff the specified child is on the
+   * specified side
+   */
+  virtual bool is_child_on_side(const unsigned int c,
+			        const unsigned int s) const;
+  
 //   /**
 //    * @returns 1
 //    */
@@ -126,8 +133,8 @@ class Edge : public Elem
    * The \p Elem::build_edge() member makes no sense for edges.
    */
   AutoPtr<Elem> build_edge (const unsigned int) const
-  //{ assert(i < n_nodes()); AutoPtr<DofObject> ap(new Node(*get_node(i))); return ap; }
-  { error(); AutoPtr<Elem> ap(NULL); return ap; }
+  //{ libmesh_assert(i < n_nodes()); AutoPtr<DofObject> ap(new Node(*get_node(i))); return ap; }
+  { libmesh_error(); AutoPtr<Elem> ap(NULL); return ap; }
 
   
  protected:
@@ -140,7 +147,7 @@ class Edge : public Elem
    */
   unsigned int side_children_matrix (const unsigned int, 
 				     const unsigned int) const
-  { error(); return 0; }
+  { libmesh_error(); return 0; }
 
 #endif
   
