@@ -1,4 +1,4 @@
-// $Id: edge_edge2.h,v 1.14 2007-10-21 20:48:41 benkirk Exp $
+// $Id: edge_edge2.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -59,7 +59,7 @@ class Edge2 : public Edge
   Edge2 (const unsigned int nn,
 	 const unsigned int ns,
 	 Elem* p) :
-    Edge(nn, p) { assert (ns == 0); }
+    Edge(nn, p) { libmesh_assert (ns == 0); }
 
   /**
    * @returns 1
