@@ -1,4 +1,4 @@
-// $Id: edge_edge4.h,v 1.4 2007-10-21 20:48:41 benkirk Exp $
+// $Id: edge_edge4.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -55,7 +55,7 @@ class Edge4 : public Edge
   Edge4(const unsigned int nn,
         const unsigned int ns,
 	Elem* p) :
-    Edge(nn, p) { assert (ns == 0); }
+    Edge(nn, p) { libmesh_assert (ns == 0); }
 
   /**
    * @returns 4
@@ -119,13 +119,13 @@ class Edge4 : public Edge
   /**
    */
   unsigned int n_second_order_adjacent_vertices (const unsigned int) const
-      { error(); return 0;  }
+      { libmesh_error(); return 0;  }
 
   /**
    */
   unsigned short int second_order_adjacent_vertex (const unsigned int,
 						   const unsigned int) const
-      { error(); return 0; }
+      { libmesh_error(); return 0; }
 
 
 #ifdef ENABLE_INFINITE_ELEMENTS
