@@ -1,4 +1,4 @@
-// $Id: elem.h,v 1.56 2007-10-21 20:48:41 benkirk Exp $
+// $Id: elem.h 2970 2008-08-11 00:17:08Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -41,6 +41,7 @@
 #include "variant_filter_iterator.h"
 
 // Forward declarations
+class MeshBase;
 class MeshRefinement;
 class Elem;
 
@@ -141,14 +142,6 @@ class Elem : public ReferenceCountedObject<Elem>,
    */
   unsigned char & subdomain_id ();
 
-  /**
-   * @returns an id assocated with this element.  The id is not
-   * guaranteed to be unique, but it should be close.  The id
-   * is thus useful, for example, as a key in a hash table
-   * data structure.
-   */
-  unsigned int key () const;
-
   /**
    * @returns an id associated with the \p s side of this element.
    * The id is not necessariy unique, but should be close.  This is
@@ -182,7 +175,7 @@ class Elem : public ReferenceCountedObject<Elem>,
    * @returns \p true if the element \p elem in question is a neighbor
    * of this element, \p false otherwise.
    */
-  bool is_neighbor (const Elem* elem) const;
+  bool has_neighbor (const Elem* elem) const;
   
   /**
    * If the element \p elem in question is a neighbor
@@ -224,6 +217,28 @@ class Elem : public ReferenceCountedObject<Elem>,
    */
   void find_point_neighbors(std::set<const Elem *> &neighbor_set) const;
 
+  /**
+   * Resets this element's neighbors' appropriate neighbor pointers
+   * and its parent's and children's appropriate pointers
+   * to point to the global remote_elem instead of this.
+   * Used by the library before a remote element is deleted on the
+   * local processor.
+   */
+  void make_links_to_me_remote ();
+
+  /** 
+   * Returns true if this element is remote, false otherwise.
+   * A remote element (see \p RemoteElem) is a syntactic convenience --
+   * it is a placeholder for an element which exists on some other
+   * processor.  Local elements are required to have valid neighbors,
+   * and these ghost elements may have remote neighbors for data
+   * structure consistency.  The use of remote elements helps assure
+   * that any element we may access has a NULL neighbor if and only if
+   * it lies on the physical boundary of the domain.
+   */
+  virtual bool is_remote () const
+  { return false; }
+
   /**
    * Returns the connectivity for this element in a specific
    * format, which is specified by the IOPackage tag.  This
@@ -254,6 +269,12 @@ class Elem : public ReferenceCountedObject<Elem>,
    * base class.
    */
   virtual ElemType type () const = 0;
+
+  /**
+   * This array maps the integer representation of the \p ElemType enum
+   * to the number of nodes in the element.
+   */
+  static const unsigned int type_to_n_nodes_map[INVALID_ELEM];
   
   /**
    * @returns the dimensionality of the object.
@@ -430,7 +451,7 @@ class Elem : public ReferenceCountedObject<Elem>,
    * for an abstract Elem, it is an error.
    */
   virtual std::pair<Real,Real> qual_bounds (const ElemQuality) const
-  { error(); return std::make_pair(0.,0.); }
+  { libmesh_error(); return std::make_pair(0.,0.); }
   
   /**
    * @returns true if the point p is contained in this element, 
@@ -478,6 +499,13 @@ class Elem : public ReferenceCountedObject<Elem>,
    */
   bool has_ancestor_children () const;
 
+  /**
+   * @returns \p true if \p descendant is a child of \p this, or a
+   * child of a child of \p this, etc.
+   * Always returns \p false if AMR is disabled. 
+   */
+  bool is_ancestor_of(const Elem *descendant) const;
+
   /**
    * @returns a const pointer to the element's parent.  Returns \p NULL if
    * the element was not created via refinement, i.e. was read from file.
@@ -608,14 +636,14 @@ class Elem : public ReferenceCountedObject<Elem>,
    */
   unsigned int which_child_am_i(const Elem *e) const; 
 
-  /*
+  /**
    * @returns true iff the specified child is on the
    * specified side
    */
   virtual bool is_child_on_side(const unsigned int c,
-			        const unsigned int s) const;
+			        const unsigned int s) const = 0;
   
-  /*
+  /**
    * @returns true iff the specified child is on the
    * specified edge
    */
@@ -630,6 +658,14 @@ class Elem : public ReferenceCountedObject<Elem>,
    */
   void add_child (Elem* elem);
 
+  /**
+   * Adds a new child pointer to the specified index in the array of
+   * children of this element.  If this is the first child to be added,
+   * this method allocates memory in the parent's _children array,
+   * otherwise, it just sets the pointer.
+   */
+  void add_child (Elem* elem, unsigned int c);
+
   /**
    * Fills the vector \p family with the children of this element,
    * recursively.  So, calling this method on a twice-refined element
@@ -658,6 +694,17 @@ class Elem : public ReferenceCountedObject<Elem>,
 		                const Elem *neighbor,
 		                const bool reset=true) const;
 
+  /**
+   * Same as the \p family_tree() member, but only adds elements
+   * which are next to \p subneighbor.  Only applicable when
+   * \p this->has_neighbor(neighbor) and
+   * \p neighbor->is_ancestor(subneighbor)
+   */
+  void family_tree_by_subneighbor (std::vector<const Elem*>& family,
+		                   const Elem *neighbor,
+		                   const Elem *subneighbor,
+		                   const bool reset=true) const;
+
   /**
    * Same as the \p active_family_tree() member, but only adds elements
    * which are next to \p neighbor.
@@ -726,13 +773,6 @@ class Elem : public ReferenceCountedObject<Elem>,
    */
   virtual void refine (MeshRefinement& mesh_refinement);
  
-  /**
-   * For an element with children, this function calculates
-   * and sets the key values for the nodes introduced by the
-   * children (e.g. mid-edge/mid-face nodes)
-   */
-  void compute_children_node_keys();
- 
   /**
    * Coarsen the element.  This is not
    * virtual since it is the same for all
@@ -750,8 +790,22 @@ class Elem : public ReferenceCountedObject<Elem>,
 
 #endif
 
+#ifdef DEBUG
+  /**
+   * This function checks for consistent neighbor links at this
+   * element.
+   */
+  void libmesh_assert_valid_neighbors() const;
+
+  /**
+   * This function checks for a valid id and for pointers to nodes
+   * with valid ids at this element.
+   */
+  void libmesh_assert_valid_node_pointers() const;
+#endif // DEBUG
 
 protected:
+
   /**
    * The protected nested SideIter class is used to iterate over the
    * sides of this Elem.  It is a specially designed class since
@@ -809,7 +863,7 @@ public:
    * all zero point would very likely lead to unexpected
    * behavior.
    */
-  virtual Point origin () const { error(); return Point(); }
+  virtual Point origin () const { libmesh_error(); return Point(); }
 
 #endif
 
@@ -837,6 +891,17 @@ public:
 #endif
   
 
+  //--------------------------------------------------------
+  /**
+   * Convenient way to communicate elements.  This struct 
+   * packes up an element so that it can easily be communicated through
+   * an MPI array.
+   *
+   * \author Benjamin S. Kirk
+   * \date 2008
+   */
+  class PackedElem;
+
 
  protected:
 
@@ -974,8 +1039,8 @@ Elem::Elem(const unsigned int nn,
 #endif
 {
   this->subdomain_id() = 0;
-  this->processor_id() = 0;
-
+  this->processor_id() = DofObject::invalid_processor_id;
+  
   // Initialize the nodes data structure
   _nodes = NULL;
   
@@ -1018,7 +1083,7 @@ Elem::Elem(const unsigned int nn,
   else
     this->set_p_level(0);
 
-#endif  
+#endif
 }
 
 
@@ -1051,9 +1116,9 @@ Elem::~Elem()
 inline
 const Point & Elem::point (const unsigned int i) const
 {
-  assert (i < this->n_nodes());
-  assert (_nodes[i] != NULL);
-  assert (_nodes[i]->id() != Node::invalid_id);
+  libmesh_assert (i < this->n_nodes());
+  libmesh_assert (_nodes[i] != NULL);
+  libmesh_assert (_nodes[i]->id() != Node::invalid_id);
 
   return *_nodes[i];
 }
@@ -1063,7 +1128,7 @@ const Point & Elem::point (const unsigned int i) const
 inline
 Point & Elem::point (const unsigned int i)
 {
-  assert (i < this->n_nodes());
+  libmesh_assert (i < this->n_nodes());
 
   return *_nodes[i];
 }
@@ -1073,9 +1138,9 @@ Point & Elem::point (const unsigned int i)
 inline
 unsigned int Elem::node (const unsigned int i) const
 {
-  assert (i < this->n_nodes());
-  assert (_nodes[i] != NULL);
-  assert (_nodes[i]->id() != Node::invalid_id);
+  libmesh_assert (i < this->n_nodes());
+  libmesh_assert (_nodes[i] != NULL);
+  libmesh_assert (_nodes[i]->id() != Node::invalid_id);
 
   return _nodes[i]->id();
 }
@@ -1085,8 +1150,8 @@ unsigned int Elem::node (const unsigned int i) const
 inline
 Node* Elem::get_node (const unsigned int i) const
 {
-  assert (i < this->n_nodes());
-  assert (_nodes[i] != NULL);
+  libmesh_assert (i < this->n_nodes());
+  libmesh_assert (_nodes[i] != NULL);
 
   return _nodes[i];
 }
@@ -1096,7 +1161,7 @@ Node* Elem::get_node (const unsigned int i) const
 inline
 Node* & Elem::set_node (const unsigned int i)
 {
-  assert (i < this->n_nodes());
+  libmesh_assert (i < this->n_nodes());
 
   return _nodes[i];
 }
@@ -1122,7 +1187,7 @@ unsigned char & Elem::subdomain_id ()
 inline
 Elem* Elem::neighbor (const unsigned int i) const
 {
-  assert (i < this->n_neighbors());
+  libmesh_assert (i < this->n_neighbors());
 
   return _neighbors[i];
 }
@@ -1132,7 +1197,7 @@ Elem* Elem::neighbor (const unsigned int i) const
 inline
 void Elem::set_neighbor (const unsigned int i, Elem* n)
 {
-  assert (i < this->n_neighbors());
+  libmesh_assert (i < this->n_neighbors());
   
   _neighbors[i] = n;
 }
@@ -1140,7 +1205,7 @@ void Elem::set_neighbor (const unsigned int i, Elem* n)
 
 
 inline
-bool Elem::is_neighbor (const Elem* elem) const
+bool Elem::has_neighbor (const Elem* elem) const
 {
   for (unsigned int n=0; n<this->n_neighbors(); n++)
     if (this->neighbor(n) == elem)
@@ -1182,7 +1247,7 @@ bool Elem::on_boundary () const
 {
   // By convention, the element is on the boundary
   // if it has a NULL neighbor.
-  return this->is_neighbor(NULL);
+  return this->has_neighbor(NULL);
 }
 
 
@@ -1190,23 +1255,20 @@ bool Elem::on_boundary () const
 inline
 unsigned int Elem::which_neighbor_am_i (const Elem* e) const
 {
-  assert (e != NULL);
+  libmesh_assert (e != NULL);
 
   const Elem* eparent = e;
 
   while (eparent->level() > this->level())
-    eparent = eparent->parent();
+    {
+      eparent = eparent->parent();
+      libmesh_assert(eparent);
+    }
   
   for (unsigned int s=0; s<this->n_neighbors(); s++)
     if (this->neighbor(s) == eparent)
       return s;
     
-
-  std::cerr << "ERROR:  Elements are not neighbors!" 
-	    << std::endl;
-
-  error();
-
   return libMesh::invalid_uint;
 }
 
@@ -1276,6 +1338,27 @@ bool Elem::has_ancestor_children() const
 
 
 
+#ifdef ENABLE_AMR
+inline
+bool Elem::is_ancestor_of(const Elem *descendant) const
+{
+  const Elem *e = descendant;
+  while (e)
+    {
+      if (this == e)
+        return true;
+      e = e->parent();
+    }
+#else
+inline
+bool Elem::is_ancestor_of(const Elem *) const
+{
+#endif
+  return false;
+}
+
+
+
 inline
 const Elem* Elem::parent () const
 {
@@ -1310,8 +1393,8 @@ const Elem* Elem::top_parent () const
   while (tp->parent() != NULL)
     tp = tp->parent();
   
-  assert (tp != NULL);
-  assert (tp->level() == 0);
+  libmesh_assert (tp != NULL);
+  libmesh_assert (tp->level() == 0);
 
   return tp;  
 }
@@ -1362,8 +1445,8 @@ unsigned int Elem::p_level() const
 inline
 Elem* Elem::child (const unsigned int i) const
 {
-  assert (_children    != NULL);
-  assert (_children[i] != NULL);
+  libmesh_assert (_children    != NULL);
+  libmesh_assert (_children[i] != NULL);
   
   return _children[i];
 }
@@ -1373,8 +1456,8 @@ Elem* Elem::child (const unsigned int i) const
 inline
 unsigned int Elem::which_child_am_i (const Elem* e) const
 {
-  assert (e != NULL);
-  assert (this->has_children());
+  libmesh_assert (e != NULL);
+  libmesh_assert (this->has_children());
 
   for (unsigned int c=0; c<this->n_children(); c++)
     if (this->child(c) == e)
@@ -1383,7 +1466,7 @@ unsigned int Elem::which_child_am_i (const Elem* e) const
   std::cerr << "ERROR:  which_child_am_i() was called with a non-child!" 
 	    << std::endl;
 
-  error();
+  libmesh_error();
 
   return libMesh::invalid_uint;
 }
@@ -1408,7 +1491,7 @@ void Elem::set_refinement_flag(RefinementState rflag)
 		<< std::endl
 		<< "Recompile with Elem:_*flag set to something bigger!"
 		<< std::endl;
-      error();
+      libmesh_error();
     }
 #endif
 
@@ -1435,7 +1518,7 @@ void Elem::set_p_refinement_flag(RefinementState pflag)
 		<< std::endl
 		<< "Recompile with Elem:_*flag set to something bigger!"
 		<< std::endl;
-      error();
+      libmesh_error();
     }
 #endif
 
@@ -1449,7 +1532,7 @@ unsigned int Elem::max_descendant_p_level () const
 {
   // This is undefined for subactive elements,
   // which have no active descendants
-  assert (!this->subactive());
+  libmesh_assert (!this->subactive());
   if (this->active())
     return this->p_level();
   
@@ -1472,7 +1555,7 @@ void Elem::set_p_level(unsigned int p)
 		<< std::endl
 		<< "Recompile with Elem:_p_level set to something bigger!"
 		<< std::endl;
-      error();
+      libmesh_error();
     }
 #endif
 
@@ -1573,7 +1656,7 @@ unsigned int Elem::compute_key (unsigned int n0,
   // Step 3
   if (n0 > n1) std::swap (n0, n1);
 
-  assert ((n0 < n1) && (n1 < n2));
+  libmesh_assert ((n0 < n1) && (n1 < n2));
 
   
   return (n0%bp + (n1<<5)%bp + (n2<<10)%bp);
@@ -1605,13 +1688,161 @@ unsigned int Elem::compute_key (unsigned int n0,
   // Finally step 5
   if (n1 > n2) std::swap (n1, n2);
 
-  assert ((n0 < n1) && (n1 < n2) && (n2 < n3));
+  libmesh_assert ((n0 < n1) && (n1 < n2) && (n2 < n3));
   
   return (n0%bp + (n1<<5)%bp + (n2<<10)%bp + (n3<<15)%bp);
 }
 
 
 
+//-----------------------------------------------------------------
+/**
+ * Convenient way to communicate elements.  This class
+ * packes up an element so that it can easily be communicated through
+ * an MPI array.
+ *
+ * \author Benjamin S. Kirk
+ * \date 2008
+ */
+class Elem::PackedElem
+{
+private:
+    
+  /**
+   * Iterator pointing to the beginning of this packed element's index buffer.
+   */
+  const std::vector<int>::const_iterator _buf_begin;
+
+public:
+
+  /**
+   * Constructor.  Takes an input iterator pointing to the 
+   * beginning of the connectivity block for this element.
+   */
+  PackedElem (const std::vector<int>::const_iterator _buf_in) :
+    _buf_begin(_buf_in)
+  {}
+    
+  /**
+   * An \p Elem can be packed into an integer array which is 
+   * \p header_size + elem->n_nodes() in length.
+   */
+  static const unsigned int header_size; /* = 10 with AMR, 4 without */
+    
+  /**
+   * For each element it is of the form
+   * [ level p_level r_flag p_r_flag etype processor_id subdomain_id 
+   *  self_ID parent_ID which_child node_0 node_1 ... node_n]
+   * We cannot use unsigned int because parent_ID can be negative
+   */
+  static void pack (std::vector<int> &conn, const Elem* elem);    
+
+  /**
+   * Unpacks this packed element.  Returns a pointer to the new element.
+   * Takes a pointer to the parent, which is required unless this packed
+   * element is at level 0.
+   */
+  Elem * unpack (MeshBase &mesh, Elem *parent = NULL) const;
+
+  /**
+   * \p return the level of this packed element.
+   */
+  unsigned int level () const
+  {
+    return static_cast<unsigned int>(*_buf_begin);
+  }
+
+  /**
+   * \p return the p-level of this packed element.
+   */
+  unsigned int p_level () const
+  {
+    return static_cast<unsigned int>(*(_buf_begin+1));
+  }
+
+#ifdef ENABLE_AMR
+  /**
+   * \p return the refinement state of this packed element.
+   */
+  Elem::RefinementState refinement_flag () const
+  {
+    return static_cast<Elem::RefinementState>(*(_buf_begin+2));
+  }
+
+  /**
+   * \p return the p-refinement state of this packed element.
+   */
+  Elem::RefinementState p_refinement_flag () const
+  {
+    return static_cast<Elem::RefinementState>(*(_buf_begin+3));
+  }
+#endif // ENABLE_AMR
+
+  /**
+   * \p return the element type of this packed element.
+   */
+  ElemType type () const
+  {
+    return static_cast<ElemType>(*(_buf_begin+4));
+  }
+
+  /**
+   * \p return the processor id of this packed element.
+   */
+  unsigned int processor_id () const
+  {
+    return static_cast<unsigned int>(*(_buf_begin+5));
+  }
+
+  /**
+   * \p return the subdomain id of this packed element.
+   */
+  unsigned int subdomain_id () const
+  {
+    return static_cast<unsigned int>(*(_buf_begin+6));
+  }
+
+  /**
+   * \p return the id of this packed element.
+   */
+  unsigned int id () const
+  {
+    return static_cast<unsigned int>(*(_buf_begin+7));
+  }
+
+  /**
+   * \p return the parent id of this packed element.
+   */
+  int parent_id () const
+  {
+    return *(_buf_begin+8);
+  }
+
+  /**
+   * \p return which child this packed element is.
+   */
+  unsigned int which_child_am_i () const
+  {
+    return static_cast<unsigned int>(*(_buf_begin+9));
+  }
+    
+  /**
+   * \p return the number of nodes in this packed element
+   */
+  unsigned int n_nodes () const
+  {
+    return Elem::type_to_n_nodes_map[this->type()];
+  }
+
+  /**
+   * \p return the global index of the packed element's nth node.
+   */
+  unsigned int node (const unsigned int n) const
+  {
+    return static_cast<unsigned int>(*(_buf_begin+10+n));
+  }    
+}; // end class PackedElem
+
 
 /**
  * The definition of the protected nested SideIter class.
