@@ -1,4 +1,4 @@
-// $Id: face_inf_quad.h,v 1.9 2007-10-21 20:48:41 benkirk Exp $
+// $Id: face_inf_quad.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -116,6 +116,13 @@ public:
    */
   unsigned int n_children() const { return 2; }
   
+  /*
+   * @returns true iff the specified child is on the
+   * specified side
+   */
+  virtual bool is_child_on_side(const unsigned int c,
+			        const unsigned int s) const;
+  
   /**
    * @returns an id associated with the \p s side of this element.
    * The id is not necessariy unique, but should be close.  This is
@@ -168,7 +175,7 @@ public:
 // inline
 // unsigned int InfQuad::n_children_per_side(const unsigned int s) const
 // {
-//   assert (s < this->n_sides());
+//   libmesh_assert (s < this->n_sides());
 
 //   switch (s)
 //   {
