@@ -1,4 +1,4 @@
-// $Id: node_elem.h,v 1.4 2007-10-21 20:48:41 benkirk Exp $
+// $Id: node_elem.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -55,7 +55,7 @@ class NodeElem : public Elem
   NodeElem (const unsigned int nn,
          const unsigned int ns,
          Elem* p) :
-    Elem(nn, ns, p) { assert(nn == 1); assert (ns == 0); }
+    Elem(nn, ns, p) { libmesh_assert(nn == 1); libmesh_assert (ns == 0); }
 
   /**
    * Default node element, takes number of nodes and 
@@ -111,19 +111,19 @@ class NodeElem : public Elem
    * The \p Elem::side() member makes no sense for nodes.
    */
   AutoPtr<DofObject> side (const unsigned int) const
-  { error(); AutoPtr<DofObject> ap(NULL); return ap; }
+  { libmesh_error(); AutoPtr<DofObject> ap(NULL); return ap; }
 
   /**
    * The \p Elem::build_side() member makes no sense for nodes.
    */
   AutoPtr<Elem> build_side (const unsigned int, bool) const
-  { error(); AutoPtr<Elem> ap(NULL); return ap; }
+  { libmesh_error(); AutoPtr<Elem> ap(NULL); return ap; }
 
   /**
    * The \p Elem::build_edge() member makes no sense for nodes.
    */
   AutoPtr<Elem> build_edge (const unsigned int) const
-  { error(); AutoPtr<Elem> ap(NULL); return ap; }
+  { libmesh_error(); AutoPtr<Elem> ap(NULL); return ap; }
 
   /**
    * @returns 1
@@ -136,28 +136,23 @@ class NodeElem : public Elem
   virtual bool is_vertex(const unsigned int) const { return true; }
 
   /**
-   * @returns true iff the specified (local) node number is an edge.
+   * NodeElem objects don't have faces or sides
    */
   virtual bool is_edge(const unsigned int) const { return false; }
 
-  /**
-   * @returns true iff the specified (local) node number is a face.
-   */
   virtual bool is_face(const unsigned int) const { return false; }
   
-  /*
-   * @returns true iff the specified (local) node number is on the
-   * specified side
-   */
+  virtual bool is_child_on_side(const unsigned int,
+			        const unsigned int) const
+  { libmesh_error(); return false; }
+  
   virtual bool is_node_on_side(const unsigned int,
-			       const unsigned int) const { error(); return false; }
+			       const unsigned int) const
+  { libmesh_error(); return false; }
   
-  /*
-   * @returns true iff the specified (local) node number is on the
-   * specified edge (i.e. "returns true" in 1D)
-   */
   virtual bool is_node_on_edge(const unsigned int,
-			       const unsigned int) const { error(); return false; }
+			       const unsigned int) const 
+  { libmesh_error(); return false; }
   
   /*
    * @returns true iff the element map is definitely affine within
@@ -214,7 +209,7 @@ protected:
    */
   unsigned int side_children_matrix (const unsigned int, 
 				     const unsigned int) const
-  { error(); return 0; }
+  { libmesh_error(); return 0; }
 
 #endif
   
