@@ -1,4 +1,4 @@
-// $Id: side.h,v 1.8 2007-10-21 20:48:42 benkirk Exp $
+// $Id: side.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -43,8 +43,8 @@ class Node;
  * does not store any.
  *
  * \author  Benjamin S. Kirk
- * \date    $Date: 2007-10-21 20:48:42 $
- * \version $Revision: 1.8 $
+ * \date    $Date: 2008-04-12 21:24:40 -0500 (Sat, 12 Apr 2008) $
+ * \version $Revision: 2789 $
  */
 
 // ------------------------------------------------------------
@@ -62,10 +62,10 @@ class Side : public SideType
     SideType(0,0,const_cast<Elem*>(parent)), // Allocate no storage for nodes or neighbors!
     _side_number(side)
   {
-    assert (parent != NULL);
+    libmesh_assert (parent != NULL);
     // may not be true when building infinite element sides
-    // assert (_side_number < this->parent()->n_sides());
-    assert ((this->dim()+1) == this->parent()->dim());
+    // libmesh_assert (_side_number < this->parent()->n_sides());
+    libmesh_assert ((this->dim()+1) == this->parent()->dim());
   }
 
   /**
@@ -73,7 +73,7 @@ class Side : public SideType
    */
   virtual const Point & point (const unsigned int i) const
   {
-    assert (i < this->n_nodes());    
+    libmesh_assert (i < this->n_nodes());    
     return this->parent()->point (ParentType::side_nodes_map[_side_number][i]);
   }
  
@@ -83,7 +83,7 @@ class Side : public SideType
    */
   virtual Point & point (const unsigned int i)
   {
-    assert (i < this->n_nodes());
+    libmesh_assert (i < this->n_nodes());
     return this->parent()->point (ParentType::side_nodes_map[_side_number][i]);
   }
   
@@ -92,7 +92,7 @@ class Side : public SideType
    */
   virtual unsigned int node (const unsigned int i) const
   {
-    assert (i < this->n_nodes());
+    libmesh_assert (i < this->n_nodes());
     return this->parent()->node (ParentType::side_nodes_map[_side_number][i]);  
   }
 
@@ -101,7 +101,7 @@ class Side : public SideType
    */
   virtual Node* get_node (const unsigned int i) const
   {
-    assert (i < this->n_nodes());    
+    libmesh_assert (i < this->n_nodes());    
     return this->parent()->get_node (ParentType::side_nodes_map[_side_number][i]);
   }
 
@@ -110,16 +110,20 @@ class Side : public SideType
    */
   virtual Node* & set_node (const unsigned int i)
   {
-    assert (i < this->n_nodes());    
+    libmesh_assert (i < this->n_nodes());    
     return this->parent()->set_node (ParentType::side_nodes_map[_side_number][i]);
   }
 
   /**
-   * @returns 0. Sides effectively do not have sides, so
-   * don't even ask!
+   * @Sides effectively do not have sides, so don't even ask!
    */
-  virtual unsigned int n_sides () const { return 0; }
+  virtual unsigned int n_sides () const 
+  { libmesh_error(); return 0; }
 
+  virtual bool is_child_on_side(const unsigned int,
+			        const unsigned int) const
+  { libmesh_error(); return false; }
+  
   
  private:
 
@@ -141,8 +145,8 @@ class Side : public SideType
  * cannot access the neighbors of a side since it does not store any.
  *
  * \author  Roy H. Stogner
- * \date    $Date: 2007-10-21 20:48:42 $
- * \version $Revision: 1.8 $
+ * \date    $Date: 2008-04-12 21:24:40 -0500 (Sat, 12 Apr 2008) $
+ * \version $Revision: 2789 $
  */
 
 // ------------------------------------------------------------
@@ -160,9 +164,9 @@ class SideEdge : public EdgeType
     EdgeType(0,0,const_cast<Elem*>(parent)), // Allocate no storage for nodes or neighbors!
     _edge_number(edge)
   {
-    assert (parent != NULL);
-    assert (_edge_number < this->parent()->n_edges());
-    assert (this->dim() == 1);
+    libmesh_assert (parent != NULL);
+    libmesh_assert (_edge_number < this->parent()->n_edges());
+    libmesh_assert (this->dim() == 1);
   }
 
   /**
@@ -170,7 +174,7 @@ class SideEdge : public EdgeType
    */
   virtual const Point & point (const unsigned int i) const
   {
-    assert (i < this->n_nodes());    
+    libmesh_assert (i < this->n_nodes());    
     return this->parent()->point (ParentType::edge_nodes_map[_edge_number][i]);
   }
  
@@ -180,7 +184,7 @@ class SideEdge : public EdgeType
    */
   virtual Point & point (const unsigned int i)
   {
-    assert (i < this->n_nodes());
+    libmesh_assert (i < this->n_nodes());
     return this->parent()->point (ParentType::edge_nodes_map[_edge_number][i]);
   }
   
@@ -189,7 +193,7 @@ class SideEdge : public EdgeType
    */
   virtual unsigned int node (const unsigned int i) const
   {
-    assert (i < this->n_nodes());
+    libmesh_assert (i < this->n_nodes());
     return this->parent()->node (ParentType::edge_nodes_map[_edge_number][i]);  
   }
 
@@ -198,7 +202,7 @@ class SideEdge : public EdgeType
    */
   virtual Node* get_node (const unsigned int i) const
   {
-    assert (i < this->n_nodes());    
+    libmesh_assert (i < this->n_nodes());    
     return this->parent()->get_node (ParentType::edge_nodes_map[_edge_number][i]);
   }
 
@@ -207,7 +211,7 @@ class SideEdge : public EdgeType
    */
   virtual Node* & set_node (const unsigned int i)
   {
-    assert (i < this->n_nodes());    
+    libmesh_assert (i < this->n_nodes());    
     return this->parent()->set_node (ParentType::edge_nodes_map[_edge_number][i]);
   }
 
