@@ -1,4 +1,4 @@
-// $Id: boundary_info.h,v 1.17 2007-10-21 20:48:42 benkirk Exp $
+// $Id: boundary_info.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -173,8 +173,7 @@ public:
   /**
    * @returns the number of element-based boundary conditions.
    */
-  unsigned int n_boundary_conds () const
-  { return _boundary_side_id.size(); }
+  unsigned int n_boundary_conds () const;
   
   /**
    * Creates a list of nodes and ids for those nodes.
@@ -314,7 +313,7 @@ public:
 inline
 void BoundaryInfo::remove (const Node* node)
 {
-  assert (node != NULL);
+  libmesh_assert (node != NULL);
   
   // Erase everything associated with node
   _boundary_node_id.erase (node);
@@ -325,7 +324,7 @@ void BoundaryInfo::remove (const Node* node)
 inline
 void BoundaryInfo::remove (const Elem* elem)
 {
-  assert (elem != NULL);
+  libmesh_assert (elem != NULL);
   
   // Erase everything associated with elem
   _boundary_side_id.erase (elem);
