@@ -1,4 +1,4 @@
-// $Id: diva_io.h,v 1.7 2007-10-21 20:48:42 benkirk Exp $
+// $Id: diva_io.h 2501 2007-11-20 02:33:29Z benkirk $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -26,7 +26,7 @@
 #include "mesh_output.h"
 
 // Forward declarations
-class UnstructuredMesh;
+class MeshBase;
 
 
 
@@ -41,7 +41,7 @@ class UnstructuredMesh;
 
 // ------------------------------------------------------------
 // DivaIO class definition
-class DivaIO : public MeshOutput<UnstructuredMesh>
+class DivaIO : public MeshOutput<MeshBase>
 {
 public:
   /**
@@ -49,7 +49,7 @@ public:
    * not a mesh generator.
    */
   //TODO:[JWP] figure out how to implement a const write method!
-  DivaIO (const UnstructuredMesh&);
+  DivaIO (const MeshBase&);
 
   /**
    * This method implements writing a mesh to a specified file.
@@ -72,8 +72,8 @@ private:
 // ------------------------------------------------------------
 // DivaIO inline members
 inline
-DivaIO::DivaIO (const UnstructuredMesh& mesh) :
-  MeshOutput<UnstructuredMesh>  (mesh)
+DivaIO::DivaIO (const MeshBase& mesh) :
+  MeshOutput<MeshBase>  (mesh)
 {}
 
 
