@@ -1,4 +1,4 @@
-// $Id: exodusII_io.h 2501 2007-11-20 02:33:29Z benkirk $
+// $Id: exodusII_io.h 2969 2008-08-10 20:59:48Z jwpeterson $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -40,7 +40,7 @@ class ExodusII;
  * licensing restrictions the external libraries required to
  * read such files cannot be redistributed with \p libMesh.
  * However, if you have these libraries, this class will allow
- * you to use the API to read ExodusII, or \p .exd, files.
+ * you to use the API to read ExodusII, or \p .exd/.e, files.
  *
  * @author Benjamin Kirk, John Peterson, 2004.
  */
@@ -76,7 +76,11 @@ class ExodusII_IO : public MeshInput<MeshBase>,
   /**
    * This method implements writing a mesh to a specified file.
    */
-  virtual void write (const std::string& ){}
+  virtual void write (const std::string& )
+  {
+    std::cerr << "The ExodusII_IO::write() method is not yet implemented." << std::endl;
+    libmesh_error();
+  }
 
 
   /**
@@ -96,9 +100,19 @@ class ExodusII_IO : public MeshInput<MeshBase>,
   void write_nodal_data (const std::string&,
 			 const std::vector<Number>&,
 			 const std::vector<std::string>&);
+
+  /**
+   * Writes out the solution at a specific timestep.
+   * @param timestep The timestep to write out, should be _1_ indexed.
+   */
+  void write_timestep (const std::string& fname,
+		       const EquationSystems& es,
+		       const int timestep,
+		       const double time);
   
  private:
   ExodusII * ex_ptr;
+  int _timestep;
 
 //-------------------------------------------------------------
   // local data
@@ -109,27 +123,6 @@ class ExodusII_IO : public MeshInput<MeshBase>,
   bool _verbose;
 };
 
-
-
-// ------------------------------------------------------------
-// MeshIO inline members
-inline
-ExodusII_IO::ExodusII_IO (MeshBase& mesh) :
-  MeshInput<MeshBase> (mesh),
-  MeshOutput<MeshBase> (mesh),
-  _verbose (false)
-{
-}
-
-
-
-inline
-ExodusII_IO::~ExodusII_IO ()
-{
-}
-
-
-
 inline
 bool & ExodusII_IO::verbose ()
 {
@@ -137,5 +130,4 @@ bool & ExodusII_IO::verbose ()
 }
 
 
-
 #endif // #define __exodusII_io_h__
