@@ -1,4 +1,4 @@
-// $Id: mesh_base.h,v 1.58 2007-10-21 20:48:42 benkirk Exp $
+// $Id: mesh_base.h 2803 2008-04-23 21:14:29Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -34,13 +34,15 @@ class Point;
 class Partitioner;
 class BoundaryInfo;
 class PointLocatorBase;
+class MeshData;
 
 // Local Includes -----------------------------------
-#include "libmesh_common.h"
-#include "enum_elem_type.h"
-#include "variant_filter_iterator.h"
-#include "multi_predicates.h"
 #include "auto_ptr.h"
+#include "dof_object.h" // for invalid_processor_id
+#include "enum_elem_type.h"
+#include "libmesh_common.h"
+#include "multi_predicates.h"
+#include "variant_filter_iterator.h"
 
 
 
@@ -57,8 +59,8 @@ class PointLocatorBase;
  * mesh to disk in various formats.
  *
  * \author  Benjamin S. Kirk
- * \date    $Date: 2007-10-21 20:48:42 $
- * \version $Revision: 1.58 $
+ * \date    $Date: 2008-04-23 16:14:29 -0500 (Wed, 23 Apr 2008) $
+ * \version $Revision: 2803 $
  */
 
 
@@ -78,6 +80,11 @@ public:
    */
   MeshBase (const MeshBase& other_mesh);
 
+  /**
+   * Virtual "copy constructor"
+   */
+  virtual AutoPtr<MeshBase> clone() const = 0;
+
   /**
    * Destructor.
    */
@@ -102,6 +109,26 @@ public:
   bool is_prepared () const
   { return _is_prepared; }
   
+  /**
+   * @returns \p true if all elements and nodes of the mesh
+   * exist on the current processor, \p false otherwise
+   */
+  virtual bool is_serial () const 
+  { return true; }
+  
+  /**
+   * @gathers all elements and nodes of the mesh onto
+   * every processor
+   */
+  virtual void allgather () {}
+  
+  /**
+   * @when supported, deletes all nonlocal elements of the mesh
+   * except for "ghosts" which touch a local element, and deletes
+   * all nodes which are not part of a local or ghost element
+   */
+  virtual void delete_remote_elements () {}
+  
   /**
    * Returns the logical dimension of the mesh.
    */
@@ -122,6 +149,23 @@ public:
    */
   virtual unsigned int n_nodes () const = 0; 
 
+  /**
+   * Returns the number of nodes on processor \p proc.
+   */
+  unsigned int n_nodes_on_proc (const unsigned int proc) const;
+
+  /**
+   * Returns the number of nodes on the local processor.
+   */
+  unsigned int n_local_nodes () const
+  { return this->n_nodes_on_proc (libMesh::processor_id()); }
+
+  /**
+   * Returns the number of nodes owned by no processor.
+   */
+  unsigned int n_unpartitioned_nodes () const
+  { return this->n_nodes_on_proc (DofObject::invalid_processor_id); }
+
   /**
    * Returns a number greater than or equal to the maximum node id in the
    * mesh.
@@ -157,6 +201,12 @@ public:
    */
   virtual void reserve_elem (const unsigned int ne) = 0; 
 
+  /**
+   * Updates parallel caches so that methods like n_elem() 
+   * accurately reflect changes on other processors
+   */
+  virtual void update_parallel_id_counts () = 0;
+
   /**
    * Returns the number of active elements in the mesh.  Implemented
    * in terms of active_element_iterators.
@@ -174,6 +224,12 @@ public:
   unsigned int n_local_elem () const
   { return this->n_elem_on_proc (libMesh::processor_id()); }
 
+  /**
+   * Returns the number of elements owned by no processor.
+   */
+  unsigned int n_unpartitioned_elem () const
+  { return this->n_elem_on_proc (DofObject::invalid_processor_id); }
+
   /**
    * Returns the number of active elements on processor \p proc.
    */
@@ -232,18 +288,42 @@ public:
   virtual Elem* elem (const unsigned int i) const = 0;
 
   /**
-   * Add \p Node \p n to the vertex array.  The node will be appended to the
-   * end of the vertex array. 
+   * Add a new \p Node at \p Point \p p to the end of the vertex array,
+   * with processor_id \p procid.
+   * Use DofObject::invalid_processor_id (default) to add a node to all
+   * processors, or libMesh::processor_id() to add a node to the local
+   * processor only.
+   * If adding a node locally, passing an \p id other than
+   * DofObject::invalid_id will set that specific node id.  Only
+   * do this in parallel if you are manually keeping ids consistent.
    */
-  virtual Node* add_point (const Point& n) = 0;
+  virtual Node* add_point (const Point& p,
+			   const unsigned int id = DofObject::invalid_id,
+			   const unsigned int proc_id =
+			     DofObject::invalid_processor_id) = 0;
+
+  /**
+   * Add \p Node \p n to the end of the vertex array.
+   */
+  virtual Node* add_node (Node* n) = 0;
 
   /**
    * Removes the Node n from the mesh.
    */
   virtual void delete_node (Node* n) = 0;
   
+  /**
+   * Changes the id of node \p old_id, both by changing node(old_id)->id() and
+   * by moving node(old_id) in the mesh's internal container.  No element with
+   * the id \p new_id should already exist.
+   */
+  virtual void renumber_node (unsigned int old_id, unsigned int new_id) = 0;
+		      
   /**
    * Add elem \p e to the end of the element array.
+   * To add an element locally, set e->processor_id() before adding it.
+   * To ensure a specific element id, call e->set_id() before adding it;
+   * only do this in parallel if you are manually keeping ids consistent.
    */
   virtual Elem* add_elem (Elem* e) = 0;
 
@@ -256,21 +336,28 @@ public:
   /**
    * Removes element \p e from the mesh. Note that calling this
    * method may produce isolated nodes, i.e. nodes not connected
-   * to any element.
+   * to any element.  This method must be implemented in derived classes
+   * in such a way that it does not invalidate element iterators.
    */
   virtual void delete_elem (Elem* e) = 0;
-		      
+
+  /**
+   * Changes the id of element \p old_id, both by changing elem(old_id)->id()
+   * and by moving elem(old_id) in the mesh's internal container.  No element
+   * with the id \p new_id should already exist.
+   */
+  virtual void renumber_elem (unsigned int old_id, unsigned int new_id) = 0;
+
   /**
    * Locate element face (edge in 2D) neighbors.  This is done with the help
-   * of a \p std::map that functions like a hash table.  When this function is
-   * called only elements with \p NULL neighbor pointers are considered, so
-   * the first call should take the longest.  Subsequent calls will only
-   * consider new elements and the elements that lie on the boundary.
+   * of a \p std::map that functions like a hash table.  
    * After this routine is called all the elements with a \p NULL neighbor
    * pointer are guaranteed to be on the boundary.  Thus this routine is
    * useful for automatically determining the boundaries of the domain.
+   * If reset_remote_elements is left to false, remote neighbor links are not
+   * reset and searched for in the local mesh.
    */
-  virtual void find_neighbors () = 0;
+  virtual void find_neighbors (bool reset_remote_elements = false) = 0;
   
   /**
    * After partitoning a mesh it is useful to renumber the nodes and elements
@@ -356,6 +443,34 @@ public:
    */
   friend std::ostream& operator << (std::ostream& os, const MeshBase& m);
 
+  /**
+   * Interfaces for reading/writing a mesh to/from a file.  Must be
+   * implemented in derived classes.
+   */
+  virtual void read  (const std::string& name, MeshData* mesh_data=NULL) = 0;
+  virtual void write (const std::string& name, MeshData* mesh_data=NULL) = 0;
+
+  /**
+   * Converts a mesh with higher-order
+   * elements into a mesh with linear elements.  For 
+   * example, a mesh consisting of \p Tet10 will be converted
+   * to a mesh with \p Tet4 etc.
+   */
+  virtual void all_first_order () = 0;
+
+  /**
+   * Converts a (conforming, non-refined) mesh with linear 
+   * elements into a mesh with second-order elements.  For 
+   * example, a mesh consisting of \p Tet4 will be converted
+   * to a mesh with \p Tet10 etc.  Note that for some elements
+   * like \p Hex8 there exist @e two higher order equivalents,
+   * \p Hex20 and \p Hex27.  When \p full_ordered is \p true
+   * (default), then \p Hex27 is built.  Otherwise, \p Hex20
+   * is built.  The same holds obviously for \p Quad4, \p Prism6
+   * ...
+   */
+  virtual void all_second_order (const bool full_ordered=true) = 0;
+
   /**
    * We need an empty, generic class to act as a predicate for this
    * and derived mesh classes.
@@ -416,10 +531,14 @@ public:
   virtual element_iterator elements_end                     () = 0;
   virtual element_iterator active_elements_begin            () = 0;
   virtual element_iterator active_elements_end              () = 0;
+  virtual element_iterator ancestor_elements_begin          () = 0;
+  virtual element_iterator ancestor_elements_end            () = 0;
   virtual element_iterator subactive_elements_begin         () = 0;
   virtual element_iterator subactive_elements_end           () = 0;
   virtual element_iterator not_active_elements_begin        () = 0;
   virtual element_iterator not_active_elements_end          () = 0;
+  virtual element_iterator not_ancestor_elements_begin      () = 0;
+  virtual element_iterator not_ancestor_elements_end        () = 0;
   virtual element_iterator not_subactive_elements_begin     () = 0;
   virtual element_iterator not_subactive_elements_end       () = 0;
   virtual element_iterator local_elements_begin             () = 0;
@@ -430,18 +549,24 @@ public:
   virtual element_iterator active_local_elements_end        () = 0;
   virtual element_iterator active_not_local_elements_begin  () = 0;
   virtual element_iterator active_not_local_elements_end    () = 0;
-  virtual element_iterator level_elements_begin         (const unsigned int level  ) = 0;
-  virtual element_iterator level_elements_end           (const unsigned int level  ) = 0;
-  virtual element_iterator not_level_elements_begin     (const unsigned int level  ) = 0;
-  virtual element_iterator not_level_elements_end       (const unsigned int level  ) = 0;
-  virtual element_iterator pid_elements_begin           (const unsigned int proc_id) = 0;
-  virtual element_iterator pid_elements_end             (const unsigned int proc_id) = 0;
-  virtual element_iterator type_elements_begin          (const ElemType type       ) = 0;
-  virtual element_iterator type_elements_end            (const ElemType type       ) = 0;
-  virtual element_iterator active_type_elements_begin   (const ElemType type       ) = 0;
-  virtual element_iterator active_type_elements_end     (const ElemType type       ) = 0;
-  virtual element_iterator active_pid_elements_begin    (const unsigned int proc_id) = 0;
-  virtual element_iterator active_pid_elements_end      (const unsigned int proc_id) = 0;
+  virtual element_iterator level_elements_begin             (const unsigned int level  ) = 0;
+  virtual element_iterator level_elements_end               (const unsigned int level  ) = 0;
+  virtual element_iterator not_level_elements_begin         (const unsigned int level  ) = 0;
+  virtual element_iterator not_level_elements_end           (const unsigned int level  ) = 0;
+  virtual element_iterator local_level_elements_begin       (const unsigned int level  ) = 0;
+  virtual element_iterator local_level_elements_end         (const unsigned int level  ) = 0;
+  virtual element_iterator local_not_level_elements_begin   (const unsigned int level  ) = 0;
+  virtual element_iterator local_not_level_elements_end     (const unsigned int level  ) = 0;
+  virtual element_iterator pid_elements_begin               (const unsigned int proc_id) = 0;
+  virtual element_iterator pid_elements_end                 (const unsigned int proc_id) = 0;
+  virtual element_iterator type_elements_begin              (const ElemType type       ) = 0;
+  virtual element_iterator type_elements_end                (const ElemType type       ) = 0;
+  virtual element_iterator active_type_elements_begin       (const ElemType type       ) = 0;
+  virtual element_iterator active_type_elements_end         (const ElemType type       ) = 0;
+  virtual element_iterator active_pid_elements_begin        (const unsigned int proc_id) = 0;
+  virtual element_iterator active_pid_elements_end          (const unsigned int proc_id) = 0;
+  virtual element_iterator unpartitioned_elements_begin     () = 0;
+  virtual element_iterator unpartitioned_elements_end       () = 0;
 
   
   
@@ -452,10 +577,14 @@ public:
   virtual const_element_iterator elements_end                     () const = 0;
   virtual const_element_iterator active_elements_begin            () const = 0;
   virtual const_element_iterator active_elements_end              () const = 0;
+  virtual const_element_iterator ancestor_elements_begin          () const = 0;
+  virtual const_element_iterator ancestor_elements_end            () const = 0;
   virtual const_element_iterator subactive_elements_begin         () const = 0;
   virtual const_element_iterator subactive_elements_end           () const = 0;
   virtual const_element_iterator not_active_elements_begin        () const = 0;
   virtual const_element_iterator not_active_elements_end          () const = 0;
+  virtual const_element_iterator not_ancestor_elements_begin      () const = 0;
+  virtual const_element_iterator not_ancestor_elements_end        () const = 0;
   virtual const_element_iterator not_subactive_elements_begin     () const = 0;
   virtual const_element_iterator not_subactive_elements_end       () const = 0;
   virtual const_element_iterator local_elements_begin             () const = 0;
@@ -466,18 +595,24 @@ public:
   virtual const_element_iterator active_local_elements_end        () const = 0;
   virtual const_element_iterator active_not_local_elements_begin  () const = 0;
   virtual const_element_iterator active_not_local_elements_end    () const = 0;
-  virtual const_element_iterator level_elements_begin         (const unsigned int level)   const = 0;
-  virtual const_element_iterator level_elements_end           (const unsigned int level)   const = 0;
-  virtual const_element_iterator not_level_elements_begin     (const unsigned int level)   const = 0;
-  virtual const_element_iterator not_level_elements_end       (const unsigned int level)   const = 0;
-  virtual const_element_iterator pid_elements_begin           (const unsigned int proc_id) const = 0;
-  virtual const_element_iterator pid_elements_end             (const unsigned int proc_id) const = 0;
-  virtual const_element_iterator type_elements_begin          (const ElemType type)        const = 0;
-  virtual const_element_iterator type_elements_end            (const ElemType type)        const = 0;
-  virtual const_element_iterator active_type_elements_begin   (const ElemType type)        const = 0;
-  virtual const_element_iterator active_type_elements_end     (const ElemType type)        const = 0;
-  virtual const_element_iterator active_pid_elements_begin    (const unsigned int proc_id) const = 0;
-  virtual const_element_iterator active_pid_elements_end      (const unsigned int proc_id) const = 0;
+  virtual const_element_iterator level_elements_begin             (const unsigned int level)   const = 0;
+  virtual const_element_iterator level_elements_end               (const unsigned int level)   const = 0;
+  virtual const_element_iterator not_level_elements_begin         (const unsigned int level)   const = 0;
+  virtual const_element_iterator not_level_elements_end           (const unsigned int level)   const = 0;
+  virtual const_element_iterator local_level_elements_begin       (const unsigned int level)   const = 0;
+  virtual const_element_iterator local_level_elements_end         (const unsigned int level)   const = 0;
+  virtual const_element_iterator local_not_level_elements_begin   (const unsigned int level)   const = 0;
+  virtual const_element_iterator local_not_level_elements_end     (const unsigned int level)   const = 0;
+  virtual const_element_iterator pid_elements_begin               (const unsigned int proc_id) const = 0;
+  virtual const_element_iterator pid_elements_end                 (const unsigned int proc_id) const = 0;
+  virtual const_element_iterator type_elements_begin              (const ElemType type)        const = 0;
+  virtual const_element_iterator type_elements_end                (const ElemType type)        const = 0;
+  virtual const_element_iterator active_type_elements_begin       (const ElemType type)        const = 0;
+  virtual const_element_iterator active_type_elements_end         (const ElemType type)        const = 0;
+  virtual const_element_iterator active_pid_elements_begin        (const unsigned int proc_id) const = 0;
+  virtual const_element_iterator active_pid_elements_end          (const unsigned int proc_id) const = 0;
+  virtual const_element_iterator unpartitioned_elements_begin     () const = 0;
+  virtual const_element_iterator unpartitioned_elements_end       () const = 0;
 
   
   /**
