@@ -1,4 +1,4 @@
-// $Id: mesh_generation.h,v 1.15 2007-10-21 20:48:42 benkirk Exp $
+// $Id: mesh_generation.h 2788 2008-04-13 02:05:22Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -47,7 +47,7 @@ namespace MeshTools
    *
    * \author Benjamin S. Kirk
    * \date 2004
-   * \version $Revision: 1.15 $
+   * \version $Revision: 2788 $
    */
   namespace Generation
   {
@@ -132,7 +132,7 @@ namespace MeshTools
 	  default:
 	    {
 	      std::cerr << "ERROR: Unrecognized 2D element type." << std::endl;
-	      error();
+	      libmesh_error();
 	    }
 	  }
 
@@ -174,7 +174,7 @@ namespace MeshTools
 	  default:
 	    {
 	      std::cerr << "ERROR: Unrecognized element type." << std::endl;
-	      error();
+	      libmesh_error();
 	    }
 	  }
       
