@@ -1,4 +1,4 @@
-// $Id: mesh_input.h,v 1.3 2007-10-21 20:48:42 benkirk Exp $
+// $Id: mesh_input.h 2832 2008-05-06 18:42:22Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -29,7 +29,7 @@
 
 // Local includes
 #include "libmesh_common.h"
-
+#include "mesh_base.h"
 
 
 
@@ -40,7 +40,7 @@
  *
  * \author Benjamin S. Kirk
  * \date 2004
- * \version $Revision: 1.3 $
+ * \version $Revision: 2832 $
  */
 
 // ------------------------------------------------------------
@@ -54,13 +54,13 @@ class MeshInput
    * Default constructor. Will set the _obj to NULL, effectively
    * rendering this object useless.
    */
-  MeshInput ();
+  MeshInput (bool is_parallel_format = false);
   
   /**
    * Constructor.  Takes a writeable reference to an object.
    * This is the constructor required to read an object.
    */
-  MeshInput (MT&);
+  MeshInput (MT&, const bool is_parallel_format = false);
   
  public:
 
@@ -98,6 +98,13 @@ class MeshInput
    * This allows us to read the object from file.
    */ 
   MT* _obj;
+
+  /**
+   * Flag specifying whether this format is parallel-capable.
+   * If this is false (default) I/O is only permitted when the mesh
+   * has been serialized.
+   */
+  const bool _is_parallel_format;
 };
 
 
@@ -106,8 +113,9 @@ class MeshInput
 // MeshInput inline members
 template <class MT>
 inline
-MeshInput<MT>::MeshInput () :
-  _obj (NULL)
+MeshInput<MT>::MeshInput (const bool is_parallel_format) :
+  _obj (NULL),
+  _is_parallel_format(is_parallel_format)
 {
 }
 
@@ -115,9 +123,20 @@ MeshInput<MT>::MeshInput () :
 
 template <class MT>
 inline
-MeshInput<MT>::MeshInput (MT& obj) :
-  _obj (&obj)
+MeshInput<MT>::MeshInput (MT& obj, const bool is_parallel_format) :
+  _obj (&obj),
+  _is_parallel_format(is_parallel_format)
 {
+  if (!_is_parallel_format && !this->mesh().is_serial())
+    {
+      if (libMesh::processor_id() == 0)
+	{
+          std::cerr << "Warning:  This I/O operation may only be supported for meshes which have been serialized!"
+		    << std::endl;
+          here();
+        }
+//      libmesh_error();
+    }
 }
 
 
@@ -134,7 +153,7 @@ template <class MT>
 inline
 MT& MeshInput<MT>::mesh ()
 {
-  if (_obj == NULL) error();
+  if (_obj == NULL) libmesh_error();
   return *_obj;
 }
 
