@@ -1,4 +1,4 @@
-// $Id: mesh_output.h,v 1.4 2007-10-21 20:48:42 benkirk Exp $
+// $Id: mesh_output.h 2832 2008-05-06 18:42:22Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -29,6 +29,7 @@
 
 // Local includes
 #include "libmesh_common.h"
+#include "mesh_base.h"
 
 // Forward declares
 class EquationSystems;
@@ -41,7 +42,7 @@ class EquationSystems;
  *
  * \author Benjamin S. Kirk
  * \date 2004
- * \version $Revision: 1.4 $
+ * \version $Revision: 2832 $
  */
 
 // ------------------------------------------------------------
@@ -55,13 +56,13 @@ class MeshOutput
    * Default constructor. Will set the _obj to NULL, effectively
    * rendering this object useless.
    */
-  MeshOutput ();
+  MeshOutput (const bool is_parallel_format = false);
   
   /**
    * Constructor.  Takes a reference to a constant object.
    * This constructor will only allow us to write the object.
    */
-  MeshOutput (const MT&);
+  MeshOutput (const MT&, const bool is_parallel_format = false);
 
   
  public:
@@ -89,7 +90,8 @@ class MeshOutput
    */
   virtual void write_nodal_data (const std::string&,
 				 const std::vector<Number>&,
-				 const std::vector<std::string>&) { error(); }
+				 const std::vector<std::string>&)
+  { libmesh_error(); }
 
   
  protected:
@@ -110,6 +112,13 @@ class MeshOutput
    */
   const MT* const _obj;
 
+  /**
+   * Flag specifying whether this format is parallel-capable.
+   * If this is false (default) I/O is only permitted when the mesh
+   * has been serialized.
+   */
+  const bool _is_parallel_format;
+
   /**
    * A helper function which allows us to fill temporary
    * name and solution vectors with an EquationSystems object
@@ -125,9 +134,29 @@ class MeshOutput
 // MeshOutput inline members
 template <class MT>
 inline
-MeshOutput<MT>::MeshOutput (const MT& obj) :
-  _obj (&obj)
+MeshOutput<MT>::MeshOutput (const bool is_parallel_format) :
+  _obj(NULL),
+  _is_parallel_format(is_parallel_format)
+{}
+
+
+
+template <class MT>
+inline
+MeshOutput<MT>::MeshOutput (const MT& obj, const bool is_parallel_format) :
+  _obj (&obj),
+  _is_parallel_format(is_parallel_format)
 {
+  if (!_is_parallel_format && !this->mesh().is_serial())
+    {
+      if (libMesh::processor_id() == 0)
+	{
+          std::cerr << "WARNING:  This I/O operation may only be supported for meshes which have been serialized!"
+		    << std::endl;
+          here();
+        }
+//      libmesh_error();
+    }
 }
 
 
@@ -163,7 +192,7 @@ template <class MT>
 inline
 const MT& MeshOutput<MT>::mesh () const
 {
-  assert (_obj != NULL);
+  libmesh_assert (_obj != NULL);
   return *_obj;
 }
 
