@@ -1,4 +1,4 @@
-// $Id: mesh_refinement.h,v 1.27 2007-10-21 20:48:42 benkirk Exp $
+// $Id: mesh_refinement.h 2822 2008-05-01 20:43:09Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -30,22 +30,13 @@
 
 // C++ Includes   -----------------------------------
 #include <vector>
-#include <list>
-
-#if   defined(HAVE_HASH_MAP)
-# include <hash_map>
-#elif defined(HAVE_EXT_HASH_MAP)
-# include <ext/hash_map>
-#else
-# include <map>
-#endif
 
 // Local Includes -----------------------------------
 #include "libmesh_common.h"
 #include "libmesh.h" // libMesh::invalid_uint
+#include "location_maps.h"
 
-//#include "node.h" // remove this when debugging is done, only need forward dec.
-
+// Forward Declarations -----------------------------
 class MeshBase;
 class Point;
 class Node;
@@ -248,27 +239,30 @@ public:
   /**
    * Returns true if and only if the mesh is level one smooth
    * Returns false otherwise
-   * Aborts the program if assert_yes is true and 
+   * Aborts the program if libmesh_assert_yes is true and 
    * the mesh is not level one smooth
    */
-  bool test_level_one (bool assert_yes = false);
+  bool test_level_one (bool libmesh_assert_yes = false);
   
   /**
    * Returns true if and only if the mesh has no elements
    * flagged to be coarsened or refined
    * Returns false otherwise
-   * Aborts the program if assert_yes is true and 
+   * Aborts the program if libmesh_assert_yes is true and 
    * the mesh has flagged elements
    */
-  bool test_unflagged (bool assert_yes = false);
+  bool test_unflagged (bool libmesh_assert_yes = false);
   
   /**
    * Add point \p p to the mesh. The function returns a pointer to
-   * the new node.  The \p key tells the method where to look.  The
-   * tolerance \p tol tells the method how far away from p to search
-   * for existing nodes.
+   * the new node.
+   * The processor_id is assigned to the new node (only if no existing
+   * node is found.  The tolerance \p tol tells the method how far away
+   * from p to search for existing nodes.
    */
-  Node* add_point (const Point& p, const unsigned int key, const Real tol);
+  Node* add_point (const Point& p,
+                   const unsigned int processor_id,
+                   const Real tol);
 
   /**
    * Adds the element \p elem to the mesh.
@@ -584,29 +578,16 @@ private:
   bool make_refinement_compatible (const bool);
   
   /**
-   * Data structure that holds the new nodes information.
-   * The key is a pointer to the element that created the node.
-   * For efficiency we will use a hashed multimap if it is
-   * available, otherwise a regular multimap.
+   * Copy refinement flags on ghost elements from their
+   * local processors.  Return true if any flags changed.
    */
-#if   defined(HAVE_HASH_MAP)    
-    typedef std::hash_multimap<unsigned int, Node*> map_type;    
-#elif defined(HAVE_EXT_HASH_MAP)
-# if   (__GNUC__ == 3) && (__GNUC_MINOR__ == 0) // gcc 3.0   
-    typedef std::hash_multimap<unsigned int, Node*> map_type;
-# elif (__GNUC__ >= 3)                          // gcc 3.1 & newer
-    typedef __gnu_cxx::hash_multimap<unsigned int, Node*> map_type;
-# else
-// XLC and who knows what other compilers get here.
-// Try the most standard thing we can:
-    typedef std::multimap<unsigned int, Node*> map_type;
-# endif
-#else
-    typedef std::multimap<unsigned int, Node*> map_type;
-#endif
+  bool make_flags_parallel_consistent ();
   
-  map_type _new_nodes_map;
-
+  /**
+   * Data structure that holds the new nodes information.
+   */
+  
+  LocationMap<Node> _new_nodes_map;
 
   /**
    * Reference to the mesh.
