@@ -1,4 +1,4 @@
-// $Id: mesh_triangle_support.h,v 1.12 2007-10-21 20:48:42 benkirk Exp $
+// $Id: mesh_triangle_support.h 2789 2008-04-13 02:24:40Z roystgnr $
  
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -405,7 +405,7 @@ public:
    */
   virtual Point point(const unsigned int n) const
   {
-    assert (n < _points.size());
+    libmesh_assert (n < _points.size());
     return _points[n];
   }
 
