@@ -1,4 +1,4 @@
-// $Id: unv_io.h,v 1.10 2007-10-21 20:48:42 benkirk Exp $
+// $Id: unv_io.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -278,8 +278,8 @@ inline
 bool UNVIO::beginning_of_dataset (std::istream& in_file, 
 				  const std::string& ds_name) const
 {
-  assert (in_file.good());
-  assert (!ds_name.empty());
+  libmesh_assert (in_file.good());
+  libmesh_assert (!ds_name.empty());
 
   std::string olds, news;
 
@@ -305,7 +305,7 @@ bool UNVIO::beginning_of_dataset (std::istream& in_file,
     }
 
   // should never end up here
-  error();
+  libmesh_error();
   return false;
 }
 
@@ -327,7 +327,7 @@ Real UNVIO::D_to_e (std::string& number) const
   const std::string::size_type position = number.find("D",6);
 #endif
 
-  assert (position != std::string::npos);
+  libmesh_assert (position != std::string::npos);
   number.replace(position, 1, "e"); 
 
   return std::atof (number.c_str());
