@@ -1,4 +1,4 @@
-// $Id: analytic_function.h,v 1.4 2007-10-21 20:48:43 benkirk Exp $
+// $Id: analytic_function.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -114,7 +114,7 @@ inline
 Number AnalyticFunction::operator() (const Point& p, 
 				     const Real time)
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   return (this->_number_fptr(p, time));
 }
 
@@ -125,7 +125,7 @@ void AnalyticFunction::operator() (const Point& p,
 				   const Real time,
 				   DenseVector<Number>& output)
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   this->_vector_fptr(output, p, time);
   return;
 }
