@@ -1,4 +1,4 @@
-// $Id: coupling_matrix.h,v 1.7 2007-10-21 20:48:43 benkirk Exp $
+// $Id: coupling_matrix.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -118,8 +118,8 @@ inline
 unsigned char CouplingMatrix::operator() (const unsigned int i,
 					  const unsigned int j) const
 {
-  assert (i < _size);
-  assert (j < _size);
+  libmesh_assert (i < _size);
+  libmesh_assert (j < _size);
 
   return _values[i*_size + j];
 }
@@ -130,8 +130,8 @@ inline
 unsigned char & CouplingMatrix::operator() (const unsigned int i,
 					    const unsigned int j)
 {
-  assert (i < _size);
-  assert (j < _size);
+  libmesh_assert (i < _size);
+  libmesh_assert (j < _size);
 
   return _values[i*_size + j];
 }
