@@ -1,4 +1,4 @@
-// $Id: dense_subvector.h,v 1.7 2007-10-21 20:48:43 benkirk Exp $
+// $Id: dense_subvector.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -151,7 +151,7 @@ void DenseSubVector<T>::reposition(const unsigned int ioff,
   _n = n;
 
   // Make sure we still fit in the parent vector.
-  assert ((this->i_off() + this->size()) <= _parent_vector.size());
+  libmesh_assert ((this->i_off() + this->size()) <= _parent_vector.size());
 }
 
 
@@ -170,8 +170,8 @@ template<typename T>
 inline
 T DenseSubVector<T>::operator () (const unsigned int i) const
 {
-  assert (i < this->size());
-  assert (i + this->i_off() < _parent_vector.size());
+  libmesh_assert (i < this->size());
+  libmesh_assert (i + this->i_off() < _parent_vector.size());
   
   return _parent_vector (i + this->i_off());
 }
@@ -181,8 +181,8 @@ template<typename T>
 inline
 T & DenseSubVector<T>::operator () (const unsigned int i)
 {
-  assert (i < this->size());
-  assert (i + this->i_off() < _parent_vector.size());
+  libmesh_assert (i < this->size());
+  libmesh_assert (i + this->i_off() < _parent_vector.size());
   
   return _parent_vector (i + this->i_off());
 }
