@@ -1,4 +1,4 @@
-// $Id: distributed_vector.h,v 1.15 2007-10-21 20:48:43 benkirk Exp $
+// $Id: distributed_vector.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -32,10 +32,8 @@
 // C++ includes
 #include <vector>
 #include <algorithm>
-
-#ifdef HAVE_MPI
-# include <mpi.h>
-#endif
+#include <complex>
+#include <limits>
 
 // Local includes
 #include "numeric_vector.h"
@@ -283,7 +281,7 @@ public:
    */
   void add_vector (const NumericVector<T>&,
 		   const SparseMatrix<T>&)
-  { error(); }
+  { libmesh_error(); }
   
   /**
    * \f$U+=V\f$ where U and V are type 
@@ -328,7 +326,7 @@ public:
   /**
    * Computes the dot product, p = U.V
    */
-  virtual Number dot(const NumericVector<T>& V) const;
+  virtual T dot(const NumericVector<T>& V) const;
   
   /**
    * Creates a copy of the global vector in the
@@ -397,7 +395,6 @@ private:
 };
 
 
-
 //--------------------------------------------------------------------------
 // DistributedVector inline methods
 template <typename T>
@@ -446,7 +443,10 @@ void DistributedVector<T>::init (const unsigned int n,
 				 const unsigned int n_local,
 				 const bool fast)
 {
-  assert (n_local <= n);
+  // This function must be run on all processors at once
+  parallel_only();
+
+  libmesh_assert (n_local <= n);
 
   // Clear the data structures if already initialized
   if (this->initialized())
@@ -486,7 +486,7 @@ void DistributedVector<T>::init (const unsigned int n,
   for (int p=0; p<n_proc; p++)
     sum += local_sizes[p];
 
-  assert (sum == static_cast<int>(n));
+  libmesh_assert (sum == static_cast<int>(n));
   
 #  endif
   
@@ -497,7 +497,7 @@ void DistributedVector<T>::init (const unsigned int n,
     {
       std::cerr << "ERROR:  MPI is required for n != n_local!"
 		<< std::endl;
-      error();
+      libmesh_error();
     }
   
 #endif
@@ -528,7 +528,7 @@ template <typename T>
 inline
 void DistributedVector<T>::close ()
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   this->_is_closed = true;
 }
@@ -556,9 +556,9 @@ template <typename T>
 inline
 void DistributedVector<T>::zero ()
 {
-  assert (this->initialized());
-  assert (_values.size() == _local_size);
-  assert ((_last_local_index - _first_local_index) == _local_size);
+  libmesh_assert (this->initialized());
+  libmesh_assert (_values.size() == _local_size);
+  libmesh_assert ((_last_local_index - _first_local_index) == _local_size);
   
   std::fill (_values.begin(),
 	     _values.end(),
@@ -584,9 +584,9 @@ template <typename T>
 inline
 unsigned int DistributedVector<T>::size () const
 {
-  assert (this->initialized());
-  assert (_values.size() == _local_size);
-  assert ((_last_local_index - _first_local_index) == _local_size);
+  libmesh_assert (this->initialized());
+  libmesh_assert (_values.size() == _local_size);
+  libmesh_assert ((_last_local_index - _first_local_index) == _local_size);
 
   return _global_size;
 }
@@ -597,9 +597,9 @@ template <typename T>
 inline
 unsigned int DistributedVector<T>::local_size () const
 {
-  assert (this->initialized());
-  assert (_values.size() == _local_size);
-  assert ((_last_local_index - _first_local_index) == _local_size);
+  libmesh_assert (this->initialized());
+  libmesh_assert (_values.size() == _local_size);
+  libmesh_assert ((_last_local_index - _first_local_index) == _local_size);
 
   return _local_size;
 }
@@ -610,9 +610,9 @@ template <typename T>
 inline
 unsigned int DistributedVector<T>::first_local_index () const
 {
-  assert (this->initialized());
-  assert (_values.size() == _local_size);
-  assert ((_last_local_index - _first_local_index) == _local_size);
+  libmesh_assert (this->initialized());
+  libmesh_assert (_values.size() == _local_size);
+  libmesh_assert ((_last_local_index - _first_local_index) == _local_size);
 
   return _first_local_index;
 }
@@ -623,9 +623,9 @@ template <typename T>
 inline
 unsigned int DistributedVector<T>::last_local_index () const
 {
-  assert (this->initialized());
-  assert (_values.size() == _local_size);
-  assert ((_last_local_index - _first_local_index) == _local_size);
+  libmesh_assert (this->initialized());
+  libmesh_assert (_values.size() == _local_size);
+  libmesh_assert ((_last_local_index - _first_local_index) == _local_size);
 
   return _last_local_index;
 }
@@ -636,10 +636,10 @@ template <typename T>
 inline
 T DistributedVector<T>::operator() (const unsigned int i) const
 {
-  assert (this->initialized());
-  assert (_values.size() == _local_size);
-  assert ((_last_local_index - _first_local_index) == _local_size);
-  assert ( ((i >= first_local_index()) &&
+  libmesh_assert (this->initialized());
+  libmesh_assert (_values.size() == _local_size);
+  libmesh_assert ((_last_local_index - _first_local_index) == _local_size);
+  libmesh_assert ( ((i >= first_local_index()) &&
 	    (i <  last_local_index())) );
 
   return _values[i - _first_local_index];
@@ -651,11 +651,11 @@ template <typename T>
 inline
 void DistributedVector<T>::set (const unsigned int i, const T value)
 {
-  assert (this->initialized());
-  assert (_values.size() == _local_size);
-  assert ((_last_local_index - _first_local_index) == _local_size);
-  assert (i<size());
-  assert (i-first_local_index() < local_size());
+  libmesh_assert (this->initialized());
+  libmesh_assert (_values.size() == _local_size);
+  libmesh_assert ((_last_local_index - _first_local_index) == _local_size);
+  libmesh_assert (i<size());
+  libmesh_assert (i-first_local_index() < local_size());
   
   _values[i - _first_local_index] = value;
 }
@@ -666,11 +666,11 @@ template <typename T>
 inline
 void DistributedVector<T>::add (const unsigned int i, const T value)
 {
-  assert (this->initialized());
-  assert (_values.size() == _local_size);
-  assert ((_last_local_index - _first_local_index) == _local_size);
-  assert (i<size());
-  assert (i-first_local_index() < local_size());
+  libmesh_assert (this->initialized());
+  libmesh_assert (_values.size() == _local_size);
+  libmesh_assert ((_last_local_index - _first_local_index) == _local_size);
+  libmesh_assert (i<size());
+  libmesh_assert (i-first_local_index() < local_size());
   
   _values[i - _first_local_index] += value;
 }
@@ -681,12 +681,17 @@ template <typename T>
 inline
 Real DistributedVector<T>::min () const
 {
-  assert (this->initialized());
-  assert (_values.size() == _local_size);
-  assert ((_last_local_index - _first_local_index) == _local_size);
+  // This function must be run on all processors at once
+  parallel_only();
 
-  double local_min = static_cast<double>(*std::min(_values.begin(),
-						   _values.end()));
+  libmesh_assert (this->initialized());
+  libmesh_assert (_values.size() == _local_size);
+  libmesh_assert ((_last_local_index - _first_local_index) == _local_size);
+
+  Real local_min = _values.size() ? 
+    libmesh_real(_values[0]) : std::numeric_limits<Real>::max();
+  for (unsigned int i = 1; i < _values.size(); ++i)
+    local_min = std::min(libmesh_real(_values[i]), local_min);
   
   Parallel::min(local_min);
 
@@ -699,17 +704,21 @@ template <typename T>
 inline
 Real DistributedVector<T>::max() const
 {
-  assert (this->initialized());
-  assert (_values.size() == _local_size);
-  assert ((_last_local_index - _first_local_index) == _local_size);
+  // This function must be run on all processors at once
+  parallel_only();
 
-  double local_max = static_cast<double>(*std::max(_values.begin(),
-						   _values.end()));
+  libmesh_assert (this->initialized());
+  libmesh_assert (_values.size() == _local_size);
+  libmesh_assert ((_last_local_index - _first_local_index) == _local_size);
 
+  Real local_max = _values.size() ? 
+    libmesh_real(_values[0]) : -std::numeric_limits<Real>::max();
+  for (unsigned int i = 1; i < _values.size(); ++i)
+    local_max = std::max(libmesh_real(_values[i]), local_max);
+  
   Parallel::max(local_max);
 
   return local_max;
 }
 
-
 #endif  // #ifdef __distributed_vector_h__
