@@ -1,4 +1,4 @@
-// $Id: laspack_linear_solver.h,v 1.3 2007-10-21 20:48:43 benkirk Exp $
+// $Id: laspack_linear_solver.h 2788 2008-04-13 02:05:22Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -94,6 +94,12 @@ class LaspackLinearSolver : public LinearSolver<T>
 	   const double tol,
 	   const unsigned int m_its);
    
+  /**
+   * Prints a useful message about why the latest linear solve
+   * con(di)verged.
+   */
+  virtual void print_converged_reason();
+  
  private:
   
   /**
@@ -140,7 +146,7 @@ LaspackLinearSolver<T>::solve (SparseMatrix<T>&,
 {
   std::cerr << "ERROR: LASPACK does not support a user-supplied preconditioner!"
 	    << std::endl;
-  error();
+  libmesh_error();
 
   std::pair<unsigned int, Real> p;
   return p;
