@@ -1,4 +1,4 @@
-// $Id: linear_solver.h,v 1.3 2007-10-21 20:48:43 benkirk Exp $
+// $Id: linear_solver.h 2501 2007-11-20 02:33:29Z benkirk $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -140,6 +140,12 @@ public:
 					       const double,      // Stopping tolerance
 					       const unsigned int) = 0; // N. Iterations
   
+  /**
+   * Prints a useful message about why the latest linear solve
+   * con(di)verged.
+   */
+  virtual void print_converged_reason() = 0;
+  
 protected:
 
   
