@@ -1,4 +1,4 @@
-// $Id: numeric_vector.h,v 1.18 2007-10-21 20:48:43 benkirk Exp $
+// $Id: numeric_vector.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -351,7 +351,7 @@ public:
   /**
    * Computes the dot product, p = U.V
    */
-  virtual Number dot(const NumericVector<T>&) const = 0;
+  virtual T dot(const NumericVector<T>&) const = 0;
   
   /**
    * Creates a copy of the global vector in the
@@ -430,7 +430,7 @@ public:
   {
     std::cerr << "ERROR: Not Implemented in base class yet!" << std::endl;
     std::cerr << "ERROR writing MATLAB file " << name << std::endl;
-    error();
+    libmesh_error();
   }
 
   /**
@@ -443,7 +443,7 @@ public:
 				const std::vector<unsigned int>& ) const
   {
     std::cerr << "ERROR: Not Implemented in base class yet!" << std::endl;
-    error();
+    libmesh_error();
   }
     
 protected:
@@ -513,7 +513,7 @@ template <typename T>
 inline
 NumericVector<T> & NumericVector<T>::operator= (const T) 
 {
-  //  error();
+  //  libmesh_error();
 
   return *this;
 }
@@ -524,7 +524,7 @@ template <typename T>
 inline
 NumericVector<T> & NumericVector<T>::operator= (const NumericVector<T>&) 
 {
-  //  error();
+  //  libmesh_error();
 
   return *this;
 }
@@ -535,7 +535,7 @@ template <typename T>
 inline
 NumericVector<T> & NumericVector<T>::operator= (const std::vector<T>&) 
 {
-  //  error();
+  //  libmesh_error();
 
   return *this;
 }
@@ -560,7 +560,7 @@ template <>
 inline
 void NumericVector<Complex>::print(std::ostream& os) const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   os << "Size\tglobal =  " << this->size()
      << "\t\tlocal =  " << this->local_size() << std::endl;
   
@@ -578,7 +578,7 @@ template <typename T>
 inline
 void NumericVector<T>::print(std::ostream& os) const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   os << "Size\tglobal =  " << this->size()
      << "\t\tlocal =  " << this->local_size() << std::endl;
 
@@ -593,7 +593,7 @@ template <>
 inline
 void NumericVector<Complex>::print_global(std::ostream& os) const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
 
   std::vector<Complex> v(this->size());
   this->localize(v);
@@ -615,7 +615,7 @@ template <typename T>
 inline
 void NumericVector<T>::print_global(std::ostream& os) const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
 
   std::vector<T> v(this->size());
   this->localize(v);
