@@ -1,4 +1,4 @@
-// $Id: petsc_linear_solver.h,v 1.6 2007-10-21 20:48:43 benkirk Exp $
+// $Id: petsc_linear_solver.h 2501 2007-11-20 02:33:29Z benkirk $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -153,6 +153,12 @@ public:
    * and not the entire history.
    */
   Real get_initial_residual();
+
+  /**
+   * Prints a useful message about why the latest linear solve
+   * con(di)verged.
+   */
+  virtual void print_converged_reason();
   
 private:
 
