@@ -1,4 +1,4 @@
-// $Id: petsc_matrix.h,v 1.18 2007-10-21 20:48:43 benkirk Exp $
+// $Id: petsc_matrix.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -26,10 +26,6 @@
 
 #ifdef HAVE_PETSC
 
-// TODO:[BSK} This seems necessary to use petsc on IBM Power3 at NERSC, but only there?  
-//#include <cmath>
-
-
 // C++ includes
 #include <algorithm>
 
@@ -288,12 +284,17 @@ public:
    */
   void print_matlab(const std::string name="NULL") const;
 
+  /**
+   * Swaps the raw PETSc matrix context pointers.
+   */
+  void swap (PetscMatrix<T> &);
+
   /**
    * Returns the raw PETSc matrix context pointer.  Note this is generally
    * not required in user-level code. Just don't do anything crazy like
    * calling MatDestroy()!
    */
-  Mat mat () { assert (_mat != NULL); return _mat; }
+  Mat mat () { libmesh_assert (_mat != NULL); return _mat; }
 
   
 protected:
@@ -323,7 +324,7 @@ private:
    * This boolean value should only be set to false
    * for the constructor which takes a PETSc Mat object. 
    */
-  const bool _destroy_mat_on_exit;
+  bool _destroy_mat_on_exit;
 };
 
 
@@ -386,7 +387,7 @@ template <typename T>
 inline
 unsigned int PetscMatrix<T>::m () const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int petsc_m=0, petsc_n=0, ierr=0;
 
@@ -401,7 +402,7 @@ template <typename T>
 inline
 unsigned int PetscMatrix<T>::n () const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int petsc_m=0, petsc_n=0, ierr=0;
 
@@ -416,7 +417,7 @@ template <typename T>
 inline
 unsigned int PetscMatrix<T>::row_start () const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int start=0, stop=0, ierr=0;
 
@@ -432,7 +433,7 @@ template <typename T>
 inline
 unsigned int PetscMatrix<T>::row_stop () const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int start=0, stop=0, ierr=0;
 
@@ -450,7 +451,7 @@ void PetscMatrix<T>::set (const unsigned int i,
 			  const unsigned int j,
 			  const T value)
 {  
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int ierr=0, i_val=i, j_val=j;
 
@@ -468,7 +469,7 @@ void PetscMatrix<T>::add (const unsigned int i,
 			  const unsigned int j,
 			  const T value)
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int ierr=0, i_val=i, j_val=j;
 
@@ -498,17 +499,17 @@ template <typename T>
 inline
 void PetscMatrix<T>::add (const T a_in, SparseMatrix<T> &X_in)
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
 
   // sanity check. but this cannot avoid 
   // crash due to incompatible sparsity structure...
-  assert (this->m() == X_in.m());
-  assert (this->n() == X_in.n());
+  libmesh_assert (this->m() == X_in.m());
+  libmesh_assert (this->n() == X_in.n());
 
   PetscScalar     a = static_cast<PetscScalar>      (a_in);
   PetscMatrix<T>* X = dynamic_cast<PetscMatrix<T>*> (&X_in);
 
-  assert (X != NULL);
+  libmesh_assert (X != NULL);
   
   int ierr=0;
 
@@ -524,7 +525,7 @@ void PetscMatrix<T>::add (const T a_in, SparseMatrix<T> &X_in)
 // 2.3.x & newer
 #else
   
-  ierr = MatAXPY(_mat, a, X->_mat, SAME_NONZERO_PATTERN);
+  ierr = MatAXPY(_mat, a, X->_mat, DIFFERENT_NONZERO_PATTERN);
          CHKERRABORT(libMesh::COMM_WORLD,ierr);
 	 
 #endif
@@ -538,7 +539,7 @@ inline
 T PetscMatrix<T>::operator () (const unsigned int i,
 			       const unsigned int j) const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
 
 #if PETSC_VERSION_LESS_THAN(2,2,1)
 
@@ -583,8 +584,8 @@ T PetscMatrix<T>::operator () (const unsigned int i,
       const int j = std::distance (const_cast<int*>(&petsc_cols[0]),
 				   const_cast<int*>(p.first));
       
-      assert (j < ncols);
-      assert (petsc_cols[j] == j_val);
+      libmesh_assert (j < ncols);
+      libmesh_assert (petsc_cols[j] == j_val);
       
       value = static_cast<T> (petsc_row[j]);
       
@@ -607,7 +608,7 @@ template <typename T>
 inline
 bool PetscMatrix<T>::closed() const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int ierr=0;
   PetscTruth assembled;
@@ -619,13 +620,23 @@ bool PetscMatrix<T>::closed() const
 }
 
 
+template <typename T>
+inline
+void PetscMatrix<T>::swap(PetscMatrix<T> &m) 
+{
+  std::swap(_mat, m._mat);
+  std::swap(_destroy_mat_on_exit, m._destroy_mat_on_exit);
+}
+
+
+
 
 
 template <typename T>
 inline
 void PetscMatrix<T>::print_personal(std::ostream& os) const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
 
 #ifndef NDEBUG
   if (os != std::cout)
