@@ -1,4 +1,4 @@
-// $Id: petsc_nonlinear_solver.h,v 1.4 2007-10-21 20:48:43 benkirk Exp $
+// $Id: petsc_nonlinear_solver.h 2891 2008-06-25 15:25:47Z friedmud $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -53,10 +53,15 @@ template <typename T>
 class PetscNonlinearSolver : public NonlinearSolver<T>
 {
 public:
+  /**
+   * The type of system
+   */
+  typedef NonlinearImplicitSystem sys_type;
+
   /**
    *  Constructor. Initializes Petsc data structures
    */
-  PetscNonlinearSolver ();
+  PetscNonlinearSolver (sys_type& system);
     
   /**
    * Destructor.
@@ -97,7 +102,8 @@ private:
 /*----------------------- functions ----------------------------------*/
 template <typename T>
 inline
-PetscNonlinearSolver<T>::PetscNonlinearSolver ()
+PetscNonlinearSolver<T>::PetscNonlinearSolver (sys_type& system) :
+  NonlinearSolver<T>(system)
 {
 }
 
