@@ -1,4 +1,4 @@
-// $Id: petsc_vector.h,v 1.18 2007-10-21 20:48:43 benkirk Exp $
+// $Id: petsc_vector.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -31,10 +31,6 @@
 
 
 
-// TODO:[BSK} This seems necessary to use petsc on IBM Power3 at NERSC, but only there?  This will need to be wrapped in an ifdef with a variable set by configure
-//#include <cmath>
-
-
 // C++ includes
 #include <vector>
 
@@ -361,7 +357,7 @@ public:
   /**
    * Computes the dot product, p = U.V
    */
-  virtual Number dot(const NumericVector<T>& V) const;
+  virtual T dot(const NumericVector<T>& V) const;
   
   /**
    * Creates a copy of the global vector in the
@@ -415,12 +411,17 @@ public:
   virtual void create_subvector(NumericVector<T>& subvector,
 				const std::vector<unsigned int>& rows) const;
 
+  /**
+   * Swaps the raw PETSc vector context pointers.
+   */
+  void swap (PetscVector<T> &v);
+
   /**
    * Returns the raw PETSc vector context pointer.  Note this is generally
    * not required in user-level code. Just don't do anything crazy like
    * calling VecDestroy()!
    */
-  Vec vec () { assert (_vec != NULL); return _vec; }
+  Vec vec () { libmesh_assert (_vec != NULL); return _vec; }
 
 
   
@@ -436,7 +437,7 @@ private:
    * This boolean value should only be set to false
    * for the constructor which takes a PETSc Vec object. 
    */
-  const bool _destroy_vec_on_exit;
+  bool _destroy_vec_on_exit;
 };
 
 
@@ -524,7 +525,7 @@ void PetscVector<T>::init (const unsigned int n,
   // otherwise create an MPI-enabled vector
   else
     {
-      assert (n_local < n);
+      libmesh_assert (n_local < n);
       
       ierr = VecCreateMPI (libMesh::COMM_WORLD, petsc_n_local, petsc_n,
 			   &_vec);
@@ -557,7 +558,7 @@ template <typename T>
 inline
 void PetscVector<T>::close ()
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int ierr=0;
   
@@ -592,7 +593,7 @@ template <typename T>
 inline
 void PetscVector<T>::zero ()
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int ierr=0;
 
@@ -632,7 +633,7 @@ template <typename T>
 inline
 unsigned int PetscVector<T>::size () const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int ierr=0, petsc_size=0;
   
@@ -651,7 +652,7 @@ template <typename T>
 inline
 unsigned int PetscVector<T>::local_size () const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int ierr=0, petsc_size=0;
   
@@ -667,7 +668,7 @@ template <typename T>
 inline
 unsigned int PetscVector<T>::first_local_index () const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int ierr=0, petsc_first=0, petsc_last=0;
   
@@ -683,7 +684,7 @@ template <typename T>
 inline
 unsigned int PetscVector<T>::last_local_index () const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
   
   int ierr=0, petsc_first=0, petsc_last=0;
   
@@ -699,8 +700,8 @@ template <typename T>
 inline
 T PetscVector<T>::operator() (const unsigned int i) const
 {
-  assert (this->initialized());
-  assert ( ((i >= this->first_local_index()) &&
+  libmesh_assert (this->initialized());
+  libmesh_assert ( ((i >= this->first_local_index()) &&
 	    (i <  this->last_local_index())) );
 
   int ierr=0;
@@ -724,7 +725,7 @@ template <typename T>
 inline
 Real PetscVector<T>::min () const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
 
   int index=0, ierr=0;
   PetscReal min=0.;
@@ -742,7 +743,7 @@ template <typename T>
 inline
 Real PetscVector<T>::max() const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
 
   int index=0, ierr=0;
   PetscReal max=0.;
@@ -755,6 +756,16 @@ Real PetscVector<T>::max() const
 }
 
 
+
+template <typename T>
+inline
+void PetscVector<T>::swap (PetscVector<T> &v)
+{
+  std::swap(_vec, v._vec);
+  std::swap(_destroy_vec_on_exit, v._destroy_vec_on_exit);
+}
+
+
 #endif // #ifdef HAVE_PETSC
 #endif // #ifdef __petsc_vector_h__
 
