@@ -1,4 +1,4 @@
-// $Id: slepc_eigen_solver.h,v 1.3 2007-10-21 20:48:43 benkirk Exp $
+// $Id: slepc_eigen_solver.h 2501 2007-11-20 02:33:29Z benkirk $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -40,12 +40,24 @@
 extern "C"
 {
 # include <slepceps.h>
+# include <slepcversion.h>
 }
 #else
 # include <slepceps.h>
+# include <slepcversion.h>
 #endif
 
 
+// A convenient macro for comparing SLEPc versions.
+// Returns 1 if the current SLEPc version is < major.minor.subminor
+// and zero otherwise.
+#define SLEPC_VERSION_LESS_THAN(major,minor,subminor)			            \
+  ((SLEPC_VERSION_MAJOR < (major) ||						    \
+    (SLEPC_VERSION_MAJOR == (major) && (SLEPC_VERSION_MINOR < (minor) ||	    \
+				  (SLEPC_VERSION_MINOR == (minor) &&		    \
+				   SLEPC_VERSION_SUBMINOR < (subminor))))) ? 1 : 0)
+
+
 
 /**
  * This class provides an interface to the SLEPc
@@ -160,7 +172,18 @@ private:
    * Eigenproblem solver context
    */
   EPS _eps;
-                    
+
+  
+#if !(SLEPC_VERSION_LESS_THAN(2,3,3))
+  
+  /**
+   * For version 2.3.3 and higher SLEPc provided a separate "inner
+   * product" context for certain operations.
+   */
+  IP _ip;
+  
+#endif
+  
 };
 
 
