@@ -1,4 +1,4 @@
-// $Id: sparse_matrix.h,v 1.13 2007-10-21 20:48:43 benkirk Exp $
+// $Id: sparse_matrix.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -33,12 +33,13 @@
 #include "reference_counted_object.h"
 #include "libmesh.h"
 
-
 // forward declarations
 template <typename T> class SparseMatrix;
 template <typename T> class DenseMatrix;
 template <typename T> inline std::ostream& operator << (std::ostream& os, const SparseMatrix<T>& m);
 class DofMap;
+namespace SparsityPattern { class Graph; }
+
 
 /**
  * Generic sparse matrix. This class contains
@@ -98,12 +99,22 @@ public:
   void attach_dof_map (const DofMap& dof_map)
   { _dof_map = &dof_map; }
 
+  /**
+   * \p returns true if this sparse matrix format needs to be fed the 
+   * graph of the sparse matrix.  This is true in the case of the \p LaspackMatrix, 
+   * but not for the \p PetscMatrix.  In the case where the full graph is not
+   * required we can efficiently approximate it to provide a good estimate of the 
+   * required size of the sparse matrix.
+   */ 
+  virtual bool need_full_sparsity_pattern() const 
+  { return false; }  
+
   /**
    * Updates the matrix sparsity pattern. When your \p SparseMatrix<T>
    * implementation does not need this data simply do
    * not overload this method.
    */
-  virtual void update_sparsity_pattern (const std::vector<std::vector<unsigned int> >&) {}
+  virtual void update_sparsity_pattern (const SparsityPattern::Graph &) {}
   
   /**
    * Initialize a Sparse matrix that is of global
@@ -297,7 +308,7 @@ public:
   {
     std::cerr << "ERROR: Not Implemented in base class yet!" << std::endl;
     std::cerr << "ERROR writing MATLAB file " << name << std::endl;
-    error();
+    libmesh_error();
   }
 
   /**
@@ -345,7 +356,7 @@ protected:
   {
     std::cerr << "Error! This function is not yet implemented in the base class!"
 	      << std::endl;
-    error();
+    libmesh_error();
   }
   
   /**
@@ -384,7 +395,7 @@ template <typename T>
 inline
 void SparseMatrix<T>::print(std::ostream& os) const
 {
-  assert (this->initialized());
+  libmesh_assert (this->initialized());
 
   for (unsigned int i=0; i<this->m(); i++)
     {
