@@ -1,4 +1,4 @@
-// $Id: type_tensor.h,v 1.9 2007-10-21 20:48:43 benkirk Exp $
+// $Id: type_tensor.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -44,6 +44,9 @@
 template <typename T>
 class TypeTensor
 {
+template <typename T2>
+friend class TypeTensor;
+
 protected:
 
   /**
@@ -67,7 +70,8 @@ public:
   /**
    * Copy-constructor.
    */
-  TypeTensor(const TypeTensor<T>& p);
+  template<typename T2>
+  TypeTensor(const TypeTensor<T2>& p);
   
   /**
    * Destructor.
@@ -77,7 +81,8 @@ public:
   /**
    * Assign to a tensor without creating a temporary.
    */
-  void assign (const TypeTensor<T> &);
+  template<typename T2>
+  void assign (const TypeTensor<T2> &);
 
   /**
    * Return the \f$ i,j^{th} \f$ element of the tensor.
@@ -93,17 +98,21 @@ public:
   /**
    * Add two tensors. 
    */
-  TypeTensor<T> operator + (const TypeTensor<T> &) const;
+  template<typename T2>
+  TypeTensor<typename CompareTypes<T, T2>::supertype>
+  operator + (const TypeTensor<T2> &) const;
 
   /**
    * Add to this tensor. 
    */
-  const TypeTensor<T> & operator += (const TypeTensor<T> &);
+  template<typename T2>
+  const TypeTensor<T> & operator += (const TypeTensor<T2> &);
   
   /**
    * Add to this tensor without creating a temporary.
    */
-  void add (const TypeTensor<T> &); 
+  template<typename T2>
+  void add (const TypeTensor<T2> &); 
   
   /**
    * Add a scaled tensor to this tensor without
@@ -115,17 +124,21 @@ public:
   /**
    * Subtract two tensors.
    */
-  TypeTensor<T> operator - (const TypeTensor<T> &) const;
+  template<typename T2>
+  TypeTensor<typename CompareTypes<T, T2>::supertype>
+  operator - (const TypeTensor<T2> &) const;
 
   /**
    * Subtract from this tensor. 
    */
-  const TypeTensor<T> & operator -= (const TypeTensor<T> &);
+  template<typename T2>
+  const TypeTensor<T> & operator -= (const TypeTensor<T2> &);
 
   /**
    * Subtract from this tensor without creating a temporary.
    */
-  void subtract (const TypeTensor<T> &); 
+  template<typename T2>
+  void subtract (const TypeTensor<T2> &); 
   
   /**
    * Subtract a scaled value from this tensor without
@@ -145,7 +158,7 @@ public:
   template <typename Scalar>
   typename boostcopy::enable_if_c<
     ScalarTraits<Scalar>::value,
-    TypeTensor<T> >::type
+    TypeTensor<typename CompareTypes<T, Scalar>::supertype> >::type
   operator * (const Scalar) const;
   
   /**
@@ -157,7 +170,11 @@ public:
   /**
    * Divide a tensor by a number, i.e. scale.
    */
-  TypeTensor<T> operator / (const T) const;
+  template <typename Scalar>
+  typename boostcopy::enable_if_c<
+    ScalarTraits<Scalar>::value,
+    TypeTensor<typename CompareTypes<T, Scalar>::supertype> >::type
+  operator / (const Scalar) const;
 
   /**
    * Divide this tensor by a number, i.e. scale.
@@ -176,14 +193,16 @@ public:
    * The tensors may be of different types.
    */
   template <typename T2>
-  T contract (const TypeTensor<T2> &) const;
+  typename CompareTypes<T,T2>::supertype
+  contract (const TypeTensor<T2> &) const;
 
   /**
    * Multiply a tensor and vector together, i.e. matrix-vector product.
    * The tensor and vector may be of different types.
    */
   template <typename T2>
-  TypeVector<T> operator * (const TypeVector<T2> &) const;
+  TypeVector<typename CompareTypes<T,T2>::supertype>
+  operator * (const TypeVector<T2> &) const;
 
   /**
    * The transpose (with complex numbers not conjugated) of the tensor.
@@ -197,8 +216,8 @@ public:
   Real size() const;
 
   /**
-   * Reutrns the Frobenius norm of the tensor squared, i.e. the
-   * square-root of the sum of the elements squared.
+   * Returns the Frobenius norm of the tensor squared, i.e.  sum of the
+   * element magnitudes squared.
    */
   Real size_sq() const;
 
@@ -218,6 +237,12 @@ public:
    */
   bool operator < (const TypeTensor<T>& rhs) const;
   
+  /**
+   * @returns \p true if this tensor is "greater"
+   * than another.
+   */
+  bool operator > (const TypeTensor<T>& rhs) const;
+  
   /**
    * Formatted print to \p std::cout.
    */
@@ -288,8 +313,9 @@ TypeTensor<T>::TypeTensor (const T xx,
 
 
 template <typename T>
+template<typename T2>
 inline
-TypeTensor<T>::TypeTensor (const TypeTensor <T> &p)
+TypeTensor<T>::TypeTensor (const TypeTensor <T2> &p)
 {
   // copy the nodes from vector p to me
   for (unsigned int i=0; i<DIM*DIM; i++)
@@ -307,8 +333,9 @@ TypeTensor<T>::~TypeTensor ()
 
 
 template <typename T>
+template<typename T2>
 inline
-void TypeTensor<T>::assign (const TypeTensor<T> &p)
+void TypeTensor<T>::assign (const TypeTensor<T2> &p)
 {
   for (unsigned int i=0; i<DIM; i++)
     _coords[i] = p._coords[i];
@@ -321,8 +348,8 @@ inline
 T TypeTensor<T>::operator () (const unsigned int i,
 			      const unsigned int j) const
 {
-  assert (i<3);
-  assert (j<3);
+  libmesh_assert (i<3);
+  libmesh_assert (j<3);
 
 #if DIM < 3
   if (i >= DIM || j >= DIM)
@@ -346,13 +373,13 @@ T & TypeTensor<T>::operator () (const unsigned int i,
 //       std::cerr << "ERROR:  You are assigning to a tensor component" << std::endl
 // 		<< "that is out of range for the compiled DIM!"      << std::endl
 // 		<< " DIM=" << DIM << " , i=" << i << " , j=" << j << std::endl;
-      error();
+      libmesh_error();
     }
   
 #endif
   
-  assert (i<DIM);
-  assert (j<DIM);
+  libmesh_assert (i<DIM);
+  libmesh_assert (j<DIM);
   
   return _coords[i*DIM+j];
 }
@@ -360,8 +387,10 @@ T & TypeTensor<T>::operator () (const unsigned int i,
 
 
 template <typename T>
+template<typename T2>
 inline
-TypeTensor<T> TypeTensor<T>::operator + (const TypeTensor<T> &p) const
+TypeTensor<typename CompareTypes<T, T2>::supertype>
+TypeTensor<T>::operator + (const TypeTensor<T2> &p) const
 {
  
 #if DIM == 1
@@ -393,8 +422,9 @@ TypeTensor<T> TypeTensor<T>::operator + (const TypeTensor<T> &p) const
 
 
 template <typename T>
+template<typename T2>
 inline
-const TypeTensor<T> & TypeTensor<T>::operator += (const TypeTensor<T> &p)
+const TypeTensor<T> & TypeTensor<T>::operator += (const TypeTensor<T2> &p)
 {
   this->add (p);
 
@@ -404,8 +434,9 @@ const TypeTensor<T> & TypeTensor<T>::operator += (const TypeTensor<T> &p)
 
 
 template <typename T>
+template<typename T2>
 inline
-void TypeTensor<T>::add (const TypeTensor<T> &p)
+void TypeTensor<T>::add (const TypeTensor<T2> &p)
 {
   for (unsigned int i=0; i<DIM*DIM; i++)
     _coords[i] += p._coords[i];
@@ -426,8 +457,10 @@ void TypeTensor<T>::add_scaled (const TypeTensor<T2> &p, const T factor)
 
 
 template <typename T>
+template<typename T2>
 inline
-TypeTensor<T> TypeTensor<T>::operator - (const TypeTensor<T> &p) const
+TypeTensor<typename CompareTypes<T, T2>::supertype>
+TypeTensor<T>::operator - (const TypeTensor<T2> &p) const
 {
 
 #if DIM == 1
@@ -459,8 +492,9 @@ TypeTensor<T> TypeTensor<T>::operator - (const TypeTensor<T> &p) const
 
 
 template <typename T>
+template <typename T2>
 inline
-const TypeTensor<T> & TypeTensor<T>::operator -= (const TypeTensor<T> &p)
+const TypeTensor<T> & TypeTensor<T>::operator -= (const TypeTensor<T2> &p)
 {
   this->subtract (p);
 
@@ -470,8 +504,9 @@ const TypeTensor<T> & TypeTensor<T>::operator -= (const TypeTensor<T> &p)
 
 
 template <typename T>
+template <typename T2>
 inline
-void TypeTensor<T>::subtract (const TypeTensor<T>& p)
+void TypeTensor<T>::subtract (const TypeTensor<T2>& p)
 {
   for (unsigned int i=0; i<DIM*DIM; i++)
     _coords[i] -= p._coords[i];
@@ -527,31 +562,33 @@ template <typename Scalar>
 inline
 typename boostcopy::enable_if_c<
   ScalarTraits<Scalar>::value,
-  TypeTensor<T> >::type
+  TypeTensor<typename CompareTypes<T, Scalar>::supertype> >::type
 TypeTensor<T>::operator * (const Scalar factor) const
 {
+  typedef typename CompareTypes<T, Scalar>::supertype TS;
+
 
 #if DIM == 1
-  return TypeTensor(_coords[0]*factor);
+  return TypeTensor<TS>(_coords[0]*factor);
 #endif
   
 #if DIM == 2 
-  return TypeTensor(_coords[0]*factor,
-		    _coords[1]*factor,
-		    _coords[2]*factor,
-		    _coords[3]*factor);
+  return TypeTensor<TS>(_coords[0]*factor,
+		        _coords[1]*factor,
+		        _coords[2]*factor,
+		        _coords[3]*factor);
 #endif
   
 #if DIM == 3
-  return TypeTensor(_coords[0]*factor,
-		    _coords[1]*factor, 
-		    _coords[2]*factor, 
-		    _coords[3]*factor, 
-		    _coords[4]*factor, 
-		    _coords[5]*factor, 
-		    _coords[6]*factor, 
-		    _coords[7]*factor, 
-		    _coords[8]*factor);
+  return TypeTensor<TS>(_coords[0]*factor,
+		        _coords[1]*factor, 
+		        _coords[2]*factor, 
+		        _coords[3]*factor, 
+		        _coords[4]*factor, 
+		        _coords[5]*factor, 
+		        _coords[6]*factor, 
+		        _coords[7]*factor, 
+		        _coords[8]*factor);
 #endif  
 }
 
@@ -561,7 +598,7 @@ template <typename T, typename Scalar>
 inline
 typename boostcopy::enable_if_c<
   ScalarTraits<Scalar>::value,
-  const TypeVector<T> >::type
+  TypeTensor<typename CompareTypes<T, Scalar>::supertype> >::type
 operator * (const Scalar factor,
 	    const TypeTensor<T> &t)
 {
@@ -585,32 +622,38 @@ const TypeTensor<T> & TypeTensor<T>::operator *= (const Scalar factor)
 
 
 template <typename T>
+template <typename Scalar>
 inline
-TypeTensor<T> TypeTensor<T>::operator / (const T factor) const
+typename boostcopy::enable_if_c<
+  ScalarTraits<Scalar>::value,
+  TypeTensor<typename CompareTypes<T, Scalar>::supertype> >::type
+TypeTensor<T>::operator / (const Scalar factor) const
 {
-  assert (factor != static_cast<T>(0.));
+  libmesh_assert (factor != static_cast<T>(0.));
+
+  typedef typename CompareTypes<T, Scalar>::supertype TS;
   
 #if DIM == 1
-  return TypeTensor(_coords[0]/factor);
+  return TypeTensor<TS>(_coords[0]/factor);
 #endif
   
 #if DIM == 2 
-  return TypeTensor(_coords[0]/factor,
-		    _coords[1]/factor,
-		    _coords[2]/factor,
-		    _coords[3]/factor);
+  return TypeTensor<TS>(_coords[0]/factor,
+		        _coords[1]/factor,
+		        _coords[2]/factor,
+		        _coords[3]/factor);
 #endif
   
 #if DIM == 3
-  return TypeTensor(_coords[0]/factor,
-		    _coords[1]/factor, 
-		    _coords[2]/factor, 
-		    _coords[3]/factor, 
-		    _coords[4]/factor, 
-		    _coords[5]/factor, 
-		    _coords[6]/factor, 
-		    _coords[7]/factor, 
-		    _coords[8]/factor);
+  return TypeTensor<TS>(_coords[0]/factor,
+		        _coords[1]/factor, 
+		        _coords[2]/factor, 
+		        _coords[3]/factor, 
+		        _coords[4]/factor, 
+		        _coords[5]/factor, 
+		        _coords[6]/factor, 
+		        _coords[7]/factor, 
+		        _coords[8]/factor);
 #endif
   
 }
@@ -651,7 +694,7 @@ template <typename T>
 inline
 const TypeTensor<T> & TypeTensor<T>::operator /= (const T factor)
 {
-  assert (factor != static_cast<T>(0.));
+  libmesh_assert (factor != static_cast<T>(0.));
   
   for (unsigned int i=0; i<DIM*DIM; i++)
     _coords[i] /= factor;
@@ -665,9 +708,10 @@ const TypeTensor<T> & TypeTensor<T>::operator /= (const T factor)
 template <typename T>
 template <typename T2>
 inline
-TypeVector<T> TypeTensor<T>::operator * (const TypeVector<T2> &p) const
+TypeVector<typename CompareTypes<T,T2>::supertype>
+TypeTensor<T>::operator * (const TypeVector<T2> &p) const
 {
-  TypeVector<T> returnval;
+  TypeVector<typename CompareTypes<T,T2>::supertype> returnval;
   for (unsigned int i=0; i<DIM; i++)
     for (unsigned int j=0; j<DIM; j++)
       returnval(i) += (*this)(i,j)*p(j);
@@ -700,9 +744,10 @@ TypeTensor<T> TypeTensor<T>::operator * (const TypeTensor<T2> &p) const
 template <typename T>
 template <typename T2>
 inline
-T TypeTensor<T>::contract (const TypeTensor<T2> &t) const
+typename CompareTypes<T,T2>::supertype
+TypeTensor<T>::contract (const TypeTensor<T2> &t) const
 {
-  T sum = 0.;
+  typename CompareTypes<T,T2>::supertype sum = 0.;
   for (unsigned int i=0; i<DIM*DIM; i++)
     sum += _coords[i]*t._coords[i];
   return sum;
@@ -729,37 +774,21 @@ void TypeTensor<T>::zero()
 
 
 
-template <>
+template <typename T>
 inline
-Real TypeTensor<Real>::size_sq () const
+Real TypeTensor<T>::size_sq () const
 {
   Real sum = 0.;
   for (unsigned int i=0; i<DIM*DIM; i++)
-    sum += _coords[i]*_coords[i];
+    sum += libmesh_norm(_coords[i]);
   return sum;
 }
 
 
 
-#ifdef USE_COMPLEX_NUMBERS
-
-template <>
+template <typename T>
 inline
-Real TypeTensor<Complex>::size_sq() const
-{
-  Real sum = 0.;
-  for (unsigned int i=0; i<DIM*DIM; i++)
-    sum += std::norm(_coords[i]);
-  return sum;
-}
-
-#endif
-
-
-
-template <>
-inline
-bool TypeTensor<Real>::operator == (const TypeTensor<Real>& rhs) const
+bool TypeTensor<T>::operator == (const TypeTensor<T>& rhs) const
 {
 #if DIM == 1
   return (std::abs(_coords[0] - rhs._coords[0])
@@ -789,41 +818,4 @@ bool TypeTensor<Real>::operator == (const TypeTensor<Real>& rhs) const
   
 }
 
-
-#ifdef USE_COMPLEX_NUMBERS
-
-template <>
-inline
-bool TypeTensor<Complex>::operator == (const TypeTensor<Complex>& rhs) const
-{
-#if DIM == 1
-  return (std::abs(_coords[0] - rhs._coords[0])
-	  < TOLERANCE);
-#endif
-  
-#if DIM == 2
-  return ((std::abs(_coords[0] - rhs._coords[0]) +
-	   std::abs(_coords[1] - rhs._coords[1]) +
-	   std::abs(_coords[2] - rhs._coords[2]) +
-	   std::abs(_coords[3] - rhs._coords[3]))
-	  < 4.*TOLERANCE);
-#endif
-  
-#if DIM == 3
-  return ((std::abs(_coords[0] - rhs._coords[0]) +
-	   std::abs(_coords[1] - rhs._coords[1]) +
-	   std::abs(_coords[2] - rhs._coords[2]) +
-	   std::abs(_coords[3] - rhs._coords[3]) +
-	   std::abs(_coords[4] - rhs._coords[4]) +
-	   std::abs(_coords[5] - rhs._coords[5]) +
-	   std::abs(_coords[6] - rhs._coords[6]) +
-	   std::abs(_coords[7] - rhs._coords[7]) +
-	   std::abs(_coords[8] - rhs._coords[8]))
-	  < 9.*TOLERANCE);
-#endif  
-}
-
-#endif
-
-
 #endif // #define __type_tensor_h__
