@@ -1,4 +1,4 @@
-// $Id: type_vector.h,v 1.21 2007-10-21 20:48:43 benkirk Exp $
+// $Id: type_vector.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -27,44 +27,7 @@
 
 // Local includes
 #include "libmesh_common.h"
-
-// Copy of boost enable_if_c
-
-namespace boostcopy {
-  template <bool B, class T = void>
-    struct enable_if_c {
-      typedef T type;
-    };
-
-  template <class T>
-    struct enable_if_c<false, T> {};
-
-}
-
-// Complete list of scalar classes, needed for disambiguation
-template <typename T>
-struct ScalarTraits {
-  static const bool value = false;
-};
-
-template<>
-struct ScalarTraits<float> { static const bool value = true; };
-
-template<>
-struct ScalarTraits<double> { static const bool value = true; };
-
-template<>
-struct ScalarTraits<long double> { static const bool value = true; };
-
-template<>
-struct ScalarTraits<std::complex<float> > { static const bool value = true; };
-
-template<>
-struct ScalarTraits<std::complex<double> > { static const bool value = true; };
-
-template<>
-struct ScalarTraits<std::complex<long double> > { static const bool value = true; };
-
+#include "compare_types.h"
 
 // Forward declaration for friend class
 template <typename T>
@@ -85,6 +48,9 @@ class TypeTensor;
 template <typename T>
 class TypeVector
 {
+template <typename T2>
+friend class TypeVector;
+
 friend class TypeTensor<T>;
 
 protected:
@@ -102,7 +68,8 @@ public:
   /**
    * Copy-constructor.
    */
-  TypeVector (const TypeVector<T>& p);
+  template <typename T2>
+  TypeVector (const TypeVector<T2>& p);
   
   /**
    * Destructor.
@@ -112,7 +79,8 @@ public:
   /**
    * Assign to a vector without creating a temporary.
    */
-  void assign (const TypeVector<T> &);
+  template <typename T2>
+  void assign (const TypeVector<T2> &);
 
   /**
    * Return the \f$ i^{th} \f$ element of the vector.
@@ -127,17 +95,21 @@ public:
   /**
    * Add two vectors.
    */
-  TypeVector<T> operator + (const TypeVector<T> &) const;
+  template <typename T2>
+  TypeVector<typename CompareTypes<T, T2>::supertype> 
+  operator + (const TypeVector<T2> &) const;
 
   /**
-   * Add to this vectors.
+   * Add to this vector.
    */
-  const TypeVector<T> & operator += (const TypeVector<T> &);
+  template <typename T2>
+  const TypeVector<T> & operator += (const TypeVector<T2> &);
   
   /**
    * Add to this vector without creating a temporary.
    */
-  void add (const TypeVector<T> &); 
+  template <typename T2>
+  void add (const TypeVector<T2> &); 
   
   /**
    * Add a scaled value to this vector without
@@ -149,17 +121,21 @@ public:
   /**
    * Subtract two vectors.
    */
-  TypeVector<T> operator - (const TypeVector<T> &) const;
+  template <typename T2>
+  TypeVector<typename CompareTypes<T, T2>::supertype> 
+  operator - (const TypeVector<T2> &) const;
 
   /**
    * Subtract from this vector.
    */
-  const TypeVector<T> & operator -= (const TypeVector<T> &);
+  template <typename T2>
+  const TypeVector<T> & operator -= (const TypeVector<T2> &);
 
   /**
    * Subtract from this vector without creating a temporary.
    */
-  void subtract (const TypeVector<T> &); 
+  template <typename T2>
+  void subtract (const TypeVector<T2> &); 
   
   /**
    * Subtract a scaled value from this vector without
@@ -179,19 +155,22 @@ public:
   template <typename Scalar>
   typename boostcopy::enable_if_c<
     ScalarTraits<Scalar>::value,
-    TypeVector<T> >::type
+    TypeVector<typename CompareTypes<T, Scalar>::supertype> >::type
   operator * (const Scalar) const;
 
   /**
    * Multiply this vector by a number, i.e. scale.
    */
-  template <typename Scalar>
-  const TypeVector<T> & operator *= (const Scalar);
+  const TypeVector<T> & operator *= (const T);
   
   /**
    * Divide a vector by a number, i.e. scale.
    */
-  TypeVector<T> operator / (const T) const;
+  template <typename Scalar>
+  typename boostcopy::enable_if_c<
+    ScalarTraits<Scalar>::value,
+    TypeVector<typename CompareTypes<T, Scalar>::supertype> >::type
+  operator / (const Scalar) const;
 
   /**
    * Divide this vector by a number, i.e. scale.
@@ -203,12 +182,15 @@ public:
    * The vectors may be of different types.
    */
   template <typename T2>
-  T operator * (const TypeVector<T2> &) const;
+  typename CompareTypes<T, T2>::supertype
+  operator * (const TypeVector<T2> &) const;
 
   /**
    * Cross 2 vectors together, i.e. cross-product.
    */
-  TypeVector<T> cross(const TypeVector<T> &) const;
+  template <typename T2>
+  TypeVector<typename CompareTypes<T, T2>::supertype>
+  cross(const TypeVector<T2> &) const;
 
   /**
    * Think of a vector as a \p dim dimensional vector.  This
@@ -223,8 +205,8 @@ public:
   Real size() const;
 
   /**
-   * Returns the magnitude of the vector squared, i.e. the square-root
-   * of the sum of the elements squared.
+   * Returns the magnitude of the vector squared, i.e. the sum of the element
+   * magnitudes squared.
    */
   Real size_sq() const;
 
@@ -328,8 +310,9 @@ TypeVector<T>::TypeVector (const T x,
 
 
 template <typename T>
+template <typename T2>
 inline
-TypeVector<T>::TypeVector (const TypeVector<T> &p)
+TypeVector<T>::TypeVector (const TypeVector<T2> &p)
 {
   // copy the nodes from vector p to me
   for (unsigned int i=0; i<DIM; i++)
@@ -347,8 +330,9 @@ TypeVector<T>::~TypeVector ()
 
 
 template <typename T>
+template <typename T2>
 inline
-void TypeVector<T>::assign (const TypeVector<T> &p)
+void TypeVector<T>::assign (const TypeVector<T2> &p)
 {
   for (unsigned int i=0; i<DIM; i++)
     _coords[i] = p._coords[i];
@@ -360,7 +344,7 @@ template <typename T>
 inline
 T TypeVector<T>::operator () (const unsigned int i) const
 {
-  assert (i<3);
+  libmesh_assert (i<3);
 
 #if DIM < 3
   
@@ -386,12 +370,12 @@ T & TypeVector<T>::operator () (const unsigned int i)
 // 		<< "that is out of range for the compiled DIM!"      << std::endl
 // 		<< " DIM=" << DIM << " , i=" << i
 // 		<< std::endl;
-      error();
+      libmesh_error();
     }
   
 #endif
   
-  assert (i<DIM);
+  libmesh_assert (i<DIM);
   
   return _coords[i];
 }
@@ -399,23 +383,25 @@ T & TypeVector<T>::operator () (const unsigned int i)
 
 
 template <typename T>
+template <typename T2>
 inline
-TypeVector<T> TypeVector<T>::operator + (const TypeVector<T> &p) const
+TypeVector<typename CompareTypes<T, T2>::supertype> 
+TypeVector<T>::operator + (const TypeVector<T2> &p) const
 {
- 
+  typedef typename CompareTypes<T, T2>::supertype TS;
 #if DIM == 1
-  return TypeVector(_coords[0] + p._coords[0]);
+  return TypeVector<TS> (_coords[0] + p._coords[0]);
 #endif
 
 #if DIM == 2 
-  return TypeVector(_coords[0] + p._coords[0],
-		    _coords[1] + p._coords[1]);
+  return TypeVector<TS> (_coords[0] + p._coords[0],
+                         _coords[1] + p._coords[1]);
 #endif
 
 #if DIM == 3
-  return TypeVector(_coords[0] + p._coords[0],
-		    _coords[1] + p._coords[1],
-		    _coords[2] + p._coords[2]);
+  return TypeVector<TS> (_coords[0] + p._coords[0],
+                         _coords[1] + p._coords[1],
+                         _coords[2] + p._coords[2]);
 #endif
 	       
 }
@@ -423,8 +409,9 @@ TypeVector<T> TypeVector<T>::operator + (const TypeVector<T> &p) const
 
 
 template <typename T>
+template <typename T2>
 inline
-const TypeVector<T> & TypeVector<T>::operator += (const TypeVector<T> &p)
+const TypeVector<T> & TypeVector<T>::operator += (const TypeVector<T2> &p)
 {
   this->add (p);
 
@@ -434,8 +421,9 @@ const TypeVector<T> & TypeVector<T>::operator += (const TypeVector<T> &p)
 
 
 template <typename T>
+template <typename T2>
 inline
-void TypeVector<T>::add (const TypeVector<T> &p)
+void TypeVector<T>::add (const TypeVector<T2> &p)
 {
 #if DIM == 1
   _coords[0] += p._coords[0];
@@ -481,23 +469,26 @@ void TypeVector<T>::add_scaled (const TypeVector<T2> &p, const T factor)
 
 
 template <typename T>
+template <typename T2>
 inline
-TypeVector<T> TypeVector<T>::operator - (const TypeVector<T> &p) const
+TypeVector<typename CompareTypes<T, T2>::supertype> 
+TypeVector<T>::operator - (const TypeVector<T2> &p) const
 {
+  typedef typename CompareTypes<T, T2>::supertype TS;
 
 #if DIM == 1
-  return TypeVector(_coords[0] - p._coords[0]);
+  return TypeVector<TS>(_coords[0] - p._coords[0]);
 #endif
 
 #if DIM == 2 
-  return TypeVector(_coords[0] - p._coords[0],
-		    _coords[1] - p._coords[1]);
+  return TypeVector<TS>(_coords[0] - p._coords[0],
+		        _coords[1] - p._coords[1]);
 #endif
 
 #if DIM == 3
-  return TypeVector(_coords[0] - p._coords[0],
-		    _coords[1] - p._coords[1],
-		    _coords[2] - p._coords[2]);
+  return TypeVector<TS>(_coords[0] - p._coords[0],
+		        _coords[1] - p._coords[1],
+		        _coords[2] - p._coords[2]);
 #endif
 
 }
@@ -505,8 +496,9 @@ TypeVector<T> TypeVector<T>::operator - (const TypeVector<T> &p) const
 
 
 template <typename T>
+template <typename T2>
 inline
-const TypeVector<T> & TypeVector<T>::operator -= (const TypeVector<T> &p)
+const TypeVector<T> & TypeVector<T>::operator -= (const TypeVector<T2> &p)
 {
   this->subtract (p);
 
@@ -516,8 +508,9 @@ const TypeVector<T> & TypeVector<T>::operator -= (const TypeVector<T> &p)
 
 
 template <typename T>
+template <typename T2>
 inline
-void TypeVector<T>::subtract (const TypeVector<T>& p)
+void TypeVector<T>::subtract (const TypeVector<T2>& p)
 {
   for (unsigned int i=0; i<DIM; i++)
     _coords[i] -= p._coords[i];
@@ -565,23 +558,24 @@ template <typename Scalar>
 inline
 typename boostcopy::enable_if_c<
   ScalarTraits<Scalar>::value,
-  TypeVector<T> >::type
+  TypeVector<typename CompareTypes<T, Scalar>::supertype> >::type
 TypeVector<T>::operator * (const Scalar factor) const
 {
+  typedef typename CompareTypes<T, Scalar>::supertype TS;
 
 #if DIM == 1
-  return TypeVector(_coords[0]*factor);
+  return TypeVector<TS>(_coords[0]*factor);
 #endif
   
 #if DIM == 2 
-  return TypeVector(_coords[0]*factor,
-		    _coords[1]*factor);
+  return TypeVector<TS>(_coords[0]*factor,
+		        _coords[1]*factor);
 #endif
   
 #if DIM == 3
-  return TypeVector(_coords[0]*factor,
-		    _coords[1]*factor, 
-		    _coords[2]*factor);
+  return TypeVector<TS>(_coords[0]*factor,
+		        _coords[1]*factor, 
+		        _coords[2]*factor);
 #endif  
 }
 
@@ -591,7 +585,7 @@ template <typename T, typename Scalar>
 inline
 typename boostcopy::enable_if_c<
   ScalarTraits<Scalar>::value,
-  TypeVector<T> >::type
+  TypeVector<typename CompareTypes<T, Scalar>::supertype> >::type
 operator * (const Scalar factor,
             const TypeVector<T> &v)
 {
@@ -601,9 +595,8 @@ operator * (const Scalar factor,
 
 
 template <typename T>
-template <typename Scalar>
 inline
-const TypeVector<T> & TypeVector<T>::operator *= (const Scalar factor)
+const TypeVector<T> & TypeVector<T>::operator *= (const T factor)
 {
 #if DIM == 1
   _coords[0] *= factor;
@@ -625,26 +618,31 @@ const TypeVector<T> & TypeVector<T>::operator *= (const Scalar factor)
 
 
 
-
 template <typename T>
+template <typename Scalar>
 inline
-TypeVector<T> TypeVector<T>::operator / (const T factor) const
+typename boostcopy::enable_if_c<
+  ScalarTraits<Scalar>::value,
+  TypeVector<typename CompareTypes<T, Scalar>::supertype> >::type
+TypeVector<T>::operator / (const Scalar factor) const
 {
-  assert (factor != static_cast<T>(0.));
+  libmesh_assert (factor != static_cast<T>(0.));
+
+  typedef typename CompareTypes<T, Scalar>::supertype TS;
   
 #if DIM == 1
-  return TypeVector(_coords[0]/factor);
+  return TypeVector<TS>(_coords[0]/factor);
 #endif
   
 #if DIM == 2 
-  return TypeVector(_coords[0]/factor,
-		    _coords[1]/factor);
+  return TypeVector<TS>(_coords[0]/factor,
+		        _coords[1]/factor);
 #endif
   
 #if DIM == 3
-  return TypeVector(_coords[0]/factor,
-		    _coords[1]/factor, 
-		    _coords[2]/factor);
+  return TypeVector<TS>(_coords[0]/factor,
+		        _coords[1]/factor, 
+		        _coords[2]/factor);
 #endif
   
 }
@@ -654,9 +652,10 @@ TypeVector<T> TypeVector<T>::operator / (const T factor) const
 
 template <typename T>
 inline
-const TypeVector<T> & TypeVector<T>::operator /= (const T factor)
+const TypeVector<T> &
+TypeVector<T>::operator /= (const T factor)
 {
-  assert (factor != static_cast<T>(0.));
+  libmesh_assert (factor != static_cast<T>(0.));
   
   for (unsigned int i=0; i<DIM; i++)
     _coords[i] /= factor;
@@ -670,7 +669,8 @@ const TypeVector<T> & TypeVector<T>::operator /= (const T factor)
 template <typename T>
 template <typename T2>
 inline
-T TypeVector<T>::operator * (const TypeVector<T2> &p) const
+typename CompareTypes<T, T2>::supertype
+TypeVector<T>::operator * (const TypeVector<T2> &p) const
 {
 #if DIM == 1
   return _coords[0]*p._coords[0];
@@ -690,6 +690,25 @@ T TypeVector<T>::operator * (const TypeVector<T2> &p) const
 
 
 
+template <typename T>
+template <typename T2>
+TypeVector<typename CompareTypes<T, T2>::supertype>
+TypeVector<T>::cross(const TypeVector<T2>& p) const
+{
+  typedef typename CompareTypes<T, T2>::supertype TS;
+  libmesh_assert (DIM == 3);
+
+  // |     i          j          k    |
+  // |(*this)(0) (*this)(1) (*this)(2)|
+  // |   p(0)       p(1)       p(2)   |
+
+  return TypeVector<TS>( _coords[1]*p._coords[2] - _coords[2]*p._coords[1],
+                        -_coords[0]*p._coords[2] + _coords[2]*p._coords[0],
+                         _coords[0]*p._coords[1] - _coords[1]*p._coords[0]);
+}
+
+
+
 template <typename T>
 inline
 Real TypeVector<T>::size() const
@@ -709,39 +728,26 @@ void TypeVector<T>::zero()
 
 
 
-template <>
+template <typename T>
 inline
-Real TypeVector<Real>::size_sq () const
-{
-  return (*this)*(*this);
-}
-
-
-
-#ifdef USE_COMPLEX_NUMBERS
-
-template <>
-inline
-Real TypeVector<Complex>::size_sq() const
+Real TypeVector<T>::size_sq() const
 {
 #if DIM == 1
-  return (std::norm(_coords[0]));
+  return (libmesh_norm(_coords[0]));
 #endif
   
 #if DIM == 2
-  return (std::norm(_coords[0]) +
-	  std::norm(_coords[1]));
+  return (libmesh_norm(_coords[0]) +
+	  libmesh_norm(_coords[1]));
 #endif
   
 #if DIM == 3
-  return (std::norm(_coords[0]) +
-	  std::norm(_coords[1]) + 
-	  std::norm(_coords[2]));
+  return (libmesh_norm(_coords[0]) +
+	  libmesh_norm(_coords[1]) + 
+	  libmesh_norm(_coords[2]));
 #endif
 }
 
-#endif
-
 
 
 template <typename T>
@@ -823,42 +829,4 @@ bool TypeVector<Real>::operator != (const TypeVector<Real>& rhs) const
   return (!(*this == rhs));
 }
 
-
-
-/*
-#ifdef USE_COMPLEX_NUMBERS
-
-template <>
-inline
-bool TypeVector<Complex>::operator == (const TypeVector<Complex>& rhs) const
-{
-#if DIM == 1
-  return (_coords[0] == rhs._coords[0]);
-#endif
-  
-#if DIM == 2
-  return (_coords[0] == rhs._coords[0] &&
-	  _coords[1] == rhs._coords[1]);
-#endif
-  
-#if DIM == 3
-  return (_coords[0] == rhs._coords[0] &&
-	  _coords[1] == rhs._coords[1] &&
-	  _coords[2] == rhs._coords[2]);
-#endif  
-}
-
-
-template <>
-inline
-bool TypeVector<Complex>::operator != (const TypeVector<Complex>& rhs) const
-{
-  return (!(*this == rhs));
-}
-
-
-#endif
-*/
-
-
 #endif // #define __type_vector_h__
