@@ -1,4 +1,4 @@
-// $Id: parmetis_partitioner.h,v 1.5 2007-10-21 20:48:44 benkirk Exp $
+// $Id: parmetis_partitioner.h 2707 2008-02-27 18:39:36Z benkirk $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -25,6 +25,7 @@
 // C++ Includes   -----------------------------------
 #include <string>
 #include <vector>
+#include <map>
 
 // Local Includes -----------------------------------
 #include "partitioner.h"
@@ -86,11 +87,17 @@ private:
    */
   void assign_partitioning (MeshBase& mesh);
 
+  /**
+   * The number of active elements on each processor.  Note that
+   * ParMETIS requires that each processor have some active elements,
+   * it will abort if any processor passes a NULL _part array.
+   */
+  std::vector<unsigned int> _n_active_elem_on_proc;
+  
   /**
    * Maps active element ids into a contiguous range, as needed by ParMETIS.
    */
-  std::vector<unsigned int> _forward_map;
-  unsigned int _first_local_elem;
+  std::map<unsigned int, unsigned int> _global_index_by_pid_map;
   
   /**
    * Data structures used by ParMETIS to describe the connectivity graph
@@ -111,7 +118,6 @@ private:
   int _nparts;
   int _edgecut;
 
-
 #endif
 };
 
