@@ -1,4 +1,4 @@
-// $Id: partitioner.h,v 1.6 2007-10-21 20:48:44 benkirk Exp $
+// $Id: partitioner.h 2708 2008-02-27 21:36:49Z benkirk $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -77,6 +77,25 @@ class Partitioner
   void repartition (MeshBase& mesh,
 		    const unsigned int n=libMesh::n_processors());
 
+  /**
+   * This function 
+   */
+  static void partition_unpartitioned_elements (MeshBase &mesh, 
+						const unsigned int n=libMesh::n_processors());
+
+  /**
+   * This function is called after partitioning to set the processor IDs
+   * for the inactive parent elements.  A Parent's processor ID is the same
+   * as its first child.
+   */
+  static void set_parent_processor_ids(MeshBase& mesh);
+
+  /**
+   * This function is called after partitioning to set the processor IDs
+   * for the nodes.  By definition, a Node's processor ID is the minimum
+   * processor ID for all of the elements which share the node.
+   */
+  static void set_node_processor_ids(MeshBase& mesh);
   
 protected:
 
@@ -105,11 +124,10 @@ protected:
 				const unsigned int n) { this->_do_partition (mesh, n); }
 
   /**
-   * This function is called after partitioning to set the processor IDs
-   * for the nodes.  By definition, a Node's processor ID is the minimum
-   * processor ID for all of the elements which share the node.
+   * The blocksize to use when doing blocked parallel communication.  This limits the
+   * maximum vector size which can be used in a single communication step.
    */
-  void _set_node_processor_ids(MeshBase& mesh);
+  static const unsigned int communication_blocksize;
 };
 
 
