@@ -1,4 +1,4 @@
-// $Id: sfc_partitioner.h,v 1.5 2007-10-21 20:48:44 benkirk Exp $
+// $Id: sfc_partitioner.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -82,7 +82,7 @@ private:
 inline
 void SFCPartitioner::set_sfc_type (const std::string& sfc_type)
 {
-  assert ((sfc_type == "Hilbert") ||
+  libmesh_assert ((sfc_type == "Hilbert") ||
 	  (sfc_type == "Morton"));
 
   _sfc_type = sfc_type;
