@@ -1,4 +1,4 @@
-// $Id: quadrature.h,v 1.12 2007-10-21 20:48:44 benkirk Exp $
+// $Id: quadrature.h 2889 2008-06-24 17:51:42Z jwpeterson $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -99,7 +99,7 @@ public:
    * @returns the number of points associated with the quadrature rule.
    */    
   unsigned int n_points() const
-    { assert (!_points.empty()); return _points.size(); }
+    { libmesh_assert (!_points.empty()); return _points.size(); }
 
   /**
    * @returns the dimension of the quadrature rule.
@@ -132,13 +132,13 @@ public:
    * @returns the \f$ i^{th} \f$ quadrature point on the reference object.
    */
   Point qp(const unsigned int i) const
-    { assert (i < _points.size()); return _points[i]; }
+    { libmesh_assert (i < _points.size()); return _points[i]; }
 
   /**
    * @returns the \f$ i^{th} \f$ quadrature weight.
    */
   Real w(const unsigned int i) const
-    { assert (i < _weights.size()); return _weights[i]; }
+    { libmesh_assert (i < _weights.size()); return _weights[i]; }
   
   /**
    * Initializes the data structures to contain a quadrature rule
@@ -158,10 +158,27 @@ public:
   void print_info(std::ostream& os=std::cout) const;
 
   /**
-   * Same as above, but allows you to use ethe stream syntax.
+   * Same as above, but allows you to use the stream syntax.
    */
   friend std::ostream& operator << (std::ostream& os, const QBase& q);
 
+  /**
+   * Flag (default true) controlling the use of quadrature rules with negative
+   * weights.  Set this to false to ONLY use (potentially) safer but more expensive
+   * rules with all positive weights.
+   *
+   * Negative weights typically appear in Gaussian quadrature rules
+   * over three-dimensional elements.  Rules with negative weights can
+   * be unsuitable for some problems.  For example, it is possible for
+   * a rule with negative weights to obtain a negative result when
+   * integrating a positive function.
+   *
+   * A particular example: if rules with negative weights are not allowed,
+   * a request for TET,THIRD (5 points) will return the TET,FIFTH (14 points)
+   * rule instead, nearly tripling the computational effort required!
+   */
+  bool allow_rules_with_negative_weights;
+  
 protected:
 
   
@@ -199,7 +216,7 @@ protected:
   {  
     std::cerr << "ERROR: Seems as if this quadrature rule" << std::endl
 	      << " is not implemented for 2D." << std::endl;
-    error();
+    libmesh_error();
   }
 #endif
 
@@ -219,7 +236,7 @@ protected:
   {  
     std::cerr << "ERROR: Seems as if this quadrature rule" << std::endl
 	      << " is not implemented for 3D." << std::endl;
-    error();
+    libmesh_error();
   }
 #endif
   
@@ -325,6 +342,7 @@ protected:
 inline
 QBase::QBase(const unsigned int d,
 	     const Order o) :
+  allow_rules_with_negative_weights(true),
   _dim(d),
   _order(o),
   _type(INVALID_ELEM),
@@ -338,8 +356,8 @@ QBase::QBase(const unsigned int d,
 inline
 void QBase::print_info(std::ostream& os) const
 {
-  assert(!_points.empty());
-  assert(!_weights.empty());
+  libmesh_assert(!_points.empty());
+  libmesh_assert(!_weights.empty());
 
   os << "N_Q_Points=" << this->n_points() << std::endl << std::endl;
   for (unsigned int qp=0; qp<this->n_points(); qp++)
