@@ -1,4 +1,4 @@
-// $Id: quadrature_gauss.h,v 1.6 2007-10-21 20:48:44 benkirk Exp $
+// $Id: quadrature_gauss.h 2929 2008-07-14 15:24:52Z jwpeterson $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -67,6 +67,25 @@ class QGauss : public QBase
   void init_3D (const ElemType _type=INVALID_ELEM,
 		unsigned int p_level=0);
 
+
+  /**
+   * The Dunavant rule is for triangles.  It takes permutation points and
+   * weights in a specific format as input and fills the pre-sized _points and _weights
+   * vectors.  This function is only used internally by the TRI geometric
+   * elements.
+   */
+  void dunavant_rule(const Real rule_data[][4],
+		     const unsigned int n_pts);
+
+  /**
+   * The Keast rule is for tets.  It takes permutation points and weights
+   * in a specific format as input and fills the pre-sized _points and _weights
+   * vectors.  This function is only used internally by the TET geometric
+   * elements.
+   */
+  void keast_rule(const Real rule_data[][4],
+		  const unsigned int n_pts);
+
 };
 
 
