@@ -1,4 +1,4 @@
-// $Id: quadrature_jacobi.h,v 1.5 2007-10-21 20:48:44 benkirk Exp $
+// $Id: quadrature_jacobi.h 2788 2008-04-13 02:05:22Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -116,7 +116,7 @@ QuadratureType QJacobi::type() const
 
   else
     { 
-      error();
+      libmesh_error();
       return INVALID_Q_RULE;
     }
 }
