@@ -1,4 +1,4 @@
-// $Id: diff_solver.h,v 1.11 2007-10-21 20:48:44 benkirk Exp $
+// $Id: diff_solver.h 2788 2008-04-13 02:05:22Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -32,7 +32,6 @@
 // Forward Declarations
 class DiffSolver;
 class DifferentiableSystem;
-class TimeSolver;
 
 /**
  * This is a generic class that defines a solver to handle
@@ -93,11 +92,28 @@ public:
    */
   virtual unsigned int solve () = 0;
 
+  /**
+   * @returns the number of "outer" (e.g. quasi-Newton) iterations
+   * required by the last solve.
+   */
+  unsigned int total_outer_iterations() { return _outer_iterations; }
+
+  /**
+   * @returns the number of "inner" (e.g. Krylov) iterations
+   * required by the last solve.
+   */
+  unsigned int total_inner_iterations() { return _inner_iterations; }
+
   /**
    * @returns a constant reference to the system we are solving.
    */
   const sys_type & system () const { return _system; }
 
+  /**
+   * @returns a writeable reference to the system we are solving.
+   */
+  sys_type & system () { return _system; }
+  
   /**
    * The DiffSolver should not print anything to std::cout
    * unless quiet is set to false
@@ -125,7 +141,7 @@ public:
   bool continue_after_max_iterations;
 
   /**
-   * Defaults to false, telling the DiffSolver to throw an error() when
+   * Defaults to false, telling the DiffSolver to throw a libmesh_error() when
    * the backtracking scheme fails to find a descent direction.
    */
   bool continue_after_backtrack_failure;
@@ -243,10 +259,15 @@ protected:
   Real max_residual_norm;
 
   /**
-   * @returns a writeable reference to the system we are solving.
+   * The number of outer iterations used by the last solve
    */
-  sys_type & system () { return _system; }
-  
+  unsigned int _outer_iterations;
+
+  /**
+   * The number of inner iterations used by the last solve
+   */
+  unsigned int _inner_iterations;
+
   /**
    * A reference to the system we are solving.
    */
