@@ -1,5 +1,5 @@
 
-// $Id: diff_system.h,v 1.20 2007-10-21 20:48:44 benkirk Exp $
+// $Id: diff_system.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -34,8 +34,6 @@
 #include "transient_system.h"
 
 // Forward Declarations
-class FEBase;
-class QBase;
 class TimeSolver;
 
 template <typename T> class NumericVector;
@@ -210,7 +208,7 @@ public:
    * time_evolving() to prepare data structures.
    */
   virtual void time_evolving (unsigned int var) {
-    assert(_time_evolving.size() > var);
+    libmesh_assert(_time_evolving.size() > var);
     _time_evolving[var] = true;
   }
 
