@@ -1,4 +1,4 @@
-// $Id: equation_systems.h,v 1.26 2007-10-21 20:48:44 benkirk Exp $
+// $Id: equation_systems.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -44,14 +44,13 @@
 
 // Forward Declarations
 class MeshData;
-//class System;
 class Elem;
-class Mesh;
+class MeshBase;
 
 /**
  * This is the \p EquationSystems class.  It is in charge
  * of handling all the various equation systems defined
- * for a \p Mesh.  It may have multiple systems, which may
+ * for a \p MeshBase.  It may have multiple systems, which may
  * be active or inactive, so that at different solution
  * stages only a sub-set may be solved for.  Also, through
  * the templated access, @e different types of systems
@@ -70,20 +69,22 @@ public:
   /**
    * Define enumeration to set properties in EquationSystems::read()
    */
-  enum ReadFlags { READ_HEADER          = 1,
-                   READ_DATA            = 2,
-                   READ_ADDITIONAL_DATA = 4 };
+  enum ReadFlags { READ_HEADER           = 1,
+                   READ_DATA             = 2,
+                   READ_ADDITIONAL_DATA  = 4,
+                   READ_LEGACY_FORMAT    = 8 };
 
   /**
    * Define enumeration to set properties in EquationSystems::write()
    */
-  enum WriteFlags { WRITE_DATA            = 1,
-                    WRITE_ADDITIONAL_DATA = 2 };
+  enum WriteFlags { WRITE_DATA             = 1,
+                    WRITE_ADDITIONAL_DATA  = 2,
+                    WRITE_PARALLEL_FILES   = 4 };
   
   /**
    * Constructor.
    */
-  EquationSystems (Mesh& mesh, MeshData* mesh_data=NULL);
+  EquationSystems (MeshBase& mesh, MeshData* mesh_data=NULL);
 
   /**
    * Destructor.  Should be virtual, since the user may want to derive
@@ -178,26 +179,6 @@ public:
    */
   System & get_system (const unsigned int num);
   
-//   /**
-//    * @returns a reference to the system named \p name.
-//    */
-//   System & operator () (const std::string& name);
- 
-//   /**
-//    * @returns a constant reference to the system name
-//    */
-//   const System & operator () (const std::string& name) const;
- 
-//   /**
-//    * @returns a reference to system number \p num.
-//    */
-//   System & operator () (const unsigned int num);
- 
-//   /**
-//    * @returns a constant reference to system number \p num.
-//    */
-//   const System & operator () (const unsigned int num) const;
-  
   /**
    * Add the system of type \p system_type named \p name to the
    * systems array.
@@ -307,7 +288,7 @@ public:
    */
   void write (const std::string& name,
 	      const libMeshEnums::XdrMODE,
-              const unsigned int write_flags=WRITE_DATA) const;
+              const unsigned int write_flags=(WRITE_DATA)) const;
 
   /**
    * @returns \p true when this equation system contains
@@ -338,12 +319,12 @@ public:
   /**
    * @returns a constant reference to the mesh
    */
-  const Mesh & get_mesh() const;
+  const MeshBase & get_mesh() const;
 
   /**
    * @returns a reference to the mesh
    */
-  Mesh & get_mesh();
+  MeshBase & get_mesh();
 
   /**
    * @returns true when the _mesh_data pointer is not NULL.
@@ -361,6 +342,12 @@ public:
    */
   MeshData & get_mesh_data();
 
+  /**
+   * @serializes a distributed mesh and its associated
+   * degree of freedom numbering for all systems
+   **/
+  void allgather ();
+
 
   /**
    * Data structure holding arbitrary parameters.
@@ -374,7 +361,7 @@ protected:
   /**
    * The mesh data structure
    */
-  Mesh& _mesh;
+  MeshBase& _mesh;
 
   /**
    * A pointer to the MeshData object you would like to use.
@@ -412,7 +399,7 @@ private:
 // ------------------------------------------------------------
 // EquationSystems inline methods
 inline
-const Mesh & EquationSystems::get_mesh () const
+const MeshBase & EquationSystems::get_mesh () const
 {
   return _mesh;
 }
@@ -420,7 +407,7 @@ const Mesh & EquationSystems::get_mesh () const
 
 
 inline
-Mesh & EquationSystems::get_mesh ()
+MeshBase & EquationSystems::get_mesh ()
 {
   return _mesh;
 }
@@ -429,7 +416,7 @@ Mesh & EquationSystems::get_mesh ()
 inline
 const MeshData & EquationSystems::get_mesh_data () const
 {
-  assert (_mesh_data != NULL);
+  libmesh_assert (_mesh_data != NULL);
   return *_mesh_data;
 }
 
@@ -437,7 +424,7 @@ const MeshData & EquationSystems::get_mesh_data () const
 inline
 MeshData & EquationSystems::get_mesh_data ()
 {
-  assert (_mesh_data != NULL);
+  libmesh_assert (_mesh_data != NULL);
   return *_mesh_data;
 }
 
@@ -481,7 +468,7 @@ T_sys & EquationSystems::add_system (const std::string& name)
 //		<< " named " << name
 //		<< std::endl;
 
-//      error();
+//      libmesh_error();
 
       ptr = &(this->get_system<T_sys>(name));
     }
@@ -507,7 +494,7 @@ template <typename T_sys>
 inline
 const T_sys & EquationSystems::get_system (const unsigned int num) const
 {
-  assert (num < this->n_systems());
+  libmesh_assert (num < this->n_systems());
 
 
   const_system_iterator       pos = _systems.begin();
@@ -522,7 +509,7 @@ const T_sys & EquationSystems::get_system (const unsigned int num) const
     {
       std::cerr << "ERROR: no system number " << num << " found!"
 		<< std::endl;
-      error();
+      libmesh_error();
     }
 
   // Attempt dynamic cast
@@ -534,7 +521,7 @@ const T_sys & EquationSystems::get_system (const unsigned int num) const
       std::cerr << "ERROR: cannot convert system "
 		<< num << " to requested type!"
 		<< std::endl;
-      error();
+      libmesh_error();
     }
   
   return *ptr;
@@ -547,7 +534,7 @@ template <typename T_sys>
 inline
 T_sys & EquationSystems::get_system (const unsigned int num)
 {
-  assert (num < this->n_systems());
+  libmesh_assert (num < this->n_systems());
   
   const_system_iterator       pos = _systems.begin();
   const const_system_iterator end = _systems.end();
@@ -561,7 +548,7 @@ T_sys & EquationSystems::get_system (const unsigned int num)
     {
       std::cerr << "ERROR: no system number " << num << " found!"
 		<< std::endl;
-      error();
+      libmesh_error();
     }
 
   // Attempt dynamic cast
@@ -573,7 +560,7 @@ T_sys & EquationSystems::get_system (const unsigned int num)
       std::cerr << "ERROR: cannot convert system "
 		<< num << " to requested type!"
 		<< std::endl;
-      error();
+      libmesh_error();
     }
 
   return *ptr; 
@@ -595,7 +582,7 @@ const T_sys & EquationSystems::get_system (const std::string& name) const
     {
       std::cerr << "ERROR: no system named \"" << name << "\" found!"
 		<< std::endl;
-      error();
+      libmesh_error();
     }
 
   // Attempt dynamic cast
@@ -607,7 +594,7 @@ const T_sys & EquationSystems::get_system (const std::string& name) const
       std::cerr << "ERROR: cannot convert system \""
 		<< name << "\" to requested type!"
 		<< std::endl;
-      error();
+      libmesh_error();
     }
 
   return *ptr; 
@@ -629,7 +616,7 @@ T_sys & EquationSystems::get_system (const std::string& name)
     {
       std::cerr << "ERROR: no system named " << name << " found!"
 		<< std::endl;
-      error();
+      libmesh_error();
     }
 
   // Attempt dynamic cast
@@ -641,7 +628,7 @@ T_sys & EquationSystems::get_system (const std::string& name)
       std::cerr << "ERROR: cannot convert system \""
 		<< name << "\" to requested type!"
 		<< std::endl;
-      error();
+      libmesh_error();
     }
 
   return *ptr; 
@@ -685,39 +672,4 @@ System & EquationSystems::get_system (const unsigned int num)
 
 
 
-// inline
-// System & EquationSystems::operator () (const std::string& name)
-// {
-//   deprecated(); // Use the get_system() interface directly instead.
-//   return this->get_system (name);
-// }
-  
- 
-// inline
-// const System & EquationSystems::operator () (const std::string& name) const
-// {
-//   deprecated(); // Use the get_system() interface directly instead.
-//   return this->get_system (name);
-// }
-  
- 
- 
-// inline
-// System & EquationSystems::operator () (const unsigned int num)
-// {
-//   deprecated(); // Use the get_system() interface directly instead.
-//   return this->get_system (num);
-// }
-
-
-
-// inline
-// const System & EquationSystems::operator () (const unsigned int num) const
-// {
-//   deprecated(); // Use the get_system() interface directly instead.
-//   return this->get_system (num);
-// }
-
-
-
 #endif
