@@ -1,4 +1,4 @@
-// $Id: euler_solver.h,v 1.6 2007-10-21 20:48:44 benkirk Exp $
+// $Id: euler_solver.h 2629 2008-02-01 23:12:52Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -25,7 +25,7 @@
 // C++ includes
 
 // Local includes
-#include "time_solver.h"
+#include "unsteady_solver.h"
 
 /**
  * This class defines a theta-method Euler (defaulting to Backward
@@ -41,18 +41,13 @@
 
 // ------------------------------------------------------------
 // Solver class definition
-class EulerSolver : public TimeSolver
+class EulerSolver : public UnsteadySolver
 {
 public:
-  /**
-   * The type of system
-   */
-  typedef DifferentiableSystem sys_type;
-  
   /**
    * The parent class
    */
-  typedef TimeSolver Parent;
+  typedef UnsteadySolver Parent;
   
   /**
    * Constructor. Requires a reference to the system
