@@ -1,5 +1,5 @@
 
-// $Id: fem_system.h,v 1.16 2007-10-21 20:48:44 benkirk Exp $
+// $Id: fem_system.h 2627 2008-01-28 23:01:18Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -35,6 +35,8 @@
 
 // Forward Declarations
 
+class FEBase;
+class QBase;
 template <typename T> class NumericVector;
 
 /**
