@@ -1,4 +1,4 @@
-// $Id: newton_solver.h,v 1.12 2007-10-21 20:48:44 benkirk Exp $
+// $Id: newton_solver.h 2788 2008-04-13 02:05:22Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -82,10 +82,23 @@ public:
    */
   bool require_residual_reduction;
 
+  /**
+   * If require_residual_reduction is true, the solver may reduce step
+   * lengths when required.  If so, brent_line_search is an option.
+   * If brent_line_search is set to false, the solver reduces the
+   * length of its steps by 1/2 iteratively until it finds residual
+   * reduction.  If true, step lengths are first reduced by 1/2 or
+   * more to find some residual reduction, then Brent's method is used
+   * to find as much residual reduction as possible.
+   *
+   * brent_line_search is currently set to true by default.
+   */
+  bool brent_line_search;
+
   /**
    * If the quasi-Newton step length must be reduced to below this
    * factor to give a residual reduction, then the Newton solver
-   * dies with an error()
+   * dies with a libmesh_error()
    * It is currently set to 1e-5 by default.
    */
   Real minsteplength;
@@ -106,6 +119,16 @@ protected:
    */
   AutoPtr<LinearSolver<Number> > linear_solver;
 
+  /**
+   * This does a line search in the direction opposite linear_solution
+   * to try and minimize the residual of newton_iterate.
+   * newton_iterate is moved to the end of the quasiNewton step, and
+   * the return value is the substep size.
+   */
+  Real line_search(Real tol, Real last_residual, Real current_residual,
+		   NumericVector<Number> &newton_iterate,
+		   const NumericVector<Number> &linear_solution);
+
   /**
    * This prints output for the convergence criteria based on
    * by the given residual and step size.
