@@ -1,4 +1,4 @@
-// $Id: solver.h,v 1.4 2007-10-21 20:48:44 benkirk Exp $
+// $Id: solver.h 2573 2007-12-06 16:20:46Z benkirk $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -30,7 +30,7 @@
 #include "equation_systems.h"
 
 // Forward Declarations
-class Mesh;
+class MeshBase;
 class Solver;
 
 /**
@@ -108,7 +108,7 @@ public:
   /**
    * @returns a reference to the \p Mesh.
    */
-  const Mesh & mesh () const { return _mesh; }
+  const MeshBase & mesh () const { return _mesh; }
 
   
 protected:
@@ -121,7 +121,7 @@ protected:
   /**
    * @returns a reference to the \p Mesh.
    */
-  Mesh & mesh () { return _mesh; }
+  MeshBase & mesh () { return _mesh; }
 
   /**
    * A reference to the system we are solving.
@@ -132,7 +132,7 @@ protected:
    * A reference to the \p Mesh for the system
    * we are solving.
    */
-  Mesh& _mesh;
+  MeshBase& _mesh;
 };
 
 
@@ -158,7 +158,7 @@ Solver::~Solver ()
 inline
 void Solver::init ()
 {
-  std::cout << "Initializing $Id: solver.h,v 1.4 2007-10-21 20:48:44 benkirk Exp $"
+  std::cout << "Initializing $Id: solver.h 2573 2007-12-06 16:20:46Z benkirk $"
 	    << std::endl;
   
   // Initialize the system.
@@ -182,7 +182,7 @@ void Solver::solve ()
   // Perform any necessary pre-processing
   Solver::pre_process ();
   
-//  std::cout << "Solving $Id: solver.h,v 1.4 2007-10-21 20:48:44 benkirk Exp $"
+//  std::cout << "Solving $Id: solver.h 2573 2007-12-06 16:20:46Z benkirk $"
 //	    << std::endl;
 
   // Solve the system
