@@ -1,5 +1,5 @@
 
-// $Id: steady_solver.h,v 1.7 2007-10-21 20:48:44 benkirk Exp $
+// $Id: steady_solver.h 2638 2008-02-05 23:15:13Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -94,7 +94,7 @@ public:
    * successive solution iterates ||u^{n+1} - u^{n}|| in some norm,
    * but for this class just returns 0.
    */
-  Real du(unsigned char) { return 0.; }
+  virtual Real du(const SystemNorm&) const { return 0; };
 };
 
 
