@@ -1,4 +1,4 @@
-// $Id: system.h,v 1.25 2007-10-21 20:48:44 benkirk Exp $
+// $Id: system.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -26,17 +26,18 @@
 #include <vector>
 
 // Local Includes
-#include "libmesh_common.h"
-#include "fe_type.h"
 #include "auto_ptr.h"
+#include "enum_xdr_mode.h"
+#include "fe_type.h"
+#include "libmesh_common.h"
 #include "reference_counted_object.h"
-
-
+#include "system_norm.h"
+#include "elem_range.h"
 
 // Forward Declarations
 class System;
 class EquationSystems;
-class Mesh;
+class MeshBase;
 class Xdr;
 class DofMap;
 class Parameters;
@@ -201,12 +202,12 @@ public:
   /**
    * @returns a constant reference to this systems's \p _mesh.
    */
-  const Mesh & get_mesh() const;
+  const MeshBase & get_mesh() const;
   
   /**
    * @returns a reference to this systems's \p _mesh.
    */
-  Mesh & get_mesh();
+  MeshBase & get_mesh();
   
   /**
    * @returns a constant reference to this system's \p _dof_map.
@@ -389,47 +390,71 @@ public:
   const FEType & variable_type (const std::string& var) const;
 
   /**
-   * @returns a norm of variable \p var in the vector \p v, in the L2 norm if
-   * \p component_norm == 0, the H1 norm if \p component_norm == 1, or the H2
-   * norm if \p component_norm == 2.
+   * @returns a norm of variable \p var in the vector \p v, in the specified
+   * norm (e.g. L2, H0, H1)
    */
   Real calculate_norm(NumericVector<Number>& v,
 		      unsigned int var = 0,
-		      unsigned char norm_type = 0) const;
+		      FEMNormType norm_type = L2) const;
 
   /**
    * @returns a norm of the vector \p v, using \p component_norm and \p
    * component_scale to choose and weight the norms of each variable.
    */
   Real calculate_norm(NumericVector<Number>& v,
-		      std::vector<unsigned char> &component_norm,
-		      std::vector<float> &component_scale) const;
+		      const SystemNorm &norm) const;
 
   /**
-   * Reads the basic data for this System.
+   * Reads the basic data header for this System.
    */
-  void read (Xdr& io, 
-	     const bool read_header=true,
-	     const bool read_additional_data=true);
+  void read_header (Xdr& io, 
+		    const bool read_header=true,
+		    const bool read_additional_data=true,
+		    const bool read_legacy_format=false);
 
   /**
    * Reads additional data, namely vectors, for this System.
    */
-  void read_data (Xdr& io,
-		  const bool read_additional_data=true);
+  void read_legacy_data (Xdr& io,
+			 const bool read_additional_data=true);
 
   /**
-   * Writes the basic data for this System.
+   * Reads additional data, namely vectors, for this System.
+   * This method may safely be called on a distributed-memory mesh.
    */
-  void write (Xdr& io,
-	      const bool write_additional_data) const;
+  void read_serialized_data (Xdr& io,
+			     const bool read_additional_data=true);
+
+  /**
+   * Reads additional data, namely vectors, for this System.
+   * This method may safely be called on a distributed-memory mesh.
+   * This method will read an individual file for each processor in the simulation
+   * where the local solution components for that processor are stored.
+   */
+  void read_parallel_data (Xdr &io,
+			   const bool read_additional_data);
+  /**
+   * Writes the basic data header for this System.
+   */
+  void write_header (Xdr& io,
+		     const bool write_additional_data) const;
 
   /**
    * Writes additional data, namely vectors, for this System.
+   * This method may safely be called on a distributed-memory mesh.
    */
-  void write_data (Xdr& io,
-		   const bool write_additional_data = true) const;
+  void write_serialized_data (Xdr& io,
+			      const bool write_additional_data = true) const;
 
+  /**
+   * Writes additional data, namely vectors, for this System.
+   * This method may safely be called on a distributed-memory mesh.
+   * This method will create an individual file for each processor in the simulation
+   * where the local solution components for that processor will be stored.
+   */
+  void write_parallel_data (Xdr &io,
+			    const bool write_additional_data) const;
+  
   /**
    * @returns a string containing information about the
    * system.
@@ -561,13 +586,50 @@ protected:
   void project_vector (const NumericVector<Number>&,
 		       NumericVector<Number>&) const;
 
-  // -------------------------------------------------
-  // Necessary classes
-  //
   
 private:
 
   
+
+  /**
+   * Reads an input vector from the stream \p io and assigns
+   * the values to a set of \p DofObjects.  This method uses
+   * blocked input and is safe to call on a distributed memory-mesh.
+   */   
+  template <typename iterator_type>
+  unsigned int read_serialized_blocked_dof_objects (const unsigned int var,
+						    const unsigned int n_objects,
+						    const iterator_type begin,
+						    const iterator_type end,
+						    Xdr &io,
+						    NumericVector<Number> &vec) const;
+
+  /**
+   * Reads a vector for this System.
+   * This method may safely be called on a distributed-memory mesh.
+   */
+  void read_serialized_vector (Xdr& io,
+			       NumericVector<Number> &vec);
+
+  /**
+   * Writes an output vector to the stream \p io for a set of \p DofObjects.
+   * This method uses blocked output and is safe to call on a distributed memory-mesh.
+   */   
+  template <typename iterator_type>
+  unsigned int write_serialized_blocked_dof_objects (const NumericVector<Number> &vec,
+						     const unsigned int var,
+						     const unsigned int n_objects,
+						     const iterator_type begin,
+						     const iterator_type end,
+						     Xdr &io) const;
+
+  /**
+   * Writes a vector for this System.
+   * This method may safely be called on a distributed-memory mesh.
+   */
+  void write_serialized_vector (Xdr& io,
+				const NumericVector<Number> &vec) const;
+
   /**
    * Function that initializes the system.
    */
@@ -603,7 +665,7 @@ private:
    * Constant reference to the \p mesh data structure used
    * for the simulation.   
    */
-  Mesh& _mesh;
+  MeshBase& _mesh;
   
   /**
    * A name associated with this system.
@@ -670,7 +732,77 @@ private:
    * additional vectors were actually written for this file.
    */
   bool _additional_data_written;
-  
+
+
+  /**
+   * This class implements projecting a vector from 
+   * an old mesh to the newly refined mesh.  This
+   * may be exectued in parallel on multiple threads.
+   */
+  class ProjectVector 
+  {
+  private:
+    const System                &system;
+    const NumericVector<Number> &old_vector;
+    NumericVector<Number>       &new_vector;
+
+  public:
+    ProjectVector (const System &system_in,
+		   const NumericVector<Number> &old_v_in,
+		   NumericVector<Number> &new_v_in) :
+    system(system_in),
+    old_vector(old_v_in),
+    new_vector(new_v_in)
+    {}
+    
+    void operator()(const ConstElemRange &range) const;
+  };
+
+
+  /**
+   * This class implements projecting a vector from 
+   * an old mesh to the newly refined mesh.  This
+   * may be exectued in parallel on multiple threads.
+   */
+  class ProjectSolution
+  {
+  private:
+    const System                &system;
+
+    Number (* fptr)(const Point& p,
+		    const Parameters& parameters,
+		    const std::string& sys_name,
+		    const std::string& unknown_name);
+
+    Gradient (* gptr)(const Point& p,
+		      const Parameters& parameters,
+		      const std::string& sys_name,
+		      const std::string& unknown_name);
+
+    Parameters &parameters;
+    NumericVector<Number>       &new_vector;
+
+  public:
+    ProjectSolution (const System &system_in,
+		     Number fptr_in(const Point& p,
+				    const Parameters& parameters,
+				    const std::string& sys_name,
+				    const std::string& unknown_name),
+		     Gradient gptr_in(const Point& p,
+				      const Parameters& parameters,
+				      const std::string& sys_name,
+				      const std::string& unknown_name),
+		     Parameters &parameters_in,
+		     NumericVector<Number> &new_v_in) :
+    system(system_in),
+    fptr(fptr_in),
+    gptr(gptr_in),
+    parameters(parameters_in),
+    new_vector(new_v_in)
+    {}
+    
+    void operator()(const ConstElemRange &range) const;
+  };
 };
 
 
@@ -694,7 +826,7 @@ unsigned int System::number() const
 
 
 inline
-const Mesh & System::get_mesh() const
+const MeshBase & System::get_mesh() const
 {
   return _mesh;
 }
@@ -702,7 +834,7 @@ const Mesh & System::get_mesh() const
 
 
 inline
-Mesh & System::get_mesh()
+MeshBase & System::get_mesh()
 {
   return _mesh;
 }
@@ -760,7 +892,7 @@ unsigned int System::n_vars() const
 inline
 const std::string & System::variable_name (const unsigned int i) const
 {
-  assert (i < n_vars());
+  libmesh_assert (i < n_vars());
 
   return _var_names[i];
 }
@@ -781,7 +913,7 @@ const FEType & System::variable_type (const std::string& var) const
   std::map<std::string, FEType>::const_iterator
     pos = _var_type.find(var);
 
-  assert (pos != _var_type.end());
+  libmesh_assert (pos != _var_type.end());
   
   return pos->second;
 }
