@@ -1,4 +1,4 @@
-// $Id: time_solver.h,v 1.14 2007-10-21 20:48:44 benkirk Exp $
+// $Id: time_solver.h 2638 2008-02-05 23:15:13Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -26,6 +26,7 @@
 
 // Local includes
 #include "auto_ptr.h"
+#include "system_norm.h"
 #include "libmesh_common.h"
 #include "numeric_vector.h"
 #include "reference_counted_object.h"
@@ -83,31 +84,21 @@ public:
   virtual void reinit ();
 
   /**
-   * This method solves for the solution at the next timestep (or solves for a
-   * steady-state solution).  Usually we will only need to solve one
-   * (non)linear system per timestep, but more complex subclasses
-   * may override this.
+   * This method solves for the solution at the next timestep (or
+   * solves for a steady-state solution).  Usually we will only need
+   * to solve one (non)linear system per timestep, but more complex
+   * subclasses may override this.
    */
   virtual void solve ();
 
   /**
    * This method advances the solution to the next timestep, after a
-   * solve() has been performed.  Often this will be
-   * done after every TimeSolver::solve(), but adaptive mesh refinement
-   * and/or adaptive timestep selection may require some solve() steps
-   * to be repeated.
+   * solve() has been performed.  Often this will be done after every
+   * UnsteadySolver::solve(), but adaptive mesh refinement and/or adaptive
+   * time step selection may require some solve() steps to be repeated.
    */
   virtual void advance_timestep ();
 
-  /**
-   * This method should return the expected convergence order of the
-   * (non-local) error of the time discretization scheme - e.g. 2 for the
-   * O(deltat^2) Crank-Nicholson, or 1 for the O(deltat) Backward Euler.
-   *
-   * Useful for adaptive timestepping schemes.
-   */
-  virtual Real error_order () const = 0;
-
   /**
    * This method uses the DifferentiableSystem's
    * element_time_derivative() and element_constraint()
@@ -155,9 +146,6 @@ public:
 
   /**
    * Computes the size of ||u^{n+1} - u^{n}|| in some norm.
-   * Supported norms are
-   * l2: norm_type=0
-   * l1: norm_type=1
    * 
    * Note that, while you can always call this function, its
    * result may or may not be very meaningful.  For example, if
@@ -165,7 +153,7 @@ public:
    * then you'll get a result of zero since old_nonlinear_solution
    * is set equal to nonlinear_solution in this function.
    */
-  Real du(unsigned char norm_type=0);
+  virtual Real du(const SystemNorm& norm) const = 0;
 
   /**
    * This value (which defaults to zero) is the number of times the
