@@ -1,4 +1,4 @@
-// $Id: error_vector.h,v 1.9 2007-10-21 20:48:45 benkirk Exp $
+// $Id: error_vector.h 2501 2007-11-20 02:33:29Z benkirk $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -147,7 +147,7 @@ public:
    * the active elements of \p mesh.
    */
   void plot_error(const std::string &filename,
-		  const Mesh& mesh) const;
+		  const MeshBase& mesh) const;
 
 protected:
   /**
