@@ -1,4 +1,4 @@
-// $Id: o_string_stream.h,v 1.5 2007-10-21 20:48:45 benkirk Exp $
+// $Id: o_string_stream.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -111,8 +111,8 @@
  /*
   * class alias
   */
-# define OStringStream           std::ostringstream
-
+//# define OStringStream           std::ostringstream
+typedef std::ostringstream OStringStream;
 
 
 
@@ -296,7 +296,7 @@
 			   const Real r,
 			   const char c)
  {
-   assert (w < 30);
+   libmesh_assert (w < 30);
    char buf[30];  
    char format[8];
    // form the format for r
@@ -315,7 +315,7 @@
  void OStringStream::left (const sizetype w,
 			   const int n)
  {
-   assert (w < 30);
+   libmesh_assert (w < 30);
    char buf[30];  
    // form string as desired
    sprintf (buf, "%d", n);
@@ -341,7 +341,7 @@
 			    const Real r,
 			    const char c)
  {
-   assert (w < 30);
+   libmesh_assert (w < 30);
    char buf[30];  
    char format[8];
    // form the format for r
@@ -359,7 +359,7 @@
  void OStringStream::scientific (const sizetype w,
 				 const Real r)
  {
-   assert (w < 30);
+   libmesh_assert (w < 30);
    char buf[30];  
    char format[8];
    // form the format for r
