@@ -1,4 +1,4 @@
-// $Id: parameters.h,v 1.9 2007-10-21 20:48:45 benkirk Exp $
+// $Id: parameters.h 2910 2008-07-08 15:41:11Z friedmud $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -41,7 +41,7 @@
  *
  * \author Benjamin S. Kirk
  * \date 2004
- * \version $Revision: 1.9 $
+ * \version $Revision: 2910 $
  */
 
 // ------------------------------------------------------------
@@ -118,7 +118,6 @@ public:
    * Prints the contents to the specified stream.
    */
   void print (std::ostream& os=std::cout) const;
-
   
 private:
 
@@ -153,6 +152,7 @@ private:
     virtual Value* clone () const = 0;
   };
 
+public:
 
   /**
    * Concrete definition of a parameter value
@@ -196,11 +196,6 @@ private:
     T _value;
   };
 
-  /**
-   * Data structure to map names with values.
-   */
-  std::map<std::string, Value*> _values;
-
   /**
    * Parameter map iterator.
    */
@@ -210,6 +205,34 @@ private:
    * Constant parameter map iterator.
    */
   typedef std::map<std::string, Value*>::const_iterator const_iterator;
+
+  /**
+   * Iterator pointing to the beginning of the set of parameters.
+   */
+  iterator begin();
+
+  /**
+   * Iterator pointing to the beginning of the set of parameters.
+   */
+  const_iterator begin() const;
+
+  /**
+   * Iterator pointing to the end of the set of parameters
+   */
+  iterator end();
+
+  /**
+   * Iterator pointing to the end of the set of parameters
+   */
+  const_iterator end() const;
+
+private:
+
+  /**
+   * Data structure to map names with values.
+   */
+  std::map<std::string, Value*> _values;
+
 };
 
 
@@ -244,7 +267,7 @@ Parameters::Value* Parameters::Parameter<T>::clone () const
   Parameter<T>
     *copy = new Parameter<T>;
 
-  assert (copy != NULL);
+  libmesh_assert (copy != NULL);
   
   copy->_value = _value;
 
@@ -359,14 +382,14 @@ const T& Parameters::get (const std::string& name) const
 		<< name << "\":" << std::endl
 		<< *this;
       
-      error();
+      libmesh_error();
     }
 
   Parameters::const_iterator it = _values.find(name);
 
-  assert (it != _values.end());
-  assert (it->second != NULL);
-  assert (dynamic_cast<const Parameter<T>*>(it->second) != NULL);
+  libmesh_assert (it != _values.end());
+  libmesh_assert (it->second != NULL);
+  libmesh_assert (dynamic_cast<const Parameter<T>*>(it->second) != NULL);
   
   return dynamic_cast<Parameter<T>*>(it->second)->get();
 }
@@ -384,7 +407,7 @@ T& Parameters::set (const std::string& name)
 
   param = dynamic_cast<Parameter<T>*>(_values[name]);
 
-  assert (param != NULL);
+  libmesh_assert (param != NULL);
   
   return param->set();
 }
@@ -423,4 +446,28 @@ unsigned int Parameters::n_parameters () const
   return cnt;	 
 }
 
+inline
+Parameters::iterator Parameters::begin()
+{
+  return _values.begin();
+}
+
+inline
+Parameters::const_iterator Parameters::begin() const
+{
+  return _values.begin();
+}
+
+inline
+Parameters::iterator Parameters::end()
+{
+  return _values.end();
+}
+
+inline
+Parameters::const_iterator Parameters::end() const
+{
+  return _values.end();
+}
+
 #endif // #define __parameters_h__
