@@ -1,4 +1,4 @@
-// $Id: tree.h,v 1.12 2007-10-22 15:58:51 benkirk Exp $
+// $Id: tree.h 2788 2008-04-13 02:05:22Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -139,7 +139,7 @@ Tree<N>::Tree (const Tree<N>& other_tree) :
   root       (other_tree.root),
   build_type (other_tree.build_type)
 {
-  error();
+  libmesh_error();
 }
 
 
