@@ -1,4 +1,4 @@
-// $Id: tree_node.h,v 1.10 2007-10-21 20:48:45 benkirk Exp $
+// $Id: tree_node.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -100,7 +100,7 @@ public:
    * false otherwise.
    */
   bool bounds_node (const Node* nd) const
-  { assert (nd != NULL); return bounds_point(*nd); }
+  { libmesh_assert (nd != NULL); return bounds_point(*nd); }
 
   /**
    * @returns true if this TreeNode (or its children) contain point p,
@@ -218,9 +218,9 @@ TreeNode<N>::TreeNode (const MeshBase& m,
   parent         (p),
   contains_ifems (false)
 {
-  // assert our children are empty, thus we are active.
-  assert (children.empty());
-  assert (this->active());
+  // libmesh_assert our children are empty, thus we are active.
+  libmesh_assert (children.empty());
+  libmesh_assert (this->active());
   
   // Reserve space for the nodes & elements
   nodes.reserve    (tgt_bin_size);
