@@ -1,4 +1,4 @@
-// $Id: utility.h,v 1.12 2007-10-21 20:48:45 benkirk Exp $
+// $Id: utility.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -72,7 +72,7 @@ namespace Utility
    */
   template <int N>
   inline
-  Real pow(const Real x) { assert(N>0); return x * pow<N-1>(x); }
+  Real pow(const Real x) { libmesh_assert(N>0); return x * pow<N-1>(x); }
 
   /**
    * You have to also provide a full specialization for
