@@ -1,4 +1,4 @@
-// $Id: xdr_cxx.h,v 1.13 2007-10-21 20:48:45 benkirk Exp $
+// $Id: xdr_cxx.h 2789 2008-04-13 02:24:40Z roystgnr $
 
 // The libMesh Finite Element Library.
 // Copyright (C) 2002-2007  Benjamin S. Kirk, John W. Peterson
@@ -24,14 +24,16 @@
 
 // Local includes
 #include "libmesh_common.h"
+#include "libmesh.h"
 #include "enum_xdr_mode.h"
-#include "o_f_stream.h"
+#include "auto_ptr.h"
 
 // C++ includes
 #ifdef HAVE_XDR
 #  include <rpc/rpc.h>
 #endif
 
+#include <iosfwd>
 #include <vector>
 #include <string>
 #ifdef USE_COMPLEX_NUMBERS
@@ -119,12 +121,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (int& a) { assert (writing()); data(a); return *this; }
+  Xdr& operator << (int& a) { libmesh_assert (writing()); data(a); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (int& a) { assert (reading()); data(a); return *this; }
+  Xdr& operator >> (int& a) { libmesh_assert (reading()); data(a); return *this; }
   
   /**
    * Inputs or outputs a single unsigned integer.
@@ -134,12 +136,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (unsigned int& a) { assert (writing()); data(a); return *this; }
+  Xdr& operator << (unsigned int& a) { libmesh_assert (writing()); data(a); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (unsigned int& a) { assert (reading()); data(a); return *this; }
+  Xdr& operator >> (unsigned int& a) { libmesh_assert (reading()); data(a); return *this; }
 
   /**
    * Inputs or outputs a single short integer.
@@ -149,12 +151,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (short int& a) { assert (writing()); data(a); return *this; }
+  Xdr& operator << (short int& a) { libmesh_assert (writing()); data(a); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (short int& a) { assert (reading()); data(a); return *this; }
+  Xdr& operator >> (short int& a) { libmesh_assert (reading()); data(a); return *this; }
 
   /**
    * Inputs or outputs a single unsigned short integer.
@@ -164,12 +166,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (unsigned short int& a) { assert (writing()); data(a); return *this; }
+  Xdr& operator << (unsigned short int& a) { libmesh_assert (writing()); data(a); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (unsigned short int& a) { assert (reading()); data(a); return *this; }
+  Xdr& operator >> (unsigned short int& a) { libmesh_assert (reading()); data(a); return *this; }
 
   /**
    * Inputs or outputs a single float.
@@ -179,12 +181,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (float& a) { assert (writing()); data(a); return *this; }
+  Xdr& operator << (float& a) { libmesh_assert (writing()); data(a); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (float& a) { assert (reading()); data(a); return *this; }
+  Xdr& operator >> (float& a) { libmesh_assert (reading()); data(a); return *this; }
 
   /**
    * Inputs or outputs a single double.
@@ -194,12 +196,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (double& a) { assert (writing()); data(a); return *this; }
+  Xdr& operator << (double& a) { libmesh_assert (writing()); data(a); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (double& a) { assert (reading()); data(a); return *this; }
+  Xdr& operator >> (double& a) { libmesh_assert (reading()); data(a); return *this; }
 
   /**
    * Inputs or outputs a single long double, but in double precision.
@@ -211,12 +213,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (long double& a) { assert (writing()); data(a); return *this; }
+  Xdr& operator << (long double& a) { libmesh_assert (writing()); data(a); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (long double& a) { assert (reading()); data(a); return *this; }
+  Xdr& operator >> (long double& a) { libmesh_assert (reading()); data(a); return *this; }
 
 
 #ifdef USE_COMPLEX_NUMBERS
@@ -229,12 +231,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (std::complex<double>& a) { assert (writing()); data(a); return *this; }
+  Xdr& operator << (std::complex<double>& a) { libmesh_assert (writing()); data(a); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (std::complex<double>& a) { assert (reading()); data(a); return *this; }
+  Xdr& operator >> (std::complex<double>& a) { libmesh_assert (reading()); data(a); return *this; }
 
   /**
    * Inputs or outputs a single complex<long double>, but in double
@@ -247,12 +249,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (std::complex<long double>& a) { assert (writing()); data(a); return *this; }
+  Xdr& operator << (std::complex<long double>& a) { libmesh_assert (writing()); data(a); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (std::complex<long double>& a) { assert (reading()); data(a); return *this; }
+  Xdr& operator >> (std::complex<long double>& a) { libmesh_assert (reading()); data(a); return *this; }
 
 #endif
 
@@ -265,12 +267,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (std::vector<int>& v) { assert (writing()); data(v); return *this; }
+  Xdr& operator << (std::vector<int>& v) { libmesh_assert (writing()); data(v); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (std::vector<int>& v) { assert (reading()); data(v); return *this; }
+  Xdr& operator >> (std::vector<int>& v) { libmesh_assert (reading()); data(v); return *this; }
 
   /**
    * Inputs or outputs a vector of unsigned integers.
@@ -280,12 +282,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (std::vector<unsigned int>& v) { assert (writing()); data(v); return *this; }
+  Xdr& operator << (std::vector<unsigned int>& v) { libmesh_assert (writing()); data(v); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (std::vector<unsigned int>& v) { assert (reading()); data(v); return *this; }
+  Xdr& operator >> (std::vector<unsigned int>& v) { libmesh_assert (reading()); data(v); return *this; }
 
   /**
    * Inputs or outputs a vector of short integers.
@@ -295,12 +297,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (std::vector<short int>& v) { assert (writing()); data(v); return *this; }
+  Xdr& operator << (std::vector<short int>& v) { libmesh_assert (writing()); data(v); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (std::vector<short int>& v) { assert (reading()); data(v); return *this; }
+  Xdr& operator >> (std::vector<short int>& v) { libmesh_assert (reading()); data(v); return *this; }
 
   /**
    * Inputs or outputs a vector of unsigned short integers.
@@ -310,12 +312,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (std::vector<unsigned short int>& v) { assert (writing()); data(v); return *this; }
+  Xdr& operator << (std::vector<unsigned short int>& v) { libmesh_assert (writing()); data(v); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (std::vector<unsigned short int>& v) { assert (reading()); data(v); return *this; }
+  Xdr& operator >> (std::vector<unsigned short int>& v) { libmesh_assert (reading()); data(v); return *this; }
 
   /**
    * Inputs or outputs a vector of floats.
@@ -325,12 +327,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (std::vector<float>& v) { assert (writing()); data(v); return *this; }
+  Xdr& operator << (std::vector<float>& v) { libmesh_assert (writing()); data(v); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (std::vector<float>& v) { assert (reading()); data(v); return *this; }
+  Xdr& operator >> (std::vector<float>& v) { libmesh_assert (reading()); data(v); return *this; }
 
   /**
    * Inputs or outputs a vector of doubles.
@@ -340,12 +342,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (std::vector<double>& v) { assert (writing()); data(v); return *this; }
+  Xdr& operator << (std::vector<double>& v) { libmesh_assert (writing()); data(v); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (std::vector<double>& v) { assert (reading()); data(v); return *this; }
+  Xdr& operator >> (std::vector<double>& v) { libmesh_assert (reading()); data(v); return *this; }
 
   /**
    * Inputs or outputs a vector of long doubles, but in double
@@ -364,12 +366,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (std::vector<long double>& v) { assert (writing()); data(v); return *this; }
+  Xdr& operator << (std::vector<long double>& v) { libmesh_assert (writing()); data(v); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (std::vector<long double>& v) { assert (reading()); data(v); return *this; }
+  Xdr& operator >> (std::vector<long double>& v) { libmesh_assert (reading()); data(v); return *this; }
 
 
 #ifdef USE_COMPLEX_NUMBERS
@@ -382,12 +384,12 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (std::vector< std::complex<double> >& v) { assert (writing()); data(v); return *this; }
+  Xdr& operator << (std::vector< std::complex<double> >& v) { libmesh_assert (writing()); data(v); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (std::vector< std::complex<double> >& v) { assert (reading()); data(v); return *this; }
+  Xdr& operator >> (std::vector< std::complex<double> >& v) { libmesh_assert (reading()); data(v); return *this; }
 
 #endif
 
@@ -400,14 +402,26 @@ public:
   /**
    * Same, but provides an \p ostream like interface.
    */
-  Xdr& operator << (std::string& v) { assert (writing()); data(v); return *this; }
+  Xdr& operator << (std::string& v) { libmesh_assert (writing()); data(v); return *this; }
 
   /**
    * Same, but provides an \p istream like interface.
    */
-  Xdr& operator >> (std::string& v) { assert (reading()); data(v); return *this; }
+  Xdr& operator >> (std::string& v) { libmesh_assert (reading()); data(v); return *this; }
 
 
+  /**
+   * Inputs or outputs a raw data stream.
+   */
+  template <typename T>
+  void data_stream (T *val, const unsigned int len, const unsigned int line_break=libMesh::invalid_uint);
+
+  /**
+   * Writes or reads (ignores) a comment line.
+   */   
+  void comment (std::string &);
+  
+
 private:
 
   /**
@@ -415,6 +429,11 @@ private:
    */ 
   const XdrMODE mode;
 
+  /**
+   * The file name
+   */
+  std::string file_name;
+
 #ifdef HAVE_XDR
   
   /**
@@ -432,24 +451,27 @@ private:
   
 #endif
 
-  /**
-   * The output file stream.
-   * Use the customized class to enable
-   * features also for compilers with broken
-   * iostream
-   */
-  OFStream out;
-
   /**
    * The input file stream.
    */
-  std::ifstream in;
+  AutoPtr<std::istream> in;
+
+  /**
+   * The output file stream.
+   */
+  AutoPtr<std::ostream> out;
 
   /**
    * A buffer to put comment strings into.
    */
   const int comm_len;
   char comm[xdr_MAX_STRING_LENGTH];  
+
+  /**
+   * Are we reading/writing bzipped or gzipped files?
+   */
+  bool gzipped_file;
+  bool bzipped_file;
 };
 
 
